@@ -10,5 +10,6 @@ var bisect__util_8hpp =
     [ "storeInterval", "bisect__util_8hpp.html#a77b416d8ba729bd231378c6fcebebcac", null ],
     [ "storeIntervalConverged", "bisect__util_8hpp.html#a63d480d679a9c6380f3c9373c419f962", null ],
     [ "storeNonEmptyIntervals", "bisect__util_8hpp.html#ae31db36470d0165a7358dad4853ff492", null ],
-    [ "subdivideActiveInterval", "bisect__util_8hpp.html#a3b925276e4de162f0bb068f90a0b298d", null ]
+    [ "subdivideActiveInterval", "bisect__util_8hpp.html#a3b925276e4de162f0bb068f90a0b298d", null ],
+    [ "subdivideActiveIntervalMulti", "bisect__util_8hpp.html#ad7ca33ef6ba189bd07de41dccce1ce61", null ]
 ];
\ No newline at end of file
