@@ -7,8 +7,10 @@ var classviennacl_1_1compressed__matrix =
     [ "compressed_matrix", "classviennacl_1_1compressed__matrix.html#a2649de8171ce97afc5e62afef862be0a", null ],
     [ "compressed_matrix", "classviennacl_1_1compressed__matrix.html#ad35fbeb8c4831787bca08e059dd3b799", null ],
     [ "compressed_matrix", "classviennacl_1_1compressed__matrix.html#a77547c4be30a4a6e69f78dca71ba71c9", null ],
+    [ "compressed_matrix", "classviennacl_1_1compressed__matrix.html#a7084e85e012f08fde31b72e09d59275d", null ],
     [ "blocks1", "classviennacl_1_1compressed__matrix.html#a805bdfab01b09101034b85e482e39701", null ],
     [ "clear", "classviennacl_1_1compressed__matrix.html#ae64788e11216b0d9fca181ce1d74fceb", null ],
+    [ "generate_row_block_information", "classviennacl_1_1compressed__matrix.html#ab5922a97b73b869fbeeb6a2fa40e3b06", null ],
     [ "handle", "classviennacl_1_1compressed__matrix.html#a87a0ad5f26983b1c2d24ee302d886562", null ],
     [ "handle", "classviennacl_1_1compressed__matrix.html#a1c173b6accbcd0267b287ed7ec040817", null ],
     [ "handle1", "classviennacl_1_1compressed__matrix.html#af71dec61a70e8df4f78a527aa989a106", null ],
@@ -21,7 +23,8 @@ var classviennacl_1_1compressed__matrix =
     [ "nnz", "classviennacl_1_1compressed__matrix.html#ae69ca21ded644fdd0c7a5168011b13ed", null ],
     [ "operator()", "classviennacl_1_1compressed__matrix.html#a05371d35109ab1ec7caa90339f859d5a", null ],
     [ "operator=", "classviennacl_1_1compressed__matrix.html#add81b190f9c85bd6fa6730be771f0979", null ],
-    [ "reserve", "classviennacl_1_1compressed__matrix.html#a20dcc89863badfb2e2c38826a9471f09", null ],
+    [ "operator=", "classviennacl_1_1compressed__matrix.html#ad0afce2e921c10b9e7b2234a6f513df6", null ],
+    [ "reserve", "classviennacl_1_1compressed__matrix.html#aba08ea5f9d1c12dff5da58e0dff7a6fe", null ],
     [ "resize", "classviennacl_1_1compressed__matrix.html#afcf49945a63836e1edfca536fcd191fb", null ],
     [ "set", "classviennacl_1_1compressed__matrix.html#a2846f5cd73ef4f03420e100a0acbcf04", null ],
     [ "size1", "classviennacl_1_1compressed__matrix.html#a463cf1739f9cdd387aa185cb574db183", null ],
