@@ -3,9 +3,8 @@ var classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_
     [ "amg_precond", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a29fa521d8d197ef48625fb3136a0b5c7", null ],
     [ "amg_precond", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a6753c39f2335407f6c15add355c79dbb", null ],
     [ "apply", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ad13c403b1d1d50a31ed3281120251295", null ],
-    [ "calc_complexity", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ab8be222572b4e437a055d9e55552771c", null ],
-    [ "init_apply", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a8d3aa0bc12003936bfd2f693226cd6d6", null ],
+    [ "levels", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ae9eee454451fa7192489007ff195bee0", null ],
     [ "setup", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ab19fc3bc1120992a264b2e4816cc99c4", null ],
-    [ "smooth_jacobi", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ac955df95f59ed8e7a2ebac9929292d31", null ],
-    [ "tag", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a7793021b79bae0db821ecc144ba60e1e", null ]
+    [ "size", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#ac343e007ddc01d12a893a2c9c9457e09", null ],
+    [ "tag", "classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a0daa8b3ccddfd195c4cf4c55601dcc3b", null ]
 ];
\ No newline at end of file
