@@ -9,5 +9,8 @@ var classviennacl_1_1matrix__slice =
     [ "value_type", "classviennacl_1_1matrix__slice.html#aa899c7446878be8a9200e741e4d57fe3", null ],
     [ "matrix_slice", "classviennacl_1_1matrix__slice.html#a75ffb6e46e07e6ffe2dbaef2d6bb7593", null ],
     [ "matrix_slice", "classviennacl_1_1matrix__slice.html#a957bc283ab8327eb93ce863c9a734f32", null ],
-    [ "matrix_slice", "classviennacl_1_1matrix__slice.html#a73ec32d37eb9c64e2e165abbb7e6d87b", null ]
+    [ "matrix_slice", "classviennacl_1_1matrix__slice.html#a73ec32d37eb9c64e2e165abbb7e6d87b", null ],
+    [ "operator=", "classviennacl_1_1matrix__slice.html#ae6b654d0c84a931eb3432a5a7c8cd106", null ],
+    [ "operator=", "classviennacl_1_1matrix__slice.html#a597f170c876f95c4c6bc3a019f3cedbd", null ],
+    [ "operator=", "classviennacl_1_1matrix__slice.html#aa8d028e30ba6472a9a632c49b9913e03", null ]
 ];
\ No newline at end of file
