@@ -11,5 +11,8 @@ var classviennacl_1_1vector__range =
     [ "value_type", "classviennacl_1_1vector__range.html#a2a89079fba59f4123d16acad2aaa8f64", null ],
     [ "vector_range", "classviennacl_1_1vector__range.html#a0e8ff91829f522c94dac80759ff20afe", null ],
     [ "vector_range", "classviennacl_1_1vector__range.html#a2d194137194a861b474ebd0129301aef", null ],
-    [ "vector_range", "classviennacl_1_1vector__range.html#a200a915e7a287327517a5d003221d0dd", null ]
+    [ "vector_range", "classviennacl_1_1vector__range.html#a200a915e7a287327517a5d003221d0dd", null ],
+    [ "operator=", "classviennacl_1_1vector__range.html#a39cec4566f99617fc96ec83d06e565f2", null ],
+    [ "operator=", "classviennacl_1_1vector__range.html#affbd05d21202d2b0c1e13830604f7a53", null ],
+    [ "operator=", "classviennacl_1_1vector__range.html#a600a1ff9fe47461c13e73bb4a6110479", null ]
 ];
\ No newline at end of file
