@@ -11,5 +11,8 @@ var classviennacl_1_1vector__slice =
     [ "value_type", "classviennacl_1_1vector__slice.html#abf5dba41dc42b45b25c3a65219531a1a", null ],
     [ "vector_slice", "classviennacl_1_1vector__slice.html#ae5af989804a68d57fe908eb4fab51f1f", null ],
     [ "vector_slice", "classviennacl_1_1vector__slice.html#a5064f6fda4c7af3707124b43869fd713", null ],
-    [ "vector_slice", "classviennacl_1_1vector__slice.html#aa3ecc1fd05c8b64434362ba5a87e29aa", null ]
+    [ "vector_slice", "classviennacl_1_1vector__slice.html#aa3ecc1fd05c8b64434362ba5a87e29aa", null ],
+    [ "operator=", "classviennacl_1_1vector__slice.html#abf9b80ffa3174cf31b36326b674623f0", null ],
+    [ "operator=", "classviennacl_1_1vector__slice.html#a7f339a7ed157665271cfcfdb42739571", null ],
+    [ "operator=", "classviennacl_1_1vector__slice.html#ae2b5d5b6103f57bb678b4da8b434c846", null ]
 ];
\ No newline at end of file
