@@ -5,5 +5,6 @@ var compressed__matrix_8hpp =
     [ "copy", "compressed__matrix_8hpp.html#afa72783b1449b3eef3fc2d5bab759871", null ],
     [ "copy", "compressed__matrix_8hpp.html#acee17c9f4826a3a7574c6d94fd1946c4", null ],
     [ "copy", "compressed__matrix_8hpp.html#aeae943c139b8f5faf2ca261c1a919e4d", null ],
-    [ "copy_impl", "compressed__matrix_8hpp.html#ae58906ac8a192c572283fbaf6347dda5", null ]
+    [ "copy_impl", "compressed__matrix_8hpp.html#ae58906ac8a192c572283fbaf6347dda5", null ],
+    [ "operator<<", "compressed__matrix_8hpp.html#a2e37765605f0b2728573419f0f6e691b", null ]
 ];
\ No newline at end of file
