@@ -14,6 +14,7 @@ var dir_95ddc301de7dff4151ad233d69616cc0 =
     [ "matrix_col_double.cpp", "matrix__col__double_8cpp.html", "matrix__col__double_8cpp" ],
     [ "matrix_col_float.cpp", "matrix__col__float_8cpp.html", "matrix__col__float_8cpp" ],
     [ "matrix_col_int.cpp", "matrix__col__int_8cpp.html", "matrix__col__int_8cpp" ],
+    [ "matrix_convert.cpp", "matrix__convert_8cpp.html", "matrix__convert_8cpp" ],
     [ "matrix_float_double.hpp", "matrix__float__double_8hpp.html", "matrix__float__double_8hpp" ],
     [ "matrix_int.hpp", "matrix__int_8hpp.html", "matrix__int_8hpp" ],
     [ "matrix_product_double.cpp", "matrix__product__double_8cpp.html", "matrix__product__double_8cpp" ],
@@ -27,7 +28,6 @@ var dir_95ddc301de7dff4151ad233d69616cc0 =
     [ "nmf.cpp", "tests_2src_2nmf_8cpp.html", "tests_2src_2nmf_8cpp" ],
     [ "qr_method.cpp", "tests_2src_2qr__method_8cpp.html", "tests_2src_2qr__method_8cpp" ],
     [ "qr_method_func.cpp", "qr__method__func_8cpp.html", "qr__method__func_8cpp" ],
-    [ "Random.hpp", "tests_2src_2_random_8hpp.html", "tests_2src_2_random_8hpp" ],
     [ "scalar.cpp", "scalar_8cpp.html", "scalar_8cpp" ],
     [ "scan.cpp", "scan_8cpp.html", "scan_8cpp" ],
     [ "scheduler_matrix.cpp", "scheduler__matrix_8cpp.html", "scheduler__matrix_8cpp" ],
@@ -37,10 +37,12 @@ var dir_95ddc301de7dff4151ad233d69616cc0 =
     [ "scheduler_vector.cpp", "scheduler__vector_8cpp.html", "scheduler__vector_8cpp" ],
     [ "self_assign.cpp", "self__assign_8cpp.html", "self__assign_8cpp" ],
     [ "sparse.cpp", "tests_2src_2sparse_8cpp.html", "tests_2src_2sparse_8cpp" ],
+    [ "sparse_prod.cpp", "sparse__prod_8cpp.html", "sparse__prod_8cpp" ],
     [ "spmdm.cpp", "spmdm_8cpp.html", "spmdm_8cpp" ],
     [ "structured-matrices.cpp", "tests_2src_2structured-matrices_8cpp.html", "tests_2src_2structured-matrices_8cpp" ],
     [ "svd.cpp", "svd_8cpp.html", "svd_8cpp" ],
     [ "tql.cpp", "tql_8cpp.html", "tql_8cpp" ],
+    [ "vector_convert.cpp", "vector__convert_8cpp.html", "vector__convert_8cpp" ],
     [ "vector_float_double.cpp", "vector__float__double_8cpp.html", "vector__float__double_8cpp" ],
     [ "vector_int.cpp", "vector__int_8cpp.html", "vector__int_8cpp" ],
     [ "vector_multi_inner_prod.cpp", "vector__multi__inner__prod_8cpp.html", "vector__multi__inner__prod_8cpp" ],
