@@ -15,9 +15,10 @@ var hierarchy =
     [ "viennacl::tools::detail::aux", "structviennacl_1_1tools_1_1detail_1_1aux.html", [
       [ "viennacl::tools::detail::auximpl< U, Deleter >", "structviennacl_1_1tools_1_1detail_1_1auximpl.html", null ]
     ] ],
+    [ "viennacl::linalg::opencl::kernels::avbv_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config.html", null ],
     [ "viennacl::ocl::backend< dummy >", "classviennacl_1_1ocl_1_1backend.html", null ],
-    [ "viennacl::basic_range< SizeT, DistanceT >", "classviennacl_1_1basic__range.html", null ],
-    [ "viennacl::basic_slice< SizeT, DistanceT >", "classviennacl_1_1basic__slice.html", null ],
+    [ "viennacl::basic_range< SizeType, DistanceType >", "classviennacl_1_1basic__range.html", null ],
+    [ "viennacl::basic_slice< SizeType, DistanceType >", "classviennacl_1_1basic__slice.html", null ],
     [ "viennacl::linalg::bicgstab_solver< VectorT >", "classviennacl_1_1linalg_1_1bicgstab__solver.html", null ],
     [ "viennacl::linalg::bicgstab_tag", "classviennacl_1_1linalg_1_1bicgstab__tag.html", null ],
     [ "viennacl::device_specific::binary_leaf", "classviennacl_1_1device__specific_1_1binary__leaf.html", [
@@ -62,14 +63,16 @@ var hierarchy =
     [ "viennacl::compressed_matrix< NumericT >", "classviennacl_1_1compressed__matrix.html", null ],
     [ "viennacl::compressed_matrix< NumericType >", "classviennacl_1_1compressed__matrix.html", null ],
     [ "viennacl::compressed_matrix< ScalarType, MAT_ALIGNMENT >", "classviennacl_1_1compressed__matrix.html", null ],
-    [ "viennacl::const_entry_proxy< NumericT >", "classviennacl_1_1const__entry__proxy.html", null ],
+    [ "viennacl::linalg::opencl::kernels::compressed_matrix_solve< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix__solve.html", null ],
+    [ "viennacl::const_entry_proxy< SCALARTYPE >", "classviennacl_1_1const__entry__proxy.html", null ],
     [ "viennacl::tools::CONST_REMOVER< T >", "structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html", null ],
     [ "viennacl::tools::const_sparse_matrix_adapted_iterator< NumericT, SizeT, is_iterator1, is_forward >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html", null ],
     [ "viennacl::tools::const_sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html", [
       [ "viennacl::tools::sparse_matrix_adapter< NumericT, SizeT >", "classviennacl_1_1tools_1_1sparse__matrix__adapter.html", null ]
     ] ],
+    [ "viennacl::const_vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1const__vector__iterator.html", null ],
     [ "viennacl::const_vector_iterator< NumericT, AlignmentV >", "classviennacl_1_1const__vector__iterator.html", [
-      [ "viennacl::vector_iterator< NumericT, AlignmentV >", "classviennacl_1_1vector__iterator.html", null ]
+      [ "viennacl::vector_iterator< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector__iterator.html", null ]
     ] ],
     [ "viennacl::context", "classviennacl_1_1context.html", null ],
     [ "viennacl::ocl::context", "classviennacl_1_1ocl_1_1context.html", null ],
@@ -98,7 +101,7 @@ var hierarchy =
     [ "viennacl::ell_matrix< double >", "classviennacl_1_1ell__matrix.html", null ],
     [ "viennacl::ell_matrix< float >", "classviennacl_1_1ell__matrix.html", null ],
     [ "viennacl::enable_if< b, T >", "structviennacl_1_1enable__if.html", null ],
-    [ "viennacl::entry_proxy< NumericT >", "classviennacl_1_1entry__proxy.html", null ],
+    [ "viennacl::entry_proxy< SCALARTYPE >", "classviennacl_1_1entry__proxy.html", null ],
     [ "viennacl::ocl::error_checker< T >", "structviennacl_1_1ocl_1_1error__checker.html", null ],
     [ "exception", null, [
       [ "viennacl::cuda_not_available_exception", "classviennacl_1_1cuda__not__available__exception.html", null ],
@@ -186,9 +189,9 @@ var hierarchy =
     [ "viennacl::ocl::handle< cl_program >", "classviennacl_1_1ocl_1_1handle.html", null ],
     [ "viennacl::device_specific::utils::handle_fun", "structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html", null ],
     [ "viennacl::ocl::handle_inc_dec_helper< OCL_TYPE >", "classviennacl_1_1ocl_1_1handle__inc__dec__helper.html", null ],
-    [ "viennacl::hankel_matrix< NumericT, AlignmentV >", "classviennacl_1_1hankel__matrix.html", null ],
+    [ "viennacl::hankel_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hankel__matrix.html", null ],
     [ "viennacl::linalg::opencl::kernels::hyb_matrix< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html", null ],
-    [ "viennacl::hyb_matrix< NumericT, AlignmentV >", "classviennacl_1_1hyb__matrix.html", null ],
+    [ "viennacl::hyb_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::hyb_matrix< double >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::hyb_matrix< float >", "classviennacl_1_1hyb__matrix.html", null ],
     [ "viennacl::linalg::ichol0_precond< MatrixT >", "classviennacl_1_1linalg_1_1ichol0__precond.html", null ],
@@ -302,7 +305,7 @@ var hierarchy =
       [ "viennacl::device_specific::mapped_vector_diag", "classviennacl_1_1device__specific_1_1mapped__vector__diag.html", null ]
     ] ],
     [ "viennacl::linalg::cuda::mat_mult_matrix_index< LayoutT >", "structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html", null ],
-    [ "viennacl::linalg::opencl::kernels::matrix< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
+    [ "viennacl::linalg::opencl::kernels::matrix< NumericT, F >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
     [ "viennacl::linalg::host_based::detail::matrix_array_wrapper< NumericT, LayoutT, is_transposed >", "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html", null ],
     [ "viennacl::matrix_base< NumericT, SizeT, DistanceT >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::matrix_base< char >", "classviennacl_1_1matrix__base.html", null ],
@@ -318,7 +321,7 @@ var hierarchy =
     ] ],
     [ "viennacl::matrix_base< NumericT >", "classviennacl_1_1matrix__base.html", [
       [ "viennacl::matrix< NumericT >", "classviennacl_1_1matrix.html", null ],
-      [ "viennacl::matrix< NumericT, F, AlignmentV >", "classviennacl_1_1matrix.html", null ]
+      [ "viennacl::matrix< SCALARTYPE, F, ALIGNMENT >", "classviennacl_1_1matrix.html", null ]
     ] ],
     [ "viennacl::matrix_base< short >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::matrix_base< unsigned char >", "classviennacl_1_1matrix__base.html", null ],
@@ -326,9 +329,9 @@ var hierarchy =
     [ "viennacl::matrix_base< unsigned long >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::matrix_base< unsigned short >", "classviennacl_1_1matrix__base.html", null ],
     [ "viennacl::linalg::opencl::kernels::matrix_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__convert.html", null ],
-    [ "viennacl::linalg::opencl::kernels::matrix_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
+    [ "viennacl::linalg::opencl::kernels::matrix_element< NumericT, F >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
     [ "viennacl::matrix_expression< LHS, RHS, OP >", "classviennacl_1_1matrix__expression.html", null ],
-    [ "viennacl::matrix_iterator< ROWCOL, MatrixT >", "classviennacl_1_1matrix__iterator.html", null ],
+    [ "viennacl::matrix_iterator< ROWCOL, MATRIXTYPE >", "classviennacl_1_1matrix__iterator.html", null ],
     [ "viennacl::tools::MATRIX_ITERATOR_INCREMENTER< ROWCOL, MATRIXTYPE >", "structviennacl_1_1tools_1_1_m_a_t_r_i_x___i_t_e_r_a_t_o_r___i_n_c_r_e_m_e_n_t_e_r.html", null ],
     [ "viennacl::linalg::opencl::kernels::matrix_legacy< NumericT, LayoutT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html", null ],
     [ "matrix_maker< UBlasType, F >", "structmatrix__maker.html", null ],
@@ -430,11 +433,7 @@ var hierarchy =
     ] ],
     [ "viennacl::ocl::packed_cl_uint", "structviennacl_1_1ocl_1_1packed__cl__uint.html", null ],
     [ "viennacl::device_specific::template_base::parameters_type", "structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html", [
-      [ "viennacl::device_specific::matrix_axpy_parameters_type", "classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html", null ],
-      [ "viennacl::device_specific::matrix_product_parameters", "structviennacl_1_1device__specific_1_1matrix__product__parameters.html", null ],
-      [ "viennacl::device_specific::reduction_parameters", "structviennacl_1_1device__specific_1_1reduction__parameters.html", null ],
-      [ "viennacl::device_specific::row_wise_reduction_parameters", "structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html", null ],
-      [ "viennacl::device_specific::vector_axpy_parameters", "classviennacl_1_1device__specific_1_1vector__axpy__parameters.html", null ]
+      [ "viennacl::device_specific::matrix_product_parameters", "structviennacl_1_1device__specific_1_1matrix__product__parameters.html", null ]
     ] ],
     [ "viennacl::ocl::platform", "classviennacl_1_1ocl_1_1platform.html", null ],
     [ "viennacl::linalg::power_iter_tag", "classviennacl_1_1linalg_1_1power__iter__tag.html", null ],
@@ -448,7 +447,6 @@ var hierarchy =
     [ "viennacl::linalg::row_scaling< MatrixType, is_viennacl >", "classviennacl_1_1linalg_1_1row__scaling.html", null ],
     [ "viennacl::linalg::row_scaling< MatrixType, true >", "classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html", null ],
     [ "viennacl::linalg::row_scaling_tag", "classviennacl_1_1linalg_1_1row__scaling__tag.html", null ],
-    [ "viennacl::linalg::opencl::kernels::row_wise_reduction< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html", null ],
     [ "runtime_error", null, [
       [ "viennacl::backend::cuda::cuda_exception", "classviennacl_1_1backend_1_1cuda_1_1cuda__exception.html", null ],
       [ "viennacl::linalg::amg_coarse_problem_too_large_exception", "classviennacl_1_1linalg_1_1amg__coarse__problem__too__large__exception.html", null ],
@@ -458,8 +456,8 @@ var hierarchy =
       [ "viennacl::unknown_norm_exception", "classviennacl_1_1unknown__norm__exception.html", null ],
       [ "viennacl::zero_on_diagonal_exception", "classviennacl_1_1zero__on__diagonal__exception.html", null ]
     ] ],
+    [ "viennacl::scalar< TYPE >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::linalg::opencl::kernels::scalar< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html", null ],
-    [ "viennacl::scalar< NumericT >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::scalar< char >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::scalar< double >", "classviennacl_1_1scalar.html", null ],
     [ "viennacl::scalar< float >", "classviennacl_1_1scalar.html", null ],
@@ -488,8 +486,8 @@ var hierarchy =
     [ "viennacl::device_specific::utils::size2_fun", "structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html", null ],
     [ "viennacl::device_specific::utils::size_fun", "structviennacl_1_1device__specific_1_1utils_1_1size__fun.html", null ],
     [ "viennacl::result_of::size_type< T >", "structviennacl_1_1result__of_1_1size__type.html", null ],
-    [ "viennacl::linalg::opencl::kernels::sliced_ell_matrix< NumericT, IndexT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html", null ],
     [ "viennacl::sliced_ell_matrix< ScalarT, IndexT >", "classviennacl_1_1sliced__ell__matrix.html", null ],
+    [ "viennacl::linalg::opencl::kernels::sliced_ell_matrix< NumericT, IndexT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html", null ],
     [ "viennacl::linalg::opencl::kernels::sliced_ell_matrix< NumericT, unsigned int >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html", null ],
     [ "viennacl::linalg::opencl::kernels::spai< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html", null ],
     [ "viennacl::linalg::spai_precond< MatrixType >", "classviennacl_1_1linalg_1_1spai__precond.html", null ],
@@ -499,6 +497,8 @@ var hierarchy =
     [ "viennacl::linalg::detail::spai::sparse_vector< NumericT >", "classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html", null ],
     [ "viennacl::linalg::host_based::spgemm_output_write_disabled", "structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__disabled.html", null ],
     [ "viennacl::linalg::host_based::spgemm_output_write_enabled", "structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__enabled.html", null ],
+    [ "viennacl::linalg::cuda::detail::spmv_alpha_beta", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__alpha__beta.html", null ],
+    [ "viennacl::linalg::cuda::detail::spmv_pure", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__pure.html", null ],
     [ "viennacl::device_specific::utils::start1_fun", "structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html", null ],
     [ "viennacl::device_specific::utils::start2_fun", "structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html", null ],
     [ "viennacl::scheduler::statement", "classviennacl_1_1scheduler_1_1statement.html", null ],
@@ -520,25 +520,14 @@ var hierarchy =
     [ "viennacl::tag_ublas", "structviennacl_1_1tag__ublas.html", null ],
     [ "viennacl::tag_viennacl", "structviennacl_1_1tag__viennacl.html", null ],
     [ "viennacl::device_specific::template_base", "classviennacl_1_1device__specific_1_1template__base.html", [
-      [ "viennacl::device_specific::template_base_impl< matrix_axpy_template, matrix_axpy_parameters_type >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
-        [ "viennacl::device_specific::matrix_axpy_template", "classviennacl_1_1device__specific_1_1matrix__axpy__template.html", null ]
-      ] ],
       [ "viennacl::device_specific::template_base_impl< matrix_product_template, matrix_product_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
         [ "viennacl::device_specific::matrix_product_template", "classviennacl_1_1device__specific_1_1matrix__product__template.html", null ]
       ] ],
-      [ "viennacl::device_specific::template_base_impl< reduction_template, reduction_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
-        [ "viennacl::device_specific::reduction_template", "classviennacl_1_1device__specific_1_1reduction__template.html", null ]
-      ] ],
-      [ "viennacl::device_specific::template_base_impl< row_wise_reduction_template, row_wise_reduction_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
-        [ "viennacl::device_specific::row_wise_reduction_template", "classviennacl_1_1device__specific_1_1row__wise__reduction__template.html", null ]
-      ] ],
-      [ "viennacl::device_specific::template_base_impl< vector_axpy_template, vector_axpy_parameters >", "classviennacl_1_1device__specific_1_1template__base__impl.html", [
-        [ "viennacl::device_specific::vector_axpy_template", "classviennacl_1_1device__specific_1_1vector__axpy__template.html", null ]
-      ] ],
       [ "viennacl::device_specific::template_base_impl< TemplateType, ParametersType >", "classviennacl_1_1device__specific_1_1template__base__impl.html", null ]
     ] ],
     [ "testData", "structtest_data.html", null ],
     [ "viennacl::tools::timer", "classviennacl_1_1tools_1_1timer.html", null ],
+    [ "viennacl::toeplitz_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1toeplitz__matrix.html", null ],
     [ "viennacl::toeplitz_matrix< NumericT, AlignmentV >", "classviennacl_1_1toeplitz__matrix.html", null ],
     [ "viennacl::device_specific::tree_parsing::traversal_functor", "classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html", [
       [ "viennacl::device_specific::tree_parsing::evaluate_expression_traversal", "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html", null ],
@@ -570,8 +559,8 @@ var hierarchy =
     [ "viennacl::linalg::unit_upper_tag", "structviennacl_1_1linalg_1_1unit__upper__tag.html", null ],
     [ "viennacl::linalg::upper_tag", "structviennacl_1_1linalg_1_1upper__tag.html", null ],
     [ "viennacl::result_of::value_type< T >", "structviennacl_1_1result__of_1_1value__type.html", null ],
-    [ "viennacl::vandermonde_matrix< NumericT, AlignmentV >", "classviennacl_1_1vandermonde__matrix.html", null ],
-    [ "viennacl::linalg::opencl::kernels::vector< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
+    [ "viennacl::vandermonde_matrix< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vandermonde__matrix.html", null ],
+    [ "viennacl::linalg::opencl::kernels::vector< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
     [ "viennacl::linalg::host_based::detail::vector_array_wrapper< NumericT >", "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html", null ],
     [ "viennacl::vector_base< NumericT, SizeT, DistanceT >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< char >", "classviennacl_1_1vector__base.html", null ],
@@ -581,19 +570,15 @@ var hierarchy =
     [ "viennacl::vector_base< long >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< NumericT >", "classviennacl_1_1vector__base.html", [
       [ "viennacl::vector< NumericT >", "classviennacl_1_1vector.html", null ],
-      [ "viennacl::vector< NumericT, AlignmentV >", "classviennacl_1_1vector.html", null ]
-    ] ],
-    [ "viennacl::vector_base< NumericType >", "classviennacl_1_1vector__base.html", [
-      [ "viennacl::vector< NumericType >", "classviennacl_1_1vector.html", null ]
-    ] ],
-    [ "viennacl::vector_base< ScalarType >", "classviennacl_1_1vector__base.html", [
-      [ "viennacl::vector< ScalarType >", "classviennacl_1_1vector.html", null ]
+      [ "viennacl::vector< NumericT, AlignmentV >", "classviennacl_1_1vector.html", null ],
+      [ "viennacl::vector< NumericType >", "classviennacl_1_1vector.html", null ],
+      [ "viennacl::vector< ScalarType >", "classviennacl_1_1vector.html", null ],
+      [ "viennacl::vector< unsigned int >", "classviennacl_1_1vector.html", null ],
+      [ "viennacl::vector< SCALARTYPE, ALIGNMENT >", "classviennacl_1_1vector.html", null ]
     ] ],
     [ "viennacl::vector_base< short >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< unsigned char >", "classviennacl_1_1vector__base.html", null ],
-    [ "viennacl::vector_base< unsigned int >", "classviennacl_1_1vector__base.html", [
-      [ "viennacl::vector< unsigned int >", "classviennacl_1_1vector.html", null ]
-    ] ],
+    [ "viennacl::vector_base< unsigned int >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< unsigned long >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< unsigned short >", "classviennacl_1_1vector__base.html", null ],
     [ "viennacl::vector_base< VectorType::cpu_value_type >", "classviennacl_1_1vector__base.html", [
@@ -605,7 +590,7 @@ var hierarchy =
     [ "viennacl::linalg::opencl::kernels::vector_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__convert.html", null ],
     [ "viennacl::linalg::opencl::kernels::vector_element< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html", null ],
     [ "viennacl::vector_expression< LHS, RHS, OP >", "classviennacl_1_1vector__expression.html", null ],
-    [ "viennacl::linalg::opencl::kernels::vector_multi_inner_prod< NumericT >", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ],
+    [ "viennacl::linalg::opencl::kernels::vector_multi_inner_prod< NumericT >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ],
     [ "vector_proxy< NumericT >", "classvector__proxy.html", null ],
     [ "viennacl::vector_tuple< ScalarT >", "classviennacl_1_1vector__tuple.html", null ],
     [ "ViennaCLBackend_impl", "struct_vienna_c_l_backend__impl.html", null ],
