@@ -1,9 +1,10 @@
 var ilut_8hpp =
 [
     [ "ilut_tag", "classviennacl_1_1linalg_1_1ilut__tag.html", "classviennacl_1_1linalg_1_1ilut__tag" ],
+    [ "ilut_sparse_vector", "structviennacl_1_1linalg_1_1detail_1_1ilut__sparse__vector.html", "structviennacl_1_1linalg_1_1detail_1_1ilut__sparse__vector" ],
     [ "ilut_precond", "classviennacl_1_1linalg_1_1ilut__precond.html", "classviennacl_1_1linalg_1_1ilut__precond" ],
     [ "ilut_precond< viennacl::compressed_matrix< NumericT, AlignmentV > >", "classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html", "classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4" ],
-    [ "precondition", "ilut_8hpp.html#a39ed99a266c4ca46f851316297ce9bf6", null ],
-    [ "setup_w", "ilut_8hpp.html#a79537640cb9e9f4dd0be0024143860b1", null ],
-    [ "setup_w", "ilut_8hpp.html#a18218af41096d0913c54322e022d780d", null ]
+    [ "insert_with_value_sort", "ilut_8hpp.html#a05d31e5838d1a6290f1394eff275cdfc", null ],
+    [ "merge_subtract_sparse_rows", "ilut_8hpp.html#ad7ed27d8821975f07a4cbc59954714df", null ],
+    [ "precondition", "ilut_8hpp.html#aabecdfbc7ea786184aa5044db47a14b7", null ]
 ];
\ No newline at end of file
