@@ -1,8 +1,11 @@
 var iterative_8hpp =
 [
     [ "iterative", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1iterative.html", null ],
+    [ "generate_compressed_matrix_pipelined_bicgstab_blocked_prod", "iterative_8hpp.html#aa8f1855a492b4c9d5e1a93a15c864dd1", null ],
     [ "generate_compressed_matrix_pipelined_bicgstab_prod", "iterative_8hpp.html#a5bb161ac1be172ac646e184400660688", null ],
+    [ "generate_compressed_matrix_pipelined_cg_blocked_prod", "iterative_8hpp.html#a255a119a62babb6e859c353a26b41f9f", null ],
     [ "generate_compressed_matrix_pipelined_cg_prod", "iterative_8hpp.html#afca54a4582b99a74ede8298e3d8f52b7", null ],
+    [ "generate_compressed_matrix_pipelined_gmres_blocked_prod", "iterative_8hpp.html#af4d565751075233155ecf6808bdb2e5b", null ],
     [ "generate_compressed_matrix_pipelined_gmres_prod", "iterative_8hpp.html#a656464442cd911a5f7ffc95ff1fdede6", null ],
     [ "generate_coordinate_matrix_pipelined_bicgstab_prod", "iterative_8hpp.html#a308bdd25097efe84bb3d5f185d6b5a00", null ],
     [ "generate_coordinate_matrix_pipelined_cg_prod", "iterative_8hpp.html#a6b13382369ce1d8e21c501626028b531", null ],
