@@ -1,19 +1,21 @@
 var linalg_2opencl_2kernels_2matrix_8hpp =
 [
     [ "ambm_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config" ],
-    [ "matrix", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
-    [ "matrix_element", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
-    [ "row_wise_reduction", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html", null ],
+    [ "matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
     [ "matrix_prod", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html", null ],
     [ "matrix_legacy", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html", null ],
     [ "matrix_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__convert.html", null ],
-    [ "VIENNACL_ADD_BINARY", "linalg_2opencl_2kernels_2matrix_8hpp.html#a67f9921aa086b1cab31a7ba49c722f84", null ],
-    [ "VIENNACL_ADD_UNARY", "linalg_2opencl_2kernels_2matrix_8hpp.html#ae7e49843c99a526b2605212454475394", null ],
     [ "ambm_scalar_type", "linalg_2opencl_2kernels_2matrix_8hpp.html#a0cafaf477353c066293d8e29ab6f80a6", [
       [ "VIENNACL_AMBM_NONE", "linalg_2opencl_2kernels_2matrix_8hpp.html#a0cafaf477353c066293d8e29ab6f80a6ab710c6de3ce0312795b926a67b665423", null ],
       [ "VIENNACL_AMBM_CPU", "linalg_2opencl_2kernels_2matrix_8hpp.html#a0cafaf477353c066293d8e29ab6f80a6a107e77961e63ef2a360a1c471c43599d", null ],
       [ "VIENNACL_AMBM_GPU", "linalg_2opencl_2kernels_2matrix_8hpp.html#a0cafaf477353c066293d8e29ab6f80a6a558544ba3607a52bd5953754234536b2", null ]
     ] ],
+    [ "generate_ambm", "linalg_2opencl_2kernels_2matrix_8hpp.html#a999dcb113412656ad0a2d19967e974b6", null ],
+    [ "generate_ambm_impl", "linalg_2opencl_2kernels_2matrix_8hpp.html#a60310392b8a56832ef4f54d7c3d550ce", null ],
+    [ "generate_ambm_impl2", "linalg_2opencl_2kernels_2matrix_8hpp.html#af27e47a0db20c2cac8acae98e0d4c4b0", null ],
+    [ "generate_assign_cpu", "linalg_2opencl_2kernels_2matrix_8hpp.html#a0590d9444d835b45e5973678c7a2ef9f", null ],
+    [ "generate_diagonal_assign_cpu", "linalg_2opencl_2kernels_2matrix_8hpp.html#aa49a6a2e4a33c8bd541154ab8ff7dd0f", null ],
+    [ "generate_element_op", "linalg_2opencl_2kernels_2matrix_8hpp.html#a4ec1fb61e6483c4f2ed90d3d4f428a03", null ],
     [ "generate_fft", "linalg_2opencl_2kernels_2matrix_8hpp.html#a121d42da1cf5ca497b8bab913ad98461", null ],
     [ "generate_lu", "linalg_2opencl_2kernels_2matrix_8hpp.html#aa58aa171ea10f5b8960efca0a224ec13", null ],
     [ "generate_matrix_convert", "linalg_2opencl_2kernels_2matrix_8hpp.html#ad618f7d6b76988567b2a7e273ee99a7c", null ],
@@ -21,7 +23,9 @@ var linalg_2opencl_2kernels_2matrix_8hpp =
     [ "generate_matrix_convert_row", "linalg_2opencl_2kernels_2matrix_8hpp.html#aaba63777bdb389846a41fcfe567f9a9a", null ],
     [ "generate_scaled_rank1_update", "linalg_2opencl_2kernels_2matrix_8hpp.html#a5d7e2837d1fd4a882ed9065191b83eff", null ],
     [ "generate_trans_kernel", "linalg_2opencl_2kernels_2matrix_8hpp.html#afbe318b322533801f24a2d3733383a0b", null ],
+    [ "generate_trans_vec_mul", "linalg_2opencl_2kernels_2matrix_8hpp.html#ac0b599c80230c8e9f015d27a02e24375", null ],
     [ "generate_triangular_substitute_inplace", "linalg_2opencl_2kernels_2matrix_8hpp.html#ad9add3d030362be82ad6b885b02cfa47", null ],
+    [ "generate_vec_mul", "linalg_2opencl_2kernels_2matrix_8hpp.html#aee79f1279392f32a429f443a4187a3e3", null ],
     [ "type_to_string", "linalg_2opencl_2kernels_2matrix_8hpp.html#a464ca905eab3e302694bc23c1edd45e1", null ],
     [ "type_to_string", "linalg_2opencl_2kernels_2matrix_8hpp.html#ab0e3d134d9fa6079a42fc3f8cd314010", null ]
 ];
\ No newline at end of file
