@@ -1,5 +1,7 @@
 var namespaceviennacl_1_1linalg_1_1cuda_1_1detail =
 [
+    [ "spmv_alpha_beta", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__alpha__beta.html", null ],
+    [ "spmv_pure", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__pure.html", null ],
     [ "type_to_type2", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2.html", null ],
     [ "type_to_type2< double >", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4" ],
     [ "type_to_type2< float >", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html", "structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4" ]
