@@ -3,11 +3,13 @@ var namespaceviennacl_1_1linalg_1_1opencl_1_1detail =
     [ "block_inplace_solve", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a144fd7dc25be2029356c24f07f281edc", null ],
     [ "block_inplace_solve", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a720d4cb00c0c08602f62608ecaa9a835", null ],
     [ "current_device", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a1ed4b5fefdb8188be7ba2909a66bc653", null ],
+    [ "element_kernel_for_matrix", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#ae63e075deb555fd0ef79218d5a913d9a", null ],
     [ "get_option_for_solver_tag", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a64f1e9f297e72762dd45b29214ae71fd", null ],
     [ "get_option_for_solver_tag", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a9d003d00f2cab87b7bc7ebdd472bf1f2", null ],
     [ "get_option_for_solver_tag", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a78416d62615725d511d7cdbd74e3235b", null ],
     [ "get_option_for_solver_tag", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a3b425cc7c38c19cc16f34eb0c349a3e2", null ],
     [ "inplace_solve_impl", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#ac213c5f1e1f1b9d18e7b94acb9e17279", null ],
+    [ "kernel_for_matrix", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#acb933cf08a45fa63d016111dfafa4791", null ],
     [ "legacy_kernel_for_matrix", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#aa42a34c8e153495ac317c599824123d4", null ],
     [ "level_scheduling_substitute", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#ad939e77692cf9b3c5746b11ba9ff024c", null ],
     [ "make_layout", "namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html#a66ecf8efa0b41147e85710db81cc9e37", null ],
