@@ -3,31 +3,32 @@ var namespaceviennacl_1_1linalg_1_1opencl_1_1kernels =
     [ "ambm_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config" ],
     [ "amg", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1amg.html", null ],
     [ "asbs_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config" ],
+    [ "avbv_config", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config.html", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config" ],
     [ "bisect_kernel", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1bisect__kernel.html", null ],
     [ "compressed_compressed_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html", null ],
     [ "compressed_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html", null ],
+    [ "compressed_matrix_solve", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix__solve.html", null ],
     [ "coordinate_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html", null ],
     [ "ell_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ell__matrix.html", null ],
     [ "fft", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1fft.html", null ],
     [ "hyb_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html", null ],
     [ "ilu", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ilu.html", null ],
     [ "iterative", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1iterative.html", null ],
-    [ "matrix", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
+    [ "matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html", null ],
     [ "matrix_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__convert.html", null ],
     [ "matrix_element", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html", null ],
     [ "matrix_legacy", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html", null ],
     [ "matrix_prod", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html", null ],
     [ "matrix_solve", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__solve.html", null ],
     [ "nmf", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1nmf.html", null ],
-    [ "row_wise_reduction", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html", null ],
     [ "scalar", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html", null ],
     [ "scan", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scan.html", null ],
     [ "sliced_ell_matrix", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html", null ],
     [ "sliced_ell_matrix< NumericT, unsigned int >", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html", null ],
     [ "spai", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html", null ],
     [ "svd", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html", null ],
-    [ "vector", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
+    [ "vector", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html", null ],
     [ "vector_convert", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__convert.html", null ],
     [ "vector_element", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html", null ],
-    [ "vector_multi_inner_prod", "classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ]
+    [ "vector_multi_inner_prod", "structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html", null ]
 ];
\ No newline at end of file
