@@ -50,32 +50,31 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "accelerator_2fallback_8hpp.html",
-"blas2__opencl_8cpp.html#ad5aba7b0e90e197d4732066e81fa81d1",
-"classviennacl_1_1const__entry__proxy.html#abc1b268a517bbb435434b9bf54f2313a",
-"classviennacl_1_1ell__matrix.html#a8575f900add9d7ff93f73063ac90b4b9",
-"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html#a7dfd62f90e89c9c44817742853f9bfdb",
-"classviennacl_1_1linalg_1_1row__scaling.html#a772edd12410c3d582f4ad4f3d1bcd110",
-"classviennacl_1_1ocl_1_1device.html#a9efdfafd0819090844b28a123510283c",
-"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html#a670faef4da7eb44516eaf0502e0da52e",
-"classviennacl_1_1vector__base.html#aa2a13cb2712dc5dd36eea81c7549a278",
-"cuda_2iterative__operations_8hpp.html#a704ee2a70cf3563e3928fec38ac16bc0",
-"custom-kernels_8cpp_source.html",
-"direct__solve_8hpp.html#a87b19fc27005f6e13a9ee981965a5e97",
-"forwards_8h.html#ab3331c10c42bdec311e4c6b8665b01ac",
-"globals_func_s.html",
-"host__based_2vector__operations_8hpp.html#a2fff34b2cb787d5c2ae89f59a93cfde8",
-"linalg_2opencl_2common_8hpp.html#a3a8f0ed5e591a8db7b6f58d6dcb0d876",
-"matrix_8hpp.html#a97d5a2c7b8514856ee97a68dee279ac2",
-"matrix__operations__row_8hpp.html#af2b44cf9690bfb3f9e5dff5b26b607e9",
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html",
-"opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528",
-"row__scaling_8hpp.html",
-"small__matrix_8hpp_source.html",
-"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html",
-"structviennacl_1_1op__fmod.html",
-"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__fabs_01_4_01_4.html#a83900c06dec61651be8bb974185c1f13a71f4169164f5bd32365e1f9170ac279b",
-"tests_2src_2sparse_8cpp.html#a3d8742cd384cb6e7893805a6c54791b2",
-"vector__operations_8hpp.html#ad648cd691bb8fa8358f552d00bce2946"
+"cg_8hpp.html",
+"classviennacl_1_1device__specific_1_1binary__leaf.html#adb5951a50055382b42d27d988e4f30a6",
+"classviennacl_1_1implicit__matrix__base.html#af9f3f82b9615ef64a728a3c8c9a1e618",
+"classviennacl_1_1linalg_1_1jacobi__precond.html",
+"classviennacl_1_1ocl_1_1context.html#a9094ac71f0cdf80df698c0c84ebb483d",
+"classviennacl_1_1scalar.html#a1348460f9568c82b03e702f0f462b103",
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a89e8ccbf2a88b5201522857f2ddbf4c4",
+"cpu__ram_8hpp.html#a307263f9deed5ce983ae50ebda5c1e0b",
+"cuda_2sparse__matrix__operations_8hpp.html#a79333b0dc10fc077353e4e619e8c3125",
+"device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9a5bac3e336ba87e7a3311dee3d2129db5",
+"execute__vector__dispatcher_8hpp.html#a6512297240413f8cb40fd0e7341f2319",
+"functions_w.html",
+"host__based_2iterative__operations_8hpp.html#af497e625d846f3e219b9467b82cda386",
+"least-squares_8cpp.html#a5bd8cdcf93dfca2b1a3e30bff4607bde",
+"manual-additional-algorithms.html#manual-additional-algorithms-preconditioners",
+"matrix__operations_8hpp.html#a34c93371a5e45fe498bf1dc4dd475497",
+"maxmin_8hpp.html#acae51ad7f1972ca14eeedc59f08b12b8",
+"ocl_2context_8hpp_source.html",
+"opencl_2sparse__matrix__operations_8hpp.html#a83199d78f9adbf3b16034fc8a093ed38",
+"scheduler_2forwards_8h.html#a32152bde4bf97c79e26300a441099a35a63ee858031e1985a022e8cc84d19ea5d",
+"sparse__prod_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4",
+"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html#a30b3642c00ccbf41e80ddbe1c8857112",
+"structviennacl_1_1op__row.html",
+"tests_2src_2qr__method_8cpp.html#ae93adcba98f8802432c4edc9a4ab96cd",
+"vector__operations_8hpp.html#a7f1b00757223e6feecf70a8657a9f096"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
