@@ -1,19 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"block__matrix_8hpp_source.html":[7,0,3,4,1,3,0],
-"block__vector_8hpp.html":[7,0,3,4,1,3,1],
-"block__vector_8hpp_source.html":[7,0,3,4,1,3,1],
-"cedar_8hpp.html":[7,0,3,2,0,0,2,0,0,0],
-"cedar_8hpp.html#a01126424ff7e61a7189de2b5c7647b02":[7,0,3,2,0,0,2,0,0,0,3],
-"cedar_8hpp.html#a0a80897a8dd6497381a5cc6a507ac4e4":[7,0,3,2,0,0,2,0,0,0,8],
-"cedar_8hpp.html#a5f971c5bb626d391d40dae4c3ce59242":[7,0,3,2,0,0,2,0,0,0,1],
-"cedar_8hpp.html#a76904af1d9184c9ebf988314b47341e6":[7,0,3,2,0,0,2,0,0,0,7],
-"cedar_8hpp.html#a97f81b34a2a6a1162c11d29f1c0457c0":[7,0,3,2,0,0,2,0,0,0,5],
-"cedar_8hpp.html#abc7f5a591b5c9f472eda3317b2995e24":[7,0,3,2,0,0,2,0,0,0,4],
-"cedar_8hpp.html#ade76e367790c3595aaff57652b6c43f6":[7,0,3,2,0,0,2,0,0,0,2],
-"cedar_8hpp.html#ae25ab68d6138e9eb004d90f7ee7348b7":[7,0,3,2,0,0,2,0,0,0,6],
-"cedar_8hpp.html#ae4ed13a8aedb8d5e9b7b82005804d3d1":[7,0,3,2,0,0,2,0,0,0,0],
-"cedar_8hpp_source.html":[7,0,3,2,0,0,2,0,0,0],
 "cg_8hpp.html":[7,0,3,4,9],
 "cg_8hpp.html#a0679942882efd21c540fac8e78a6d56a":[7,0,3,4,9,7],
 "cg_8hpp.html#a2fad8cb9d4b354019644518915c7f54f":[7,0,3,4,9,5],
@@ -107,34 +93,34 @@ var NAVTREEINDEX1 =
 "classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html#aede2f174e7cde9c3a7e6ace5ff35e47e":[6,0,0,0,6,2],
 "classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html#af69b0bbba6bba94e1bad0b0059913e7f":[6,0,0,0,6,6],
 "classviennacl_1_1basic__range.html":[6,0,0,11],
-"classviennacl_1_1basic__range.html#a086579df41cd54835531c7baabf49c00":[6,0,0,11,10],
-"classviennacl_1_1basic__range.html#a0d5f11c0c300a33e8ae4181ebbabeb01":[6,0,0,11,6],
-"classviennacl_1_1basic__range.html#a666628fe9b604dc566fa7eb0123f8ddd":[6,0,0,11,7],
-"classviennacl_1_1basic__range.html#a8708b1743bca7c539a81be8099f49f90":[6,0,0,11,8],
-"classviennacl_1_1basic__range.html#a98fe8293684a30f75d6aacad7ec13bde":[6,0,0,11,2],
-"classviennacl_1_1basic__range.html#aa34b76f6efe362415edb407937e0cba4":[6,0,0,11,0],
-"classviennacl_1_1basic__range.html#abb9929b7929b0741e17b3cfe8b928079":[6,0,0,11,1],
-"classviennacl_1_1basic__range.html#abd197f659f5498ee5e3fb4977664f057":[6,0,0,11,12],
-"classviennacl_1_1basic__range.html#ac90a11d76a2b1e29da3cd0633d442324":[6,0,0,11,9],
-"classviennacl_1_1basic__range.html#ad012ab1496aae10765aa38a79b927d75":[6,0,0,11,3],
-"classviennacl_1_1basic__range.html#ae213fd034e4db9cd0ce570c1be075efc":[6,0,0,11,5],
-"classviennacl_1_1basic__range.html#aea4fe4dd7cdf834b8f40675c3ad7e0e6":[6,0,0,11,4],
-"classviennacl_1_1basic__range.html#af2ae0723d25249de4e6ac3398c532849":[6,0,0,11,11],
+"classviennacl_1_1basic__range.html#a19cc82c72c48f3a228040975e0277639":[6,0,0,11,7],
+"classviennacl_1_1basic__range.html#a23b0af93d74104dfbe4158b94ded751b":[6,0,0,11,6],
+"classviennacl_1_1basic__range.html#a2541840a74de59d8392c2ef2f5e14688":[6,0,0,11,8],
+"classviennacl_1_1basic__range.html#a4120d60389efc52cb5235dd796897aa3":[6,0,0,11,4],
+"classviennacl_1_1basic__range.html#a76e130f45289f502bb75637391b6ebaf":[6,0,0,11,11],
+"classviennacl_1_1basic__range.html#a7862bf679f6f3d74ac0449b4fcb81edd":[6,0,0,11,9],
+"classviennacl_1_1basic__range.html#a96bc2ca82dc308bfe484e5c93213f925":[6,0,0,11,0],
+"classviennacl_1_1basic__range.html#aa6e54d5a8c0d51d4310bb57f98bec3eb":[6,0,0,11,1],
+"classviennacl_1_1basic__range.html#ab5e949b2f3c1495eb423f568623ec862":[6,0,0,11,12],
+"classviennacl_1_1basic__range.html#abf9f70746fdf670cf1f134ae74db9c02":[6,0,0,11,10],
+"classviennacl_1_1basic__range.html#af055791c1672b45ca992d0fd6045d5d5":[6,0,0,11,3],
+"classviennacl_1_1basic__range.html#af96be8225f4918a7f2bd85ef9d739210":[6,0,0,11,5],
+"classviennacl_1_1basic__range.html#af98fd6cd691b6cdc6fe92b66e72ec581":[6,0,0,11,2],
 "classviennacl_1_1basic__slice.html":[6,0,0,12],
-"classviennacl_1_1basic__slice.html#a09d5a73b2d94035ac6171c85e76f9a2a":[6,0,0,12,5],
-"classviennacl_1_1basic__slice.html#a107d2a257efd86a3496a2095b14d390c":[6,0,0,12,6],
-"classviennacl_1_1basic__slice.html#a1f3bee006aa6206cd5c2d465bc1ec7b9":[6,0,0,12,0],
-"classviennacl_1_1basic__slice.html#a6c0632edd54727c588037d4f01d4a7f5":[6,0,0,12,3],
-"classviennacl_1_1basic__slice.html#a7eccf03bc2a7d3ecb61df27f4c1230a9":[6,0,0,12,13],
-"classviennacl_1_1basic__slice.html#a8a81ffae54298af31d0ee4524e96ce6c":[6,0,0,12,4],
-"classviennacl_1_1basic__slice.html#aa82399e34bba223d9873613e05e93e2d":[6,0,0,12,10],
-"classviennacl_1_1basic__slice.html#ab03350f92555c7d4278f039347f7c200":[6,0,0,12,1],
-"classviennacl_1_1basic__slice.html#ad0a964026f2456cba267c2e577f8f4b3":[6,0,0,12,12],
-"classviennacl_1_1basic__slice.html#ad68a4709ed2046d3c1fabb2a35a77c8e":[6,0,0,12,9],
-"classviennacl_1_1basic__slice.html#ade9eed27085e548ae36b0872cf7502bf":[6,0,0,12,2],
-"classviennacl_1_1basic__slice.html#ae4fe7a9208a59756c8214734835897f7":[6,0,0,12,11],
-"classviennacl_1_1basic__slice.html#aeb7a706834740984fa46aec18c0265c8":[6,0,0,12,8],
-"classviennacl_1_1basic__slice.html#afd7e1263cd81282515c203ae039adf6b":[6,0,0,12,7],
+"classviennacl_1_1basic__slice.html#a0b6d101bae091dba51d3345ecd860855":[6,0,0,12,0],
+"classviennacl_1_1basic__slice.html#a2a6813112d126c662827a988963f2078":[6,0,0,12,10],
+"classviennacl_1_1basic__slice.html#a38cc42b6a33d1d94257d6d2a14348412":[6,0,0,12,7],
+"classviennacl_1_1basic__slice.html#a3a7bac8d57ee54a8b6fe56ffcfaac638":[6,0,0,12,3],
+"classviennacl_1_1basic__slice.html#a58c9942b91aa224c0aa552be7f0a45b0":[6,0,0,12,11],
+"classviennacl_1_1basic__slice.html#a7b8cf1d3e5790b7263aa2147a4eecf74":[6,0,0,12,5],
+"classviennacl_1_1basic__slice.html#a8d251dc812858795ecd43307ad9697cc":[6,0,0,12,13],
+"classviennacl_1_1basic__slice.html#aa55fc37b7e4f63295e4f18bf467b3f22":[6,0,0,12,8],
+"classviennacl_1_1basic__slice.html#aa6d0070558344d0fc00f55385b45bd2e":[6,0,0,12,1],
+"classviennacl_1_1basic__slice.html#adfcc1b0f7e5c71e0a9c95da0051ca19e":[6,0,0,12,2],
+"classviennacl_1_1basic__slice.html#af141c5755a25cb69564d15b488dc2c7b":[6,0,0,12,6],
+"classviennacl_1_1basic__slice.html#af1caf81d3003290ca700e63133fa7479":[6,0,0,12,9],
+"classviennacl_1_1basic__slice.html#afc8c94993c7b04fe8b78dacb22d463f9":[6,0,0,12,12],
+"classviennacl_1_1basic__slice.html#afdd8df15a78772bab3804aa32bd3703b":[6,0,0,12,4],
 "classviennacl_1_1circulant__matrix.html":[6,0,0,13],
 "classviennacl_1_1circulant__matrix.html#a1117ac76564254e55a0aa840094c188f":[6,0,0,13,1],
 "classviennacl_1_1circulant__matrix.html#a20add1ca7973763648451656c1a691c2":[6,0,0,13,0],
@@ -206,32 +192,32 @@ var NAVTREEINDEX1 =
 "classviennacl_1_1compressed__matrix.html#af71dec61a70e8df4f78a527aa989a106":[6,0,0,18,13],
 "classviennacl_1_1compressed__matrix.html#afcf49945a63836e1edfca536fcd191fb":[6,0,0,18,25],
 "classviennacl_1_1const__entry__proxy.html":[6,0,0,19],
-"classviennacl_1_1const__entry__proxy.html#a7292550b61e1a625496dd362339c7187":[6,0,0,19,0],
-"classviennacl_1_1const__entry__proxy.html#abe9e28e8a14d528af431c4c946a46f80":[6,0,0,19,3],
-"classviennacl_1_1const__entry__proxy.html#adb02059e2c2baddfcc1fd7b97614213a":[6,0,0,19,4],
-"classviennacl_1_1const__entry__proxy.html#aed2935b8d5040b680419cde80828b5f2":[6,0,0,19,1],
-"classviennacl_1_1const__entry__proxy.html#af3cd5a538ac1202e0dac28bcf887077d":[6,0,0,19,2],
+"classviennacl_1_1const__entry__proxy.html#a8f916f229ef166b16006b514b13d1318":[6,0,0,19,0],
+"classviennacl_1_1const__entry__proxy.html#a9906f1d945b78b11ab14feef6367d2c8":[6,0,0,19,1],
+"classviennacl_1_1const__entry__proxy.html#abc1b268a517bbb435434b9bf54f2313a":[6,0,0,19,4],
+"classviennacl_1_1const__entry__proxy.html#ac364f96496deec7473be1126f12279fc":[6,0,0,19,3],
+"classviennacl_1_1const__entry__proxy.html#afd3d3e90596401bb6cb6309cb6d46fb4":[6,0,0,19,2],
 "classviennacl_1_1const__vector__iterator.html":[6,0,0,20],
-"classviennacl_1_1const__vector__iterator.html#a0ce7b1d338d35efc3e378ec7af7e4b8c":[6,0,0,20,10],
-"classviennacl_1_1const__vector__iterator.html#a29aad8e236f2fe712ebdf98825f427ee":[6,0,0,20,2],
-"classviennacl_1_1const__vector__iterator.html#a40596679a283d524291a9a63af97e5f5":[6,0,0,20,17],
-"classviennacl_1_1const__vector__iterator.html#a63de71957553776e0178f1bb2a795ea6":[6,0,0,20,9],
-"classviennacl_1_1const__vector__iterator.html#a74689fc520d387564e70d5e73f527ddd":[6,0,0,20,4],
-"classviennacl_1_1const__vector__iterator.html#a7871517dbb0e61034ecc87dba13bd2cb":[6,0,0,20,7],
-"classviennacl_1_1const__vector__iterator.html#a866aa6ce744d8c59819cb4061a48166f":[6,0,0,20,14],
-"classviennacl_1_1const__vector__iterator.html#a96f34aa17ad546ea8d97e205d05b372b":[6,0,0,20,1],
-"classviennacl_1_1const__vector__iterator.html#a9f5686cab330f99c29ab57925f84b136":[6,0,0,20,15],
-"classviennacl_1_1const__vector__iterator.html#aac68e355edde844dec53cec7851de2af":[6,0,0,20,6],
-"classviennacl_1_1const__vector__iterator.html#aacc19519a7cd9a50a76197efd5202b27":[6,0,0,20,0],
-"classviennacl_1_1const__vector__iterator.html#aaff6b3b9edca90b6fac60fef55332b77":[6,0,0,20,18],
-"classviennacl_1_1const__vector__iterator.html#abda30c30684ac0ee23edebf6538a483f":[6,0,0,20,19],
-"classviennacl_1_1const__vector__iterator.html#ac0f2d487d81e6fcb9500d333f3dfe3b7":[6,0,0,20,8],
-"classviennacl_1_1const__vector__iterator.html#acf6f49633b55a04677eb0e05fd414d34":[6,0,0,20,5],
-"classviennacl_1_1const__vector__iterator.html#ad5b5840973672401934ddb081020691b":[6,0,0,20,13],
-"classviennacl_1_1const__vector__iterator.html#ad83ced390bbb5be3d10eeab4e250a640":[6,0,0,20,3],
-"classviennacl_1_1const__vector__iterator.html#ae34886f524c5a05bb2722adc87dddfa3":[6,0,0,20,11],
-"classviennacl_1_1const__vector__iterator.html#ae798738527a30c65c6ce3b3b3a019299":[6,0,0,20,16],
-"classviennacl_1_1const__vector__iterator.html#afaae3d7d629117d5fae91586c5aac66c":[6,0,0,20,12],
+"classviennacl_1_1const__vector__iterator.html#a07e5fcc51a0374b2ce568d8fafed7d53":[6,0,0,20,15],
+"classviennacl_1_1const__vector__iterator.html#a158896d38289f0513c2ca66a62de1883":[6,0,0,20,11],
+"classviennacl_1_1const__vector__iterator.html#a1838b359c2e56e79c515e358841f2bd1":[6,0,0,20,2],
+"classviennacl_1_1const__vector__iterator.html#a2e372df1cde8e780c6255bacc5e0d4fa":[6,0,0,20,3],
+"classviennacl_1_1const__vector__iterator.html#a3fd269ef2b1b32502f2588fc9ef0b20a":[6,0,0,20,9],
+"classviennacl_1_1const__vector__iterator.html#a4c93a6e434c6b18288ec6cbcb75959d6":[6,0,0,20,16],
+"classviennacl_1_1const__vector__iterator.html#a5896558cde67938026b1fa5841443861":[6,0,0,20,0],
+"classviennacl_1_1const__vector__iterator.html#a67270e817fff05ddf59e255f90a2e7a6":[6,0,0,20,5],
+"classviennacl_1_1const__vector__iterator.html#a75ffbe5005aca3d4c5a429c4bd5743ea":[6,0,0,20,4],
+"classviennacl_1_1const__vector__iterator.html#a82c4bf795074b8d05b0d9069916c9e51":[6,0,0,20,8],
+"classviennacl_1_1const__vector__iterator.html#a8937c16730a25f44912fbac6343ff54d":[6,0,0,20,12],
+"classviennacl_1_1const__vector__iterator.html#a98ba9bd7fe31f43438258257dcd4249e":[6,0,0,20,1],
+"classviennacl_1_1const__vector__iterator.html#aa608de6a49490a8a222fe5ffb38526f9":[6,0,0,20,10],
+"classviennacl_1_1const__vector__iterator.html#aa6c4497212e7144b088f9c26a05f2cb5":[6,0,0,20,14],
+"classviennacl_1_1const__vector__iterator.html#abbd5bfa4b7dc793fce6532e94ae80249":[6,0,0,20,7],
+"classviennacl_1_1const__vector__iterator.html#abfc56e2dd63d65539cbb297a7ed96787":[6,0,0,20,17],
+"classviennacl_1_1const__vector__iterator.html#ac9a48f522ed8667681ce24ba68b48973":[6,0,0,20,19],
+"classviennacl_1_1const__vector__iterator.html#acce2d2e5cb157dd10f198f797432549b":[6,0,0,20,13],
+"classviennacl_1_1const__vector__iterator.html#ad0c0c351fcbc964e8a2e26481066c678":[6,0,0,20,6],
+"classviennacl_1_1const__vector__iterator.html#af077a2cd92ce958c587e219b2996ad11":[6,0,0,20,18],
 "classviennacl_1_1context.html":[6,0,0,21],
 "classviennacl_1_1context.html#a88b51d155aee396ef6d8d8a96bd7e90a":[6,0,0,21,1],
 "classviennacl_1_1context.html#a8f95db066e453ccd52aa9305fbd71243":[6,0,0,21,0],
@@ -249,5 +235,19 @@ var NAVTREEINDEX1 =
 "classviennacl_1_1coordinate__matrix.html#a66b7f5c5487b719c91bc76984f89f97f":[6,0,0,22,11],
 "classviennacl_1_1coordinate__matrix.html#a734ed32ff1858ef5453c170326fda377":[6,0,0,22,16],
 "classviennacl_1_1coordinate__matrix.html#a7f83ad82b3bab755d76e7f9d665367f7":[6,0,0,22,8],
-"classviennacl_1_1coordinate__matrix.html#a875b6ccacbf0df8ef48ab7f7c46244f1":[6,0,0,22,10]
+"classviennacl_1_1coordinate__matrix.html#a875b6ccacbf0df8ef48ab7f7c46244f1":[6,0,0,22,10],
+"classviennacl_1_1coordinate__matrix.html#a9cde8a8c5cb1516c5503d011388daed4":[6,0,0,22,4],
+"classviennacl_1_1coordinate__matrix.html#a9fd9168600c330faa69cae2626509602":[6,0,0,22,2],
+"classviennacl_1_1coordinate__matrix.html#ad091412ca52bb131234464ed3f5b103c":[6,0,0,22,14],
+"classviennacl_1_1coordinate__matrix.html#ad4218882f3bd97eeff6d81b575ea1e3c":[6,0,0,22,1],
+"classviennacl_1_1coordinate__matrix.html#ad5b57c8ab8bcc8d839aba53be7cb1463":[6,0,0,22,5],
+"classviennacl_1_1coordinate__matrix.html#aeb74dd2ab673d7912a17f60777e9bf6c":[6,0,0,22,9],
+"classviennacl_1_1cuda__not__available__exception.html":[6,0,0,23],
+"classviennacl_1_1cuda__not__available__exception.html#a8e4a228218ec828c3d74facbd8388df0":[6,0,0,23,1],
+"classviennacl_1_1cuda__not__available__exception.html#a941a849d4b445e91c19f14cb3e7d1419":[6,0,0,23,0],
+"classviennacl_1_1cuda__not__available__exception.html#a94c488fd1c10322c3f594bdf7946a859":[6,0,0,23,2],
+"classviennacl_1_1device__specific_1_1binary__leaf.html":[6,0,0,2,3],
+"classviennacl_1_1device__specific_1_1binary__leaf.html#a11ef22c2e5b36de4e5d350766e50e04f":[6,0,0,2,3,1],
+"classviennacl_1_1device__specific_1_1binary__leaf.html#a616051ebd6114784ecba182531e1ad9f":[6,0,0,2,3,3],
+"classviennacl_1_1device__specific_1_1binary__leaf.html#aaf20a0f61286e07400f4daef62c4ad9f":[6,0,0,2,3,2]
 };
