@@ -1,70 +1,5 @@
 var NAVTREEINDEX10 =
 {
-"detail_2spai_2qr_8hpp.html#aa50a771c3604ad3913905871d54176f4":[7,0,3,4,1,3,3,3],
-"detail_2spai_2qr_8hpp.html#ab3b64ba7bb53a1526cc852daf0d4d53e":[7,0,3,4,1,3,3,2],
-"detail_2spai_2qr_8hpp.html#abbff207e6f84bc89822c0eab0aea0fe7":[7,0,3,4,1,3,3,15],
-"detail_2spai_2qr_8hpp.html#abcaaf643f5b021ac04dd7690904e59f9":[7,0,3,4,1,3,3,17],
-"detail_2spai_2qr_8hpp.html#ae6d21631da144b8d5c5de25afcbe53e7":[7,0,3,4,1,3,3,7],
-"detail_2spai_2qr_8hpp.html#af12bfcc7a652ea6bc9150c302dae81a7":[7,0,3,4,1,3,3,9],
-"detail_2spai_2qr_8hpp.html#af7b43cbe43e0371cea55b325b410c1b4":[7,0,3,4,1,3,3,10],
-"detail_2spai_2qr_8hpp_source.html":[7,0,3,4,1,3,3],
-"detail_2spai_2spai_8hpp.html":[7,0,3,4,1,3,7],
-"detail_2spai_2spai_8hpp.html#a18b9a595189ffa38d5acdaad6a286905":[7,0,3,4,1,3,7,15],
-"detail_2spai_2spai_8hpp.html#a1a76d81e5a1302f9d03949ea2783ee7d":[7,0,3,4,1,3,7,19],
-"detail_2spai_2spai_8hpp.html#a1dda26d5d7af5cbba03485b2da3075b2":[7,0,3,4,1,3,7,0],
-"detail_2spai_2spai_8hpp.html#a312ded5b57f112daa612d3b790cbc830":[7,0,3,4,1,3,7,12],
-"detail_2spai_2spai_8hpp.html#a4673473f615b2369ca4e14b1a6f98b5c":[7,0,3,4,1,3,7,6],
-"detail_2spai_2spai_8hpp.html#a4a5e501e0f8a2f6e2733b0c5df10c6ad":[7,0,3,4,1,3,7,9],
-"detail_2spai_2spai_8hpp.html#a4d52c5d84eb0f23619d0129c50412e82":[7,0,3,4,1,3,7,7],
-"detail_2spai_2spai_8hpp.html#a511597723c2d451fda55ff4ead99eaf0":[7,0,3,4,1,3,7,21],
-"detail_2spai_2spai_8hpp.html#a5dca466b626554c2b42bf25b500842e2":[7,0,3,4,1,3,7,16],
-"detail_2spai_2spai_8hpp.html#a644c28fb7b3c4e677d86dc4b06388dab":[7,0,3,4,1,3,7,14],
-"detail_2spai_2spai_8hpp.html#a6983ad76ea95e66ed94092bd05f44204":[7,0,3,4,1,3,7,10],
-"detail_2spai_2spai_8hpp.html#a7c462e0ad109f5e23eb34982c2f91dd4":[7,0,3,4,1,3,7,20],
-"detail_2spai_2spai_8hpp.html#a906b89d67f50b1adf349391bb62b7cf0":[7,0,3,4,1,3,7,3],
-"detail_2spai_2spai_8hpp.html#a934fa8b447e7836d4c9be2dd40c35390":[7,0,3,4,1,3,7,18],
-"detail_2spai_2spai_8hpp.html#acaad1278cf03e43d711f0f24d9d454c9":[7,0,3,4,1,3,7,5],
-"detail_2spai_2spai_8hpp.html#ada1688aeb8885254756bf80384a223ac":[7,0,3,4,1,3,7,1],
-"detail_2spai_2spai_8hpp.html#ae544b4abea516f88a64117c4c548d3a7":[7,0,3,4,1,3,7,4],
-"detail_2spai_2spai_8hpp.html#ae5d1da881af74993b78c433286b70a00":[7,0,3,4,1,3,7,17],
-"detail_2spai_2spai_8hpp.html#aea8b96ecccca6f209e810669f0d13e36":[7,0,3,4,1,3,7,13],
-"detail_2spai_2spai_8hpp.html#af29f9f19dceffdd04a1ac530c6fbb4ed":[7,0,3,4,1,3,7,8],
-"detail_2spai_2spai_8hpp.html#afe2919f83347787985e20e0599ba4296":[7,0,3,4,1,3,7,2],
-"detail_2spai_2spai_8hpp.html#aff1616fc9ee32fd0e1d641f6d8f2ebf3":[7,0,3,4,1,3,7,11],
-"detail_2spai_2spai_8hpp_source.html":[7,0,3,4,1,3,7],
-"devastator_8hpp.html":[7,0,3,2,0,0,2,0,1,1],
-"devastator_8hpp.html#a15fbb651ef6e5e58b285f68269c61c8a":[7,0,3,2,0,0,2,0,1,1,6],
-"devastator_8hpp.html#a1f4714219d6dc156beb94179729d02f4":[7,0,3,2,0,0,2,0,1,1,1],
-"devastator_8hpp.html#a396b54b5fc650e6d5e767244b1feeecf":[7,0,3,2,0,0,2,0,1,1,8],
-"devastator_8hpp.html#a3efd3b9772f8ea7229bbe154cb0ca84f":[7,0,3,2,0,0,2,0,1,1,0],
-"devastator_8hpp.html#a4ff2803744c9df519eb87a0549b08bcf":[7,0,3,2,0,0,2,0,1,1,2],
-"devastator_8hpp.html#a6e6e9f32577222daef044d8456c96cda":[7,0,3,2,0,0,2,0,1,1,4],
-"devastator_8hpp.html#aaefad1bacebf761b5114e82da75a2d87":[7,0,3,2,0,0,2,0,1,1,5],
-"devastator_8hpp.html#abb46400dbeeadbd7704dbb0bc979e927":[7,0,3,2,0,0,2,0,1,1,3],
-"devastator_8hpp.html#acd00c2fa09e47c6dfb0c1607f32317b0":[7,0,3,2,0,0,2,0,1,1,7],
-"devastator_8hpp_source.html":[7,0,3,2,0,0,2,0,1,1],
-"device_8hpp.html":[7,0,3,7,3],
-"device_8hpp_source.html":[7,0,3,7,3],
-"device__specific_2builtin__database_2common_8hpp.html":[7,0,3,2,0,1],
-"device__specific_2builtin__database_2common_8hpp.html#a6f059365bdf3dcb21b78c519dc294250":[7,0,3,2,0,1,6],
-"device__specific_2builtin__database_2common_8hpp_source.html":[7,0,3,2,0,1],
-"device__specific_2execute_8hpp.html":[7,0,3,2,2],
-"device__specific_2execute_8hpp.html#a0e0576421dc6e48555abd251d0a83ae0":[7,0,3,2,2,0],
-"device__specific_2execute_8hpp_source.html":[7,0,3,2,2],
-"device__specific_2forwards_8h.html":[7,0,3,2,4],
-"device__specific_2forwards_8h.html#a08bd08c6dc86b78e78749891e8832fe4":[7,0,3,2,4,16],
-"device__specific_2forwards_8h.html#a4ae1b6692dfe648094c52c14f0e81d45":[7,0,3,2,4,11],
-"device__specific_2forwards_8h.html#a5927db4220a325127326f3391ddf3321":[7,0,3,2,4,10],
-"device__specific_2forwards_8h.html#a5a4282524aeeafba4d9c5e44397403e7":[7,0,3,2,4,22],
-"device__specific_2forwards_8h.html#a70f9b436519b02537064504f3a327470":[7,0,3,2,4,24],
-"device__specific_2forwards_8h.html#a7935d6fe2cb68ce032c9a177ed7f1d41":[7,0,3,2,4,23],
-"device__specific_2forwards_8h.html#a810fd16fbb883a4987ff0cf720d47037":[7,0,3,2,4,17],
-"device__specific_2forwards_8h.html#a89c2dbe54841c653951eaa6a248c7526":[7,0,3,2,4,20],
-"device__specific_2forwards_8h.html#aa451f851b492f6422bfdd71f51fdc1fb":[7,0,3,2,4,7],
-"device__specific_2forwards_8h.html#aaa1f965282523dc44221b5ee4a99d41b":[7,0,3,2,4,8],
-"device__specific_2forwards_8h.html#ab912aba0d144f286022bb3af5d5f8f77":[7,0,3,2,4,15],
-"device__specific_2forwards_8h.html#ac45007f831a7945fb8b03ab3a8498446":[7,0,3,2,4,9],
-"device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9":[7,0,3,2,4,12],
 "device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9a5bac3e336ba87e7a3311dee3d2129db5":[7,0,3,2,4,12,1],
 "device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9a763b24a54e9bdb083926bc27e90ba0d6":[7,0,3,2,4,12,0],
 "device__specific_2forwards_8h.html#acf5956ffbc42d6804ba7f9c2376ddc75":[7,0,3,2,4,21],
@@ -87,13 +22,13 @@ var NAVTREEINDEX10 =
 "device__specific_2forwards_8h.html#ae9b56899cd3fc4fb4f0ab83ee174b26b":[7,0,3,2,4,19],
 "device__specific_2forwards_8h.html#af46ac461e9e315b07018aef4110de10b":[7,0,3,2,4,18],
 "device__specific_2forwards_8h_source.html":[7,0,3,2,4],
-"device__specific_2templates_2utils_8hpp.html":[7,0,3,2,1,5],
-"device__specific_2templates_2utils_8hpp.html#a0caa2acde930200ff31a87e7fbf0c9a1":[7,0,3,2,1,5,3],
-"device__specific_2templates_2utils_8hpp.html#a0e380a9c323adcd3f5c587f82c3cce66":[7,0,3,2,1,5,4],
-"device__specific_2templates_2utils_8hpp.html#a1e2369d7f7fbcacf9c16f48cabd21b4a":[7,0,3,2,1,5,1],
-"device__specific_2templates_2utils_8hpp.html#a9c1338a8a946a361418c94dd15809ae7":[7,0,3,2,1,5,0],
-"device__specific_2templates_2utils_8hpp.html#af5ca1aac7c74718369880d50d690655e":[7,0,3,2,1,5,2],
-"device__specific_2templates_2utils_8hpp_source.html":[7,0,3,2,1,5],
+"device__specific_2templates_2utils_8hpp.html":[7,0,3,2,1,2],
+"device__specific_2templates_2utils_8hpp.html#a0caa2acde930200ff31a87e7fbf0c9a1":[7,0,3,2,1,2,3],
+"device__specific_2templates_2utils_8hpp.html#a0e380a9c323adcd3f5c587f82c3cce66":[7,0,3,2,1,2,4],
+"device__specific_2templates_2utils_8hpp.html#a1e2369d7f7fbcacf9c16f48cabd21b4a":[7,0,3,2,1,2,1],
+"device__specific_2templates_2utils_8hpp.html#a9c1338a8a946a361418c94dd15809ae7":[7,0,3,2,1,2,0],
+"device__specific_2templates_2utils_8hpp.html#af5ca1aac7c74718369880d50d690655e":[7,0,3,2,1,2,2],
+"device__specific_2templates_2utils_8hpp_source.html":[7,0,3,2,1,2],
 "device__specific_2utils_8hpp.html":[7,0,3,2,8],
 "device__specific_2utils_8hpp.html#a13c97b9a5b877537d3df565b6b2f3d15":[7,0,3,2,8,48],
 "device__specific_2utils_8hpp.html#a16e857beaea305ca65c3ad7f85ef98a0":[7,0,3,2,8,42],
@@ -126,51 +61,51 @@ var NAVTREEINDEX10 =
 "device__utils_8hpp.html#ac19deb058c8b979eba1faba219542c35af25058db0b8bd4549bfc505a1fabd65c":[7,0,3,7,4,2,7],
 "device__utils_8hpp.html#ac19deb058c8b979eba1faba219542c35af9a1d1ba7d8da2e2d3156ca47b0313a2":[7,0,3,7,4,2,1],
 "device__utils_8hpp_source.html":[7,0,3,7,4],
-"dir_01b3c751f720f476f11e734a5342cf1b.html":[7,0,3,2,0,0,1],
-"dir_092b0434a99bb331b2d9b2dab295534c.html":[7,0,3,1],
-"dir_099d776d46ae96ff5cee19885f4f74f2.html":[7,0,2,0],
-"dir_0b4fb0e326d4c389a119669d669a6e69.html":[7,0,3,2,0,0,2,1,0],
-"dir_2001d641ce37c2db2d1e007fffdbbab7.html":[7,0,3,2,0,0,0],
-"dir_27114906f706ecdebcc89e2874337717.html":[7,0,3,2,1],
-"dir_2c76207559b46be39a09cc4d70787ef4.html":[7,0,3,4,1],
-"dir_2f67efd16f85b85ca16db052e014fcaf.html":[7,0,3,2,0,0,2,0],
-"dir_3434f00e33d7f192388fb69bbf2f37a2.html":[7,0,3,5],
-"dir_35f9be625259f60231ebff5b0d077ea2.html":[7,0,0,1],
-"dir_390b8788bc396e89a6deace7ca940934.html":[7,0,3,2,0,0,2,1,3],
-"dir_3c0f8bca876b5668e3f390ae97746303.html":[7,0,3,4,0],
-"dir_41e0e67a22e5e0d73b771322c991061f.html":[7,0,3,4,2],
-"dir_4de6310690561ebe9ac5fd60ffe08037.html":[7,0,3],
-"dir_58fc2bc704609e0f008af69b801200e4.html":[7,0,3,2],
-"dir_59cb328a51f7f6429c345eb686ab7724.html":[7,0,3,2,0,0,2,1,1],
-"dir_5c3e36572ba72092998a3741bd07cdf1.html":[7,0,3,2,0,0,2],
-"dir_5f8f0868158a2d22d511a28fc1cd18ce.html":[7,0,3,9],
-"dir_63a76f200abdc5aa2f86541e7eb7aef8.html":[7,0,3,6],
-"dir_6dca993aa72ebeec8a0f442d956c9913.html":[7,0,2],
-"dir_6f8f0f2d0c4cbbddd33023456e356f61.html":[7,0,3,2,0,0,2,1,2],
-"dir_77930e01897af26f03a43cb7e2da3e4a.html":[7,0,3,4],
-"dir_8118e66653cd7da1a37aaa1607e88630.html":[7,0,3,2,0,0],
-"dir_824564dd709617d4bdedad95258d9046.html":[7,0,3,4,1,1],
-"dir_858444a2a3a03d054aa7433b28efdef9.html":[7,0,3,2,0],
-"dir_8b1ffc44f1138c76b3fbf6563058dc96.html":[7,0,3,3],
-"dir_93563308d5b356d3ecc9c56b5eba5216.html":[7,0,0],
-"dir_95fc417dec4bda27f5b6b357f2a06a36.html":[7,0,1,0],
-"dir_a35454c136dbde0efc3d038671c34f86.html":[7,0,3,4,1,2],
-"dir_c31b5415cda288c5525ed229fcfffcf8.html":[7,0,3,8],
-"dir_c9edeb3d94bf5e327751a8cc5813c8dd.html":[7,0,3,4,1,3],
-"dir_ce8031117faa480542275b5ce9add50d.html":[7,0,3,10],
-"dir_d1898bb18f82202c483fe3a51bff13d4.html":[7,0,3,2,0,0,2,0,2],
-"dir_d23fc3235ab72e0492c7b54726da60e2.html":[7,0,3,2,0,0,2,0,3],
-"dir_d3fb184dc4f20da33396307607cc8bb4.html":[7,0,1],
-"dir_d68073153f76c9008f2e3fe0f69d64d6.html":[7,0,0,0],
-"dir_e2246a470efa11fe5ee09b98569d4f67.html":[7,0,3,4,3,0],
-"dir_e41cc518aa56aa7f9ce018465031b9eb.html":[7,0,3,2,0,0,2,0,0],
-"dir_e8182705ebed9d1d140d832c453ebe92.html":[7,0,1,1],
-"dir_eb859c66d33e4484181fb09db56df864.html":[7,0,3,2,0,0,2,1],
-"dir_ed6f2e67dec54bb764eec12abdb4cfa4.html":[7,0,3,2,0,0,2,0,1],
-"dir_f6bb7da30ce818e127ed2ed164db6395.html":[7,0,3,7],
-"dir_f80b40e4de20372a9d8da07b695e9141.html":[7,0,3,4,1,0],
-"dir_fde5adc25a0fd7501eb505b6744dc8e7.html":[7,0,3,0],
-"dir_fe84e742d5b92d85f104b5626c2ae061.html":[7,0,3,4,3],
+"dir_16664ee5917227688a793c46bff13f10.html":[7,0,3,1],
+"dir_19b91ce24010a277ae42e0f12bdd020d.html":[7,0,3,4,3,0],
+"dir_225062f072d8eb572e25b876c44903f8.html":[7,0,3,0],
+"dir_2753ed8074493aeff3e0515eb0266828.html":[7,0,3,4,1],
+"dir_27edd4ef761976637f0a6ff19cff4c00.html":[7,0,3,4,1,2],
+"dir_28beffbf6e9a4aae9ebfd9c70ae78dbb.html":[7,0,3,2,0,0,1],
+"dir_28d0cd2c2b69cc52f4592b0100abbb19.html":[7,0,3,2,0,0,2,0,2],
+"dir_2aede027c3fab12899418e3db60d7e7a.html":[7,0,3,4,0],
+"dir_3f34dde6f45e42123944fdf74c951721.html":[7,0,3,2,0],
+"dir_46cfbf617d85ee2b7d727c96b372dc67.html":[7,0,3,2,0,0,2,0,1],
+"dir_49d9f40cb486c21f519277654eaf1706.html":[7,0,3,2],
+"dir_4cce297acab7995b556697564a5c781a.html":[7,0,2],
+"dir_54216ae2e4dd664125f44b7fd28e4307.html":[7,0,3,9],
+"dir_5d0e0c49da9183844fcfe7c46dce8078.html":[7,0,1],
+"dir_63cde087767c4ed65c7901ffc6e293fe.html":[7,0,3,4],
+"dir_64c1c02bcadf9f69b9adb149c0a5035c.html":[7,0,3,2,0,0,2],
+"dir_69e45189a60a9e7cdae73056ab62ba64.html":[7,0,1,0],
+"dir_717f42b2bc9c32450292c49ab28b084d.html":[7,0,3,3],
+"dir_88cf2948f5fd612ee5751a9df4dcf539.html":[7,0,3,10],
+"dir_891862c9d10548f0b71e7a20afa28180.html":[7,0,3,2,0,0,2,0,0],
+"dir_8d65d6aa9e8b523925f2b9aaa58554fe.html":[7,0,3,8],
+"dir_8d734bf48796b8afc2ea3e50ddaea273.html":[7,0,3,4,2],
+"dir_8e9f3cc091f3e773a2961f7e1b2269a2.html":[7,0,3,6],
+"dir_8eb26a60ce7e4e74227e98fac5455a0e.html":[7,0,3,2,0,0,0],
+"dir_952080306f114f51a8f2d73e253ffb05.html":[7,0,3,2,0,0,2,1,2],
+"dir_95ddc301de7dff4151ad233d69616cc0.html":[7,0,2,0],
+"dir_9d6102a0bd98effb16f0ae15f80f4955.html":[7,0,3,2,0,0,2,0],
+"dir_9d83cdcad950ebf3600600fb35f63223.html":[7,0,3,7],
+"dir_9df590563da805a074404567c6e27abf.html":[7,0,3,4,3],
+"dir_a5d754652166e9a81bc9a52ffaf77760.html":[7,0,0,1],
+"dir_a78feceb34e860582b3d668a1009a0c5.html":[7,0,3,4,1,0],
+"dir_a905ce029440da2b05eea32d8557e825.html":[7,0,3,2,1],
+"dir_aa995bfae49b010b59767b6c6eeaeea5.html":[7,0,1,1],
+"dir_aa9c51eb28287244843c1d8e47ca0d4b.html":[7,0,3,2,0,0,2,1],
+"dir_ac15a598d0f4a939ccff6b1a44621590.html":[7,0,3,2,0,0],
+"dir_b76e1ea04152a1f4ad74f59634c8ce42.html":[7,0,3,2,0,0,2,1,0],
+"dir_c82e3d11dd171600f4a6e0cab1ec1e0d.html":[7,0,3],
+"dir_cefc9203477f333ab105ea8579c62693.html":[7,0,3,5],
+"dir_cf1005d941559b8247e0b371f7ec5325.html":[7,0,3,2,0,0,2,1,1],
+"dir_d19492564bd1307bd18c84298ee04469.html":[7,0,3,4,1,3],
+"dir_d8545eca993c5d9c7906a844d16124ca.html":[7,0,0,0],
+"dir_e3caf1d7a9bf57697faf63bc7e466f4c.html":[7,0,3,2,0,0,2,0,3],
+"dir_e6cbf65cd48c4de0cbf6207c238fcdc2.html":[7,0,0],
+"dir_f2f353a0caae60a604684eba008d62d6.html":[7,0,3,4,1,1],
+"dir_fd2283f1c867d7bf85da4bd3c6348507.html":[7,0,3,2,0,0,2,1,3],
 "direct__solve_8cpp.html":[7,0,0,0,1],
 "direct__solve_8cpp.html#a33980228e5f215fd71462379cd1211b9":[7,0,0,0,1,2],
 "direct__solve_8cpp.html#a76c117307d545decb2480596430b8ed0":[7,0,0,0,1,6],
@@ -249,5 +184,70 @@ var NAVTREEINDEX10 =
 "examples_2benchmarks_2sparse_8cpp.html#af9d2311f8dd8c5536101e46f1351df56":[7,0,0,0,6,2],
 "examples_2benchmarks_2sparse_8cpp_source.html":[7,0,0,0,6],
 "examples_2tutorial_2bisect_8cpp.html":[7,0,0,1,3],
-"examples_2tutorial_2bisect_8cpp_source.html":[7,0,0,1,3]
+"examples_2tutorial_2bisect_8cpp_source.html":[7,0,0,1,3],
+"examples_2tutorial_2blas1_8cpp.html":[7,0,0,1,4],
+"examples_2tutorial_2blas1_8cpp_source.html":[7,0,0,1,4],
+"examples_2tutorial_2blas2_8cpp.html":[7,0,0,1,5],
+"examples_2tutorial_2blas2_8cpp_source.html":[7,0,0,1,5],
+"examples_2tutorial_2blas3_8cpp.html":[7,0,0,1,6],
+"examples_2tutorial_2blas3_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,1,6,0],
+"examples_2tutorial_2blas3_8cpp_source.html":[7,0,0,1,6],
+"examples_2tutorial_2libviennacl_8cpp-example.html":[8,10],
+"examples_2tutorial_2nmf_8cpp.html":[7,0,0,1,26],
+"examples_2tutorial_2nmf_8cpp_source.html":[7,0,0,1,26],
+"examples_2tutorial_2qr__method_8cpp.html":[7,0,0,1,29],
+"examples_2tutorial_2qr__method_8cpp_source.html":[7,0,0,1,29],
+"examples_2tutorial_2sparse_8cpp.html":[7,0,0,1,32],
+"examples_2tutorial_2sparse_8cpp_source.html":[7,0,0,1,32],
+"examples_2tutorial_2structured-matrices_8cpp.html":[7,0,0,1,33],
+"examples_2tutorial_2structured-matrices_8cpp_source.html":[7,0,0,1,33],
+"execute__axbx_8hpp.html":[7,0,3,8,1],
+"execute__axbx_8hpp.html#a2f9d553c7deffb59338de92689a6bd21":[7,0,3,8,1,0],
+"execute__axbx_8hpp_source.html":[7,0,3,8,1],
+"execute__elementwise_8hpp.html":[7,0,3,8,2],
+"execute__elementwise_8hpp.html#a0637666aeba76d4f30d97a81d8b8eb36":[7,0,3,8,2,2],
+"execute__elementwise_8hpp.html#a4eba46ca2fed779c016547178786202d":[7,0,3,8,2,3],
+"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,0],
+"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,1],
+"execute__elementwise_8hpp.html#aaaa93acc7901ab5a44ff4b00b986362b":[7,0,3,8,2,4],
+"execute__elementwise_8hpp_source.html":[7,0,3,8,2],
+"execute__generic__dispatcher_8hpp.html":[7,0,3,8,3],
+"execute__generic__dispatcher_8hpp.html#a3b738ebf96bc6dc90ee319f76384200f":[7,0,3,8,3,1],
+"execute__generic__dispatcher_8hpp.html#a4e622b0090a19757b52263765b32563b":[7,0,3,8,3,2],
+"execute__generic__dispatcher_8hpp.html#a5accb7e7374986bab8de2e2052396d4f":[7,0,3,8,3,0],
+"execute__generic__dispatcher_8hpp_source.html":[7,0,3,8,3],
+"execute__matrix__dispatcher_8hpp.html":[7,0,3,8,4],
+"execute__matrix__dispatcher_8hpp.html#a1e19fbe37940c1222e7523451575e63d":[7,0,3,8,4,1],
+"execute__matrix__dispatcher_8hpp.html#a25fa1772306c466a93b7444d50562a3e":[7,0,3,8,4,3],
+"execute__matrix__dispatcher_8hpp.html#a65eed844b91af24e61e9b4e671f5bf1f":[7,0,3,8,4,2],
+"execute__matrix__dispatcher_8hpp.html#aca2b475628c8f81635fa7186098cb5d6":[7,0,3,8,4,0],
+"execute__matrix__dispatcher_8hpp_source.html":[7,0,3,8,4],
+"execute__matrix__prod_8hpp.html":[7,0,3,8,5],
+"execute__matrix__prod_8hpp.html#a319c0746aade8ee712943f7fab0534f0":[7,0,3,8,5,3],
+"execute__matrix__prod_8hpp.html#a6089b683fe5e7e2250d3ba165d218a36":[7,0,3,8,5,0],
+"execute__matrix__prod_8hpp.html#aa1e2a8be3d9a082439b60ee3c5cdd8d9":[7,0,3,8,5,1],
+"execute__matrix__prod_8hpp.html#aabb862c7cd4ae0c07dce0fe2c699b62b":[7,0,3,8,5,2],
+"execute__matrix__prod_8hpp_source.html":[7,0,3,8,5],
+"execute__scalar__assign_8hpp.html":[7,0,3,8,6],
+"execute__scalar__assign_8hpp.html#a799345d5ccfaa42eb0b946c2896b9dd3":[7,0,3,8,6,0],
+"execute__scalar__assign_8hpp_source.html":[7,0,3,8,6],
+"execute__scalar__dispatcher_8hpp.html":[7,0,3,8,7],
+"execute__scalar__dispatcher_8hpp.html#a38d01048e4ccf5c5e79631285b74ee39":[7,0,3,8,7,0],
+"execute__scalar__dispatcher_8hpp.html#aa3339b4dbc6a35020187b842f3ecbd93":[7,0,3,8,7,2],
+"execute__scalar__dispatcher_8hpp.html#ae1c6c429214457410d66c19bcbab207a":[7,0,3,8,7,1],
+"execute__scalar__dispatcher_8hpp_source.html":[7,0,3,8,7],
+"execute__util_8hpp.html":[7,0,3,8,8],
+"execute__util_8hpp.html#a2b5c98a91cb51442944469960a201c51":[7,0,3,8,8,7],
+"execute__util_8hpp.html#a2c18b2af7ae9cc51b3043a037d1a9392":[7,0,3,8,8,1],
+"execute__util_8hpp.html#a420ee63edc572707098f89a93ebda6d8":[7,0,3,8,8,4],
+"execute__util_8hpp.html#a683bf651d720e1f98b068f338decd44e":[7,0,3,8,8,8],
+"execute__util_8hpp.html#a787b1a16dbfa7603d9b56755e9c47763":[7,0,3,8,8,2],
+"execute__util_8hpp.html#a9a26383bde576fcd27221a4c186d49ad":[7,0,3,8,8,3],
+"execute__util_8hpp.html#aa5e683dd98d9557be81d2abeefcf5d4b":[7,0,3,8,8,0],
+"execute__util_8hpp.html#af3cde7e8defdd2ac5d1888e98382602a":[7,0,3,8,8,5],
+"execute__util_8hpp.html#af5bfe6adf6edc8107b384ab54f8b6d04":[7,0,3,8,8,9],
+"execute__util_8hpp.html#afc342ce110f98120b991fd5ee03bc3cb":[7,0,3,8,8,6],
+"execute__util_8hpp_source.html":[7,0,3,8,8],
+"execute__vector__dispatcher_8hpp.html":[7,0,3,8,9],
+"execute__vector__dispatcher_8hpp.html#a45eff9c59fbae556d7e3295e062cdb4f":[7,0,3,8,9,0]
 };
