@@ -1,70 +1,5 @@
 var NAVTREEINDEX11 =
 {
-"examples_2tutorial_2blas1_8cpp.html":[7,0,0,1,4],
-"examples_2tutorial_2blas1_8cpp_source.html":[7,0,0,1,4],
-"examples_2tutorial_2blas2_8cpp.html":[7,0,0,1,5],
-"examples_2tutorial_2blas2_8cpp_source.html":[7,0,0,1,5],
-"examples_2tutorial_2blas3_8cpp.html":[7,0,0,1,6],
-"examples_2tutorial_2blas3_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,0,1,6,0],
-"examples_2tutorial_2blas3_8cpp_source.html":[7,0,0,1,6],
-"examples_2tutorial_2libviennacl_8cpp-example.html":[8,10],
-"examples_2tutorial_2nmf_8cpp.html":[7,0,0,1,26],
-"examples_2tutorial_2nmf_8cpp_source.html":[7,0,0,1,26],
-"examples_2tutorial_2qr__method_8cpp.html":[7,0,0,1,29],
-"examples_2tutorial_2qr__method_8cpp_source.html":[7,0,0,1,29],
-"examples_2tutorial_2sparse_8cpp.html":[7,0,0,1,32],
-"examples_2tutorial_2sparse_8cpp_source.html":[7,0,0,1,32],
-"examples_2tutorial_2structured-matrices_8cpp.html":[7,0,0,1,33],
-"examples_2tutorial_2structured-matrices_8cpp_source.html":[7,0,0,1,33],
-"execute__axbx_8hpp.html":[7,0,3,8,1],
-"execute__axbx_8hpp.html#a2f9d553c7deffb59338de92689a6bd21":[7,0,3,8,1,0],
-"execute__axbx_8hpp_source.html":[7,0,3,8,1],
-"execute__elementwise_8hpp.html":[7,0,3,8,2],
-"execute__elementwise_8hpp.html#a0637666aeba76d4f30d97a81d8b8eb36":[7,0,3,8,2,2],
-"execute__elementwise_8hpp.html#a4eba46ca2fed779c016547178786202d":[7,0,3,8,2,3],
-"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,0],
-"execute__elementwise_8hpp.html#a580ada22945ca328dddeca2b1ace85d0":[7,0,3,8,2,1],
-"execute__elementwise_8hpp.html#aaaa93acc7901ab5a44ff4b00b986362b":[7,0,3,8,2,4],
-"execute__elementwise_8hpp_source.html":[7,0,3,8,2],
-"execute__generic__dispatcher_8hpp.html":[7,0,3,8,3],
-"execute__generic__dispatcher_8hpp.html#a3b738ebf96bc6dc90ee319f76384200f":[7,0,3,8,3,1],
-"execute__generic__dispatcher_8hpp.html#a4e622b0090a19757b52263765b32563b":[7,0,3,8,3,2],
-"execute__generic__dispatcher_8hpp.html#a5accb7e7374986bab8de2e2052396d4f":[7,0,3,8,3,0],
-"execute__generic__dispatcher_8hpp_source.html":[7,0,3,8,3],
-"execute__matrix__dispatcher_8hpp.html":[7,0,3,8,4],
-"execute__matrix__dispatcher_8hpp.html#a1e19fbe37940c1222e7523451575e63d":[7,0,3,8,4,1],
-"execute__matrix__dispatcher_8hpp.html#a25fa1772306c466a93b7444d50562a3e":[7,0,3,8,4,3],
-"execute__matrix__dispatcher_8hpp.html#a65eed844b91af24e61e9b4e671f5bf1f":[7,0,3,8,4,2],
-"execute__matrix__dispatcher_8hpp.html#aca2b475628c8f81635fa7186098cb5d6":[7,0,3,8,4,0],
-"execute__matrix__dispatcher_8hpp_source.html":[7,0,3,8,4],
-"execute__matrix__prod_8hpp.html":[7,0,3,8,5],
-"execute__matrix__prod_8hpp.html#a319c0746aade8ee712943f7fab0534f0":[7,0,3,8,5,3],
-"execute__matrix__prod_8hpp.html#a6089b683fe5e7e2250d3ba165d218a36":[7,0,3,8,5,0],
-"execute__matrix__prod_8hpp.html#aa1e2a8be3d9a082439b60ee3c5cdd8d9":[7,0,3,8,5,1],
-"execute__matrix__prod_8hpp.html#aabb862c7cd4ae0c07dce0fe2c699b62b":[7,0,3,8,5,2],
-"execute__matrix__prod_8hpp_source.html":[7,0,3,8,5],
-"execute__scalar__assign_8hpp.html":[7,0,3,8,6],
-"execute__scalar__assign_8hpp.html#a799345d5ccfaa42eb0b946c2896b9dd3":[7,0,3,8,6,0],
-"execute__scalar__assign_8hpp_source.html":[7,0,3,8,6],
-"execute__scalar__dispatcher_8hpp.html":[7,0,3,8,7],
-"execute__scalar__dispatcher_8hpp.html#a38d01048e4ccf5c5e79631285b74ee39":[7,0,3,8,7,0],
-"execute__scalar__dispatcher_8hpp.html#aa3339b4dbc6a35020187b842f3ecbd93":[7,0,3,8,7,2],
-"execute__scalar__dispatcher_8hpp.html#ae1c6c429214457410d66c19bcbab207a":[7,0,3,8,7,1],
-"execute__scalar__dispatcher_8hpp_source.html":[7,0,3,8,7],
-"execute__util_8hpp.html":[7,0,3,8,8],
-"execute__util_8hpp.html#a2b5c98a91cb51442944469960a201c51":[7,0,3,8,8,7],
-"execute__util_8hpp.html#a2c18b2af7ae9cc51b3043a037d1a9392":[7,0,3,8,8,1],
-"execute__util_8hpp.html#a420ee63edc572707098f89a93ebda6d8":[7,0,3,8,8,4],
-"execute__util_8hpp.html#a683bf651d720e1f98b068f338decd44e":[7,0,3,8,8,8],
-"execute__util_8hpp.html#a787b1a16dbfa7603d9b56755e9c47763":[7,0,3,8,8,2],
-"execute__util_8hpp.html#a9a26383bde576fcd27221a4c186d49ad":[7,0,3,8,8,3],
-"execute__util_8hpp.html#aa5e683dd98d9557be81d2abeefcf5d4b":[7,0,3,8,8,0],
-"execute__util_8hpp.html#af3cde7e8defdd2ac5d1888e98382602a":[7,0,3,8,8,5],
-"execute__util_8hpp.html#af5bfe6adf6edc8107b384ab54f8b6d04":[7,0,3,8,8,9],
-"execute__util_8hpp.html#afc342ce110f98120b991fd5ee03bc3cb":[7,0,3,8,8,6],
-"execute__util_8hpp_source.html":[7,0,3,8,8],
-"execute__vector__dispatcher_8hpp.html":[7,0,3,8,9],
-"execute__vector__dispatcher_8hpp.html#a45eff9c59fbae556d7e3295e062cdb4f":[7,0,3,8,9,0],
 "execute__vector__dispatcher_8hpp.html#a6512297240413f8cb40fd0e7341f2319":[7,0,3,8,9,1],
 "execute__vector__dispatcher_8hpp.html#a6da29ab11b7b25e95f3bbd6ec0a129e0":[7,0,3,8,9,2],
 "execute__vector__dispatcher_8hpp.html#a73dab38c6aa13429092ea2450f888914":[7,0,3,8,9,3],
@@ -93,9 +28,9 @@ var NAVTREEINDEX11 =
 "fft__1d_8cpp.html#a10dea82a2fa07d8d38107391a60965cf":[7,0,2,0,4,13],
 "fft__1d_8cpp.html#a130b38a8dcc95afd21cc3937e996fd81":[7,0,2,0,4,20],
 "fft__1d_8cpp.html#a23a4f0ce6452f4e3e946dddf0ae77b7e":[7,0,2,0,4,17],
-"fft__1d_8cpp.html#a2a45245a8d0c1b133d9876722dfb2b7e":[7,0,2,0,4,3],
 "fft__1d_8cpp.html#a3042870eb8881681860b088156ccf079":[7,0,2,0,4,11],
 "fft__1d_8cpp.html#a43f5046b412bf346fe3821f020ce36b8":[7,0,2,0,4,19],
+"fft__1d_8cpp.html#a4b189d809e837b0a80d17a81f0649314":[7,0,2,0,4,1],
 "fft__1d_8cpp.html#a50090af3f56c8a964b17ccd9ea6ba500":[7,0,2,0,4,26],
 "fft__1d_8cpp.html#a56353420d188d1181ae49bf69283b497":[7,0,2,0,4,14],
 "fft__1d_8cpp.html#a6a4a1ee00ce74b6815ae3c9b8e00d10e":[7,0,2,0,4,23],
@@ -108,11 +43,11 @@ var NAVTREEINDEX11 =
 "fft__1d_8cpp.html#ac6e604e018809020ccd77546f3329e77":[7,0,2,0,4,10],
 "fft__1d_8cpp.html#acaa4a4c5600c798706da45006e3b7210":[7,0,2,0,4,4],
 "fft__1d_8cpp.html#ace9acba72e03f317c16a9d6b4d888f73":[7,0,2,0,4,5],
+"fft__1d_8cpp.html#ad431337acacff9e06c1286095e78f8ac":[7,0,2,0,4,3],
 "fft__1d_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,4,2],
 "fft__1d_8cpp.html#ada492f44f9e83b833972a277284864be":[7,0,2,0,4,7],
 "fft__1d_8cpp.html#ae0bafa0f4214db07d0fd1e5a486caba9":[7,0,2,0,4,21],
 "fft__1d_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,4,18],
-"fft__1d_8cpp.html#aeb9e349ae153e1baf7e55868792ee5af":[7,0,2,0,4,1],
 "fft__1d_8cpp.html#af439f7a9be2c4f5746d22bfecb527bdd":[7,0,2,0,4,24],
 "fft__1d_8cpp.html#af6f913fdc71ad35c8ec4d99fe8671987":[7,0,2,0,4,28],
 "fft__1d_8cpp.html#afc156a01486ed303c46673d3e0976e1f":[7,0,2,0,4,22],
@@ -120,17 +55,17 @@ var NAVTREEINDEX11 =
 "fft__2d_8cpp.html":[7,0,2,0,5],
 "fft__2d_8cpp.html#a05ddc634f34ae8fb86372ff8626a059f":[7,0,2,0,5,9],
 "fft__2d_8cpp.html#a0b36333131d10fd9a0abb3aa21b0b445":[7,0,2,0,5,14],
-"fft__2d_8cpp.html#a2a45245a8d0c1b133d9876722dfb2b7e":[7,0,2,0,5,3],
 "fft__2d_8cpp.html#a3042870eb8881681860b088156ccf079":[7,0,2,0,5,6],
 "fft__2d_8cpp.html#a40b89a65d3390cf44a03717ee53eedca":[7,0,2,0,5,5],
 "fft__2d_8cpp.html#a4461a05ba16b9052cf36f4752c63619e":[7,0,2,0,5,4],
+"fft__2d_8cpp.html#a4b189d809e837b0a80d17a81f0649314":[7,0,2,0,5,1],
 "fft__2d_8cpp.html#a4eb5cd8352d689f5495ec1ba1ea49f0a":[7,0,2,0,5,15],
 "fft__2d_8cpp.html#a50090af3f56c8a964b17ccd9ea6ba500":[7,0,2,0,5,13],
 "fft__2d_8cpp.html#a7cee249cffcd5d7be1c31ea17a284cd9":[7,0,2,0,5,11],
 "fft__2d_8cpp.html#aadad85fa5cbf31466487bb0585d1a769":[7,0,2,0,5,7],
+"fft__2d_8cpp.html#ad431337acacff9e06c1286095e78f8ac":[7,0,2,0,5,3],
 "fft__2d_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5":[7,0,2,0,5,2],
 "fft__2d_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4":[7,0,2,0,5,10],
-"fft__2d_8cpp.html#aeb9e349ae153e1baf7e55868792ee5af":[7,0,2,0,5,1],
 "fft__2d_8cpp.html#af439f7a9be2c4f5746d22bfecb527bdd":[7,0,2,0,5,12],
 "fft__2d_8cpp.html#af6f913fdc71ad35c8ec4d99fe8671987":[7,0,2,0,5,16],
 "fft__2d_8cpp.html#afc07a94f6f8fca89904a2b6a89bc4e14":[7,0,2,0,5,8],
@@ -249,5 +184,70 @@ var NAVTREEINDEX11 =
 "functions_func_i.html":[6,3,1,8],
 "functions_func_j.html":[6,3,1,9],
 "functions_func_k.html":[6,3,1,10],
-"functions_func_l.html":[6,3,1,11]
+"functions_func_l.html":[6,3,1,11],
+"functions_func_m.html":[6,3,1,12],
+"functions_func_n.html":[6,3,1,13],
+"functions_func_o.html":[6,3,1,14],
+"functions_func_p.html":[6,3,1,15],
+"functions_func_q.html":[6,3,1,16],
+"functions_func_r.html":[6,3,1,17],
+"functions_func_s.html":[6,3,1,18],
+"functions_func_t.html":[6,3,1,19],
+"functions_func_u.html":[6,3,1,20],
+"functions_func_v.html":[6,3,1,21],
+"functions_func_w.html":[6,3,1,22],
+"functions_func_z.html":[6,3,1,23],
+"functions_func_~.html":[6,3,1,24],
+"functions_g.html":[6,3,0,6],
+"functions_h.html":[6,3,0,7],
+"functions_i.html":[6,3,0,8],
+"functions_j.html":[6,3,0,9],
+"functions_k.html":[6,3,0,10],
+"functions_l.html":[6,3,0,11],
+"functions_m.html":[6,3,0,12],
+"functions_n.html":[6,3,0,13],
+"functions_o.html":[6,3,0,14],
+"functions_p.html":[6,3,0,15],
+"functions_q.html":[6,3,0,16],
+"functions_r.html":[6,3,0,17],
+"functions_rela.html":[6,3,6],
+"functions_s.html":[6,3,0,18],
+"functions_t.html":[6,3,0,19],
+"functions_type.html":[6,3,3],
+"functions_type.html":[6,3,3,0],
+"functions_type_d.html":[6,3,3,1],
+"functions_type_e.html":[6,3,3,2],
+"functions_type_h.html":[6,3,3,3],
+"functions_type_i.html":[6,3,3,4],
+"functions_type_m.html":[6,3,3,5],
+"functions_type_n.html":[6,3,3,6],
+"functions_type_o.html":[6,3,3,7],
+"functions_type_p.html":[6,3,3,8],
+"functions_type_r.html":[6,3,3,9],
+"functions_type_s.html":[6,3,3,10],
+"functions_type_t.html":[6,3,3,11],
+"functions_type_v.html":[6,3,3,12],
+"functions_u.html":[6,3,0,20],
+"functions_v.html":[6,3,0,21],
+"functions_vars.html":[6,3,2,0],
+"functions_vars.html":[6,3,2],
+"functions_vars_b.html":[6,3,2,1],
+"functions_vars_c.html":[6,3,2,2],
+"functions_vars_d.html":[6,3,2,3],
+"functions_vars_e.html":[6,3,2,4],
+"functions_vars_g.html":[6,3,2,5],
+"functions_vars_h.html":[6,3,2,6],
+"functions_vars_i.html":[6,3,2,7],
+"functions_vars_j.html":[6,3,2,8],
+"functions_vars_k.html":[6,3,2,9],
+"functions_vars_l.html":[6,3,2,10],
+"functions_vars_m.html":[6,3,2,11],
+"functions_vars_n.html":[6,3,2,12],
+"functions_vars_o.html":[6,3,2,13],
+"functions_vars_p.html":[6,3,2,14],
+"functions_vars_r.html":[6,3,2,15],
+"functions_vars_s.html":[6,3,2,16],
+"functions_vars_t.html":[6,3,2,17],
+"functions_vars_v.html":[6,3,2,18],
+"functions_vars_w.html":[6,3,2,19]
 };
