@@ -1,112 +1,5 @@
 var NAVTREEINDEX18 =
 {
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1scrapper.html":[5,0,1,2,1,0,2,0,1,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[5,0,1,2,1,0,2,0,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[6,0,0,2,0,0,2,0,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands_1_1tahiti.html":[5,0,1,2,1,0,2,0,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[5,0,1,2,1,0,2,0,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[6,0,0,2,0,0,2,0,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[5,0,1,2,1,0,2,0,3,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[5,0,1,2,1,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[5,0,1,2,1,0,2,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[6,0,0,2,0,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[5,0,1,2,1,0,2,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[6,0,0,2,0,0,2,1,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[5,0,1,2,1,0,2,2,0,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__470.html":[5,0,1,2,1,0,2,2,0,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__580.html":[5,0,1,2,1,0,2,2,0,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1tesla__c2050.html":[5,0,1,2,1,0,2,2,0,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[6,0,0,2,0,0,2,1,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[5,0,1,2,1,0,2,2,1],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler_1_1tesla__k20m.html":[5,0,1,2,1,0,2,2,1,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[6,0,0,2,0,0,2,1,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell.html":[5,0,1,2,1,0,2,2,2],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1maxwell_1_1geforce__gtx__750__ti.html":[5,0,1,2,1,0,2,2,2,0],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[6,0,0,2,0,0,2,1,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[5,0,1,2,1,0,2,2,3],
-"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
-"namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
-"namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
-"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
-"namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
-"namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
-"namespaceviennacl_1_1io.html":[6,0,0,3],
-"namespaceviennacl_1_1io.html":[5,0,1,3],
-"namespaceviennacl_1_1io_1_1detail.html":[5,0,1,3,0],
-"namespaceviennacl_1_1io_1_1tag.html":[5,0,1,3,1],
-"namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
-"namespaceviennacl_1_1linalg.html":[6,0,0,4],
-"namespaceviennacl_1_1linalg.html":[5,0,1,4],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
-"namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1amg.html":[5,0,1,4,0,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,1],
-"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,1,0],
-"namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
-"namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
-"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[5,0,1,4,1,0],
-"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[6,0,0,4,1,0],
-"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[5,0,1,4,1,1],
-"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
-"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[5,0,1,4,1,2],
-"namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
-"namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1amg.html":[5,0,1,4,2,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1amg.html":[6,0,0,4,2,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,1],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,1],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,1,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,1,0],
-"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,1,0,0],
-"namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
-"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1amg.html":[5,0,1,4,4,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,1],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,2],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
-"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,2,0],
-"namespaceviennacl_1_1ocl.html":[6,0,0,5],
-"namespaceviennacl_1_1ocl.html":[5,0,1,5],
-"namespaceviennacl_1_1result__of.html":[6,0,0,6],
-"namespaceviennacl_1_1result__of.html":[5,0,1,6],
-"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
-"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
-"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
-"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
-"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
-"namespaceviennacl_1_1tools.html":[6,0,0,8],
-"namespaceviennacl_1_1tools.html":[5,0,1,8],
-"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
-"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
-"namespaceviennacl_1_1traits.html":[6,0,0,9],
-"namespaceviennacl_1_1traits.html":[5,0,1,9],
-"nmf_8cpp-example.html":[8,25],
-"nmf_8hpp.html":[7,0,3,4,28],
-"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,28,0],
-"nmf_8hpp_source.html":[7,0,3,4,28],
-"norm__1_8hpp.html":[7,0,3,4,29],
-"norm__1_8hpp.html#a18799037aaa2e6b5e1778cdf203a0274":[7,0,3,4,29,1],
-"norm__1_8hpp.html#a2efad0d090dde0c127fa8b25a73836e4":[7,0,3,4,29,0],
-"norm__1_8hpp.html#ab5b81d05ed5510a3142a5f29e8b2525f":[7,0,3,4,29,2],
-"norm__1_8hpp_source.html":[7,0,3,4,29],
-"norm__2_8hpp.html":[7,0,3,4,30],
-"norm__2_8hpp.html#a2a22bc2566ec601883db764cf08950c9":[7,0,3,4,30,2],
-"norm__2_8hpp.html#abdb24aada7fa315529db8931ed08cd5b":[7,0,3,4,30,1],
-"norm__2_8hpp.html#ae46f15d01c01f92a153b3f555a15096b":[7,0,3,4,30,0],
-"norm__2_8hpp_source.html":[7,0,3,4,30],
-"norm__frobenius_8hpp.html":[7,0,3,4,31],
-"norm__frobenius_8hpp.html#a67813d48ed274df9fc19e6aad99fc761":[7,0,3,4,31,0],
-"norm__frobenius_8hpp_source.html":[7,0,3,4,31],
-"norm__inf_8hpp.html":[7,0,3,4,32],
-"norm__inf_8hpp.html#a3097c09e7f5ec6aa812420965f147f69":[7,0,3,4,32,1],
-"norm__inf_8hpp.html#ae4de9152d556e89d823eb47a683ead11":[7,0,3,4,32,0],
-"norm__inf_8hpp.html#af6ac490ffc6af2faebcc33724bba120e":[7,0,3,4,32,2],
-"norm__inf_8hpp_source.html":[7,0,3,4,32],
-"ocl_2context_8hpp.html":[7,0,3,7,2],
 "ocl_2context_8hpp_source.html":[7,0,3,7,2],
 "ocl_2forwards_8h.html":[7,0,3,7,7],
 "ocl_2forwards_8h.html#a16fc917445ce2010e7b16fbc968771b7":[7,0,3,7,7,6],
@@ -249,5 +142,112 @@ var NAVTREEINDEX18 =
 "opencl_2kernels_2bisect_8hpp.html#abc6b25fb3693f18d024c5a1615852428":[7,0,3,4,3,0,1,21],
 "opencl_2kernels_2bisect_8hpp.html#acd7b8f4a45a0a33a994c89589efd9cf0":[7,0,3,4,3,0,1,10],
 "opencl_2kernels_2bisect_8hpp.html#ae8638f026e01f96697536552db93212f":[7,0,3,4,3,0,1,11],
-"opencl_2kernels_2bisect_8hpp.html#af493d04690d488d12a9e8b5b671bfce2":[7,0,3,4,3,0,1,13]
+"opencl_2kernels_2bisect_8hpp.html#af493d04690d488d12a9e8b5b671bfce2":[7,0,3,4,3,0,1,13],
+"opencl_2kernels_2bisect_8hpp.html#af691d922a1d82dbc23382b2b3042366b":[7,0,3,4,3,0,1,25],
+"opencl_2kernels_2bisect_8hpp.html#aff62149c62908e2fa37bfbf85a4a5cdf":[7,0,3,4,3,0,1,22],
+"opencl_2kernels_2bisect_8hpp_source.html":[7,0,3,4,3,0,1],
+"opencl_2kernels_2ilu_8hpp.html":[7,0,3,4,3,0,8],
+"opencl_2kernels_2ilu_8hpp.html#a1a223cf7316024cd6027a4ab5482ba55":[7,0,3,4,3,0,8,10],
+"opencl_2kernels_2ilu_8hpp.html#a250af558e33347dfe02d1396a046e527":[7,0,3,4,3,0,8,8],
+"opencl_2kernels_2ilu_8hpp.html#a39aa2018ede459e7933c158c5509d2a2":[7,0,3,4,3,0,8,5],
+"opencl_2kernels_2ilu_8hpp.html#a46dbdc4b33b0ee817c4be125201ce9d6":[7,0,3,4,3,0,8,4],
+"opencl_2kernels_2ilu_8hpp.html#a4c499442d4874c1bb2d01d50596f209f":[7,0,3,4,3,0,8,2],
+"opencl_2kernels_2ilu_8hpp.html#a580b4af031de163696de2e7a31760e1e":[7,0,3,4,3,0,8,1],
+"opencl_2kernels_2ilu_8hpp.html#aa50278d751dfa0d29114d81adfe844f0":[7,0,3,4,3,0,8,9],
+"opencl_2kernels_2ilu_8hpp.html#aaed657cc88d051620e4f2008ac696f1c":[7,0,3,4,3,0,8,3],
+"opencl_2kernels_2ilu_8hpp.html#ac052aff9b87d0ef20a1144a45ee6b619":[7,0,3,4,3,0,8,6],
+"opencl_2kernels_2ilu_8hpp.html#ad01c23f62a318c9299c8748fcb335fd7":[7,0,3,4,3,0,8,7],
+"opencl_2kernels_2ilu_8hpp_source.html":[7,0,3,4,3,0,8],
+"opencl_2kernels_2nmf_8hpp.html":[7,0,3,4,3,0,13],
+"opencl_2kernels_2nmf_8hpp.html#a2a18b14d636474012cbb5cd6c160c282":[7,0,3,4,3,0,13,1],
+"opencl_2kernels_2nmf_8hpp_source.html":[7,0,3,4,3,0,13],
+"opencl_2kernels_2spai_8hpp.html":[7,0,3,4,3,0,17],
+"opencl_2kernels_2spai_8hpp.html#a0ef446958eadb7566af5af164c42d753":[7,0,3,4,3,0,17,6],
+"opencl_2kernels_2spai_8hpp.html#a46c06e71a895b596b14c63ebc30d6da0":[7,0,3,4,3,0,17,5],
+"opencl_2kernels_2spai_8hpp.html#a59c4e99f39339ce7adfbb4793ec9a90f":[7,0,3,4,3,0,17,4],
+"opencl_2kernels_2spai_8hpp.html#a684d46d7a6d25da9315a650389a6b9a6":[7,0,3,4,3,0,17,8],
+"opencl_2kernels_2spai_8hpp.html#a6fc75b18244da56426784cbf789c030c":[7,0,3,4,3,0,17,1],
+"opencl_2kernels_2spai_8hpp.html#a8aa3b4bed4795a77017bf4419fd3b180":[7,0,3,4,3,0,17,3],
+"opencl_2kernels_2spai_8hpp.html#a947e6322493e8087cfd86d03fd858189":[7,0,3,4,3,0,17,2],
+"opencl_2kernels_2spai_8hpp.html#af432061aaf6283a75ec3b81ac0ab0f48":[7,0,3,4,3,0,17,7],
+"opencl_2kernels_2spai_8hpp_source.html":[7,0,3,4,3,0,17],
+"opencl_2kernels_2svd_8hpp.html":[7,0,3,4,3,0,18],
+"opencl_2kernels_2svd_8hpp.html#a198d151faa9ed845841dd6e54c4d1720":[7,0,3,4,3,0,18,2],
+"opencl_2kernels_2svd_8hpp.html#a2314bf6a3ca995899978c2504eacdb4b":[7,0,3,4,3,0,18,8],
+"opencl_2kernels_2svd_8hpp.html#a2b6175d3f83cd821e06daab3ac1ad466":[7,0,3,4,3,0,18,1],
+"opencl_2kernels_2svd_8hpp.html#a3e7ada351d176c2c90a63032f3eabdcf":[7,0,3,4,3,0,18,6],
+"opencl_2kernels_2svd_8hpp.html#a71cf92278b63ea07b23d70621e64221e":[7,0,3,4,3,0,18,3],
+"opencl_2kernels_2svd_8hpp.html#a8506b81f8f6e700161e4a67d4f2c8dc2":[7,0,3,4,3,0,18,10],
+"opencl_2kernels_2svd_8hpp.html#a94f9fe10c3a77798a44a0dcce9480e1b":[7,0,3,4,3,0,18,14],
+"opencl_2kernels_2svd_8hpp.html#a986156e7f4ee31480fbe542ec4890c46":[7,0,3,4,3,0,18,9],
+"opencl_2kernels_2svd_8hpp.html#aa02c92f95d3fa5183013ce74756249cd":[7,0,3,4,3,0,18,5],
+"opencl_2kernels_2svd_8hpp.html#aa6d359797763e880a73bd22c1f87fc10":[7,0,3,4,3,0,18,11],
+"opencl_2kernels_2svd_8hpp.html#abb44553f086222188bf3d0413bcc634c":[7,0,3,4,3,0,18,13],
+"opencl_2kernels_2svd_8hpp.html#ac6a619337d349abc2e69236f4bba7416":[7,0,3,4,3,0,18,4],
+"opencl_2kernels_2svd_8hpp.html#acd1b7bfd307875135e20920575174e4e":[7,0,3,4,3,0,18,12],
+"opencl_2kernels_2svd_8hpp.html#afb2fe1df86a78f4f2f97742f6b463b29":[7,0,3,4,3,0,18,7],
+"opencl_2kernels_2svd_8hpp_source.html":[7,0,3,4,3,0,18],
+"opencl_2matrix__operations_8hpp.html":[7,0,3,4,3,8],
+"opencl_2matrix__operations_8hpp.html#a16366a34aab924b279bcd2b4f403a159":[7,0,3,4,3,8,23],
+"opencl_2matrix__operations_8hpp.html#a18a93d38ca1eff472149093974edb5cb":[7,0,3,4,3,8,22],
+"opencl_2matrix__operations_8hpp.html#a1b350268a70fb6d032bb0360a1157584":[7,0,3,4,3,8,18],
+"opencl_2matrix__operations_8hpp.html#a24049445243113b8aff433e4dd6d3c01":[7,0,3,4,3,8,31],
+"opencl_2matrix__operations_8hpp.html#a2db93608afb5e8b93a0ed5c1df92b61c":[7,0,3,4,3,8,16],
+"opencl_2matrix__operations_8hpp.html#a36588f4299e97d8505d17da3b5ddb266":[7,0,3,4,3,8,2],
+"opencl_2matrix__operations_8hpp.html#a37fbfb949aae5a860d0308717e5b4ff5":[7,0,3,4,3,8,3],
+"opencl_2matrix__operations_8hpp.html#a3ca5ea18659312a9857abb74504465e1":[7,0,3,4,3,8,19],
+"opencl_2matrix__operations_8hpp.html#a42d8cc5fddc8d8fe7819428f3570d8d7":[7,0,3,4,3,8,11],
+"opencl_2matrix__operations_8hpp.html#a4b7f757f629ae312a7e949f73aec7eb8":[7,0,3,4,3,8,17],
+"opencl_2matrix__operations_8hpp.html#a4e7dbe07ee5433438da8435cdb1a08ee":[7,0,3,4,3,8,5],
+"opencl_2matrix__operations_8hpp.html#a5588877cfe1610e81fff4f915fe7ada8":[7,0,3,4,3,8,20],
+"opencl_2matrix__operations_8hpp.html#a5d5b4fe8827c4d4da9f2df19cf8ee971":[7,0,3,4,3,8,6],
+"opencl_2matrix__operations_8hpp.html#a656519064a982e5904b5a66b5e9c2785":[7,0,3,4,3,8,32],
+"opencl_2matrix__operations_8hpp.html#a6c692160febc1bf0c8c1b3f14609843b":[7,0,3,4,3,8,26],
+"opencl_2matrix__operations_8hpp.html#a72bf0d80c0608b5645d06703c7807253":[7,0,3,4,3,8,25],
+"opencl_2matrix__operations_8hpp.html#a786d68766ad5e6b6fb239274efde0bf7":[7,0,3,4,3,8,13],
+"opencl_2matrix__operations_8hpp.html#a7a3df357024a5414f6731b34ee275c80":[7,0,3,4,3,8,1],
+"opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45":[7,0,3,4,3,8,27],
+"opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f":[7,0,3,4,3,8,30],
+"opencl_2matrix__operations_8hpp.html#a8dd7386eb70a19d9d818b5ba57512d57":[7,0,3,4,3,8,8],
+"opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565":[7,0,3,4,3,8,24],
+"opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95":[7,0,3,4,3,8,12],
+"opencl_2matrix__operations_8hpp.html#aa42a34c8e153495ac317c599824123d4":[7,0,3,4,3,8,15],
+"opencl_2matrix__operations_8hpp.html#aba191367e3a3d0f0f603df72046e09e7":[7,0,3,4,3,8,9],
+"opencl_2matrix__operations_8hpp.html#ac5c16bfd288a10e6a2897b86747df98b":[7,0,3,4,3,8,21],
+"opencl_2matrix__operations_8hpp.html#acb933cf08a45fa63d016111dfafa4791":[7,0,3,4,3,8,14],
+"opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170":[7,0,3,4,3,8,10],
+"opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c":[7,0,3,4,3,8,28],
+"opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646":[7,0,3,4,3,8,29],
+"opencl_2matrix__operations_8hpp.html#ae63e075deb555fd0ef79218d5a913d9a":[7,0,3,4,3,8,7],
+"opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379":[7,0,3,4,3,8,4],
+"opencl_2matrix__operations_8hpp.html#aea7225cb76eda44509d42ec0e824a184":[7,0,3,4,3,8,0],
+"opencl_2matrix__operations_8hpp_source.html":[7,0,3,4,3,8],
+"opencl_2misc__operations_8hpp.html":[7,0,3,4,3,9],
+"opencl_2misc__operations_8hpp.html#ad939e77692cf9b3c5746b11ba9ff024c":[7,0,3,4,3,9,0],
+"opencl_2misc__operations_8hpp_source.html":[7,0,3,4,3,9],
+"opencl_2nmf__operations_8hpp.html":[7,0,3,4,3,10],
+"opencl_2nmf__operations_8hpp.html#a9f0c073c618b76460027457d7331ba33":[7,0,3,4,3,10,0],
+"opencl_2nmf__operations_8hpp_source.html":[7,0,3,4,3,10],
+"opencl_2scalar__operations_8hpp.html":[7,0,3,4,3,11],
+"opencl_2scalar__operations_8hpp.html#a11ed680640c9598490f6a98c16828d77":[7,0,3,4,3,11,0],
+"opencl_2scalar__operations_8hpp.html#a54a07e7d66ac02c7879af93ce5eb2336":[7,0,3,4,3,11,2],
+"opencl_2scalar__operations_8hpp.html#ac02d4b9c2ac529bcd8a76c081c9702eb":[7,0,3,4,3,11,1],
+"opencl_2scalar__operations_8hpp.html#af17184fcbab9dbaa872694436946a174":[7,0,3,4,3,11,3],
+"opencl_2scalar__operations_8hpp_source.html":[7,0,3,4,3,11],
+"opencl_2sparse__matrix__operations_8hpp.html":[7,0,3,4,3,12],
+"opencl_2sparse__matrix__operations_8hpp.html#a0a16aa6006192d8f3f127b48bfcf9ca5":[7,0,3,4,3,12,19],
+"opencl_2sparse__matrix__operations_8hpp.html#a0a236936156b4950d9c3a00899d24db4":[7,0,3,4,3,12,13],
+"opencl_2sparse__matrix__operations_8hpp.html#a144fd7dc25be2029356c24f07f281edc":[7,0,3,4,3,12,0],
+"opencl_2sparse__matrix__operations_8hpp.html#a1b40072f44f7e9bd156d9560ca7ee30e":[7,0,3,4,3,12,11],
+"opencl_2sparse__matrix__operations_8hpp.html#a1fcccd84db8c1659e268e6d7719df94e":[7,0,3,4,3,12,26],
+"opencl_2sparse__matrix__operations_8hpp.html#a20c8cd535c54bba79b1912abce227d04":[7,0,3,4,3,12,23],
+"opencl_2sparse__matrix__operations_8hpp.html#a256a599dedd093618c9936e85a75b3d4":[7,0,3,4,3,12,25],
+"opencl_2sparse__matrix__operations_8hpp.html#a3a97d7d39ed0063efc0e2a7184c63711":[7,0,3,4,3,12,5],
+"opencl_2sparse__matrix__operations_8hpp.html#a57184647b968d0eb667cf38f20f08792":[7,0,3,4,3,12,21],
+"opencl_2sparse__matrix__operations_8hpp.html#a58540b3dfdf2451f59a8d69b0d503977":[7,0,3,4,3,12,8],
+"opencl_2sparse__matrix__operations_8hpp.html#a66050024d4fd7fe421fdec79b082268e":[7,0,3,4,3,12,3],
+"opencl_2sparse__matrix__operations_8hpp.html#a720d4cb00c0c08602f62608ecaa9a835":[7,0,3,4,3,12,1],
+"opencl_2sparse__matrix__operations_8hpp.html#a72fb925402b34c304e02fb4feafb8bc9":[7,0,3,4,3,12,17],
+"opencl_2sparse__matrix__operations_8hpp.html#a7f4c33a310f17f3379aac2f88348f85b":[7,0,3,4,3,12,7],
+"opencl_2sparse__matrix__operations_8hpp.html#a82d0e161d210b339dbda37d6ebc6318f":[7,0,3,4,3,12,2]
 };
