@@ -1,19 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"classviennacl_1_1coordinate__matrix.html#a9cde8a8c5cb1516c5503d011388daed4":[6,0,0,22,4],
-"classviennacl_1_1coordinate__matrix.html#a9fd9168600c330faa69cae2626509602":[6,0,0,22,2],
-"classviennacl_1_1coordinate__matrix.html#ad091412ca52bb131234464ed3f5b103c":[6,0,0,22,14],
-"classviennacl_1_1coordinate__matrix.html#ad4218882f3bd97eeff6d81b575ea1e3c":[6,0,0,22,1],
-"classviennacl_1_1coordinate__matrix.html#ad5b57c8ab8bcc8d839aba53be7cb1463":[6,0,0,22,5],
-"classviennacl_1_1coordinate__matrix.html#aeb74dd2ab673d7912a17f60777e9bf6c":[6,0,0,22,9],
-"classviennacl_1_1cuda__not__available__exception.html":[6,0,0,23],
-"classviennacl_1_1cuda__not__available__exception.html#a8e4a228218ec828c3d74facbd8388df0":[6,0,0,23,1],
-"classviennacl_1_1cuda__not__available__exception.html#a941a849d4b445e91c19f14cb3e7d1419":[6,0,0,23,0],
-"classviennacl_1_1cuda__not__available__exception.html#a94c488fd1c10322c3f594bdf7946a859":[6,0,0,23,2],
-"classviennacl_1_1device__specific_1_1binary__leaf.html":[6,0,0,2,3],
-"classviennacl_1_1device__specific_1_1binary__leaf.html#a11ef22c2e5b36de4e5d350766e50e04f":[6,0,0,2,3,1],
-"classviennacl_1_1device__specific_1_1binary__leaf.html#a616051ebd6114784ecba182531e1ad9f":[6,0,0,2,3,3],
-"classviennacl_1_1device__specific_1_1binary__leaf.html#aaf20a0f61286e07400f4daef62c4ad9f":[6,0,0,2,3,2],
 "classviennacl_1_1device__specific_1_1binary__leaf.html#adb5951a50055382b42d27d988e4f30a6":[6,0,0,2,3,0],
 "classviennacl_1_1device__specific_1_1bind__all__unique.html":[6,0,0,2,4],
 "classviennacl_1_1device__specific_1_1bind__all__unique.html#a7c2f476d12792e3b27780e3f3b4046d3":[6,0,0,2,4,2],
@@ -105,66 +91,51 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1device__specific_1_1mapped__vector.html#ae3fdfc4cb7c19c3d4311dc82ec113904":[6,0,0,2,27,0],
 "classviennacl_1_1device__specific_1_1mapped__vector__diag.html":[6,0,0,2,28],
 "classviennacl_1_1device__specific_1_1mapped__vector__diag.html#a37725e711ee3adce9928e8951dc25439":[6,0,0,2,28,0],
-"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html":[6,0,0,2,29],
-"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html#a2e16f2f724b74614f60617b54ca2acac":[6,0,0,2,29,1],
-"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html#aa09905d23f6d94e73d3b06d27b7ce78d":[6,0,0,2,29,0],
-"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html#aa96d9f2ac2ea1e330e6c5aa8ddce578e":[6,0,0,2,29,2],
-"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html#afa3c5d69fb3546ed8ee633b6ed1a442b":[6,0,0,2,29,3],
-"classviennacl_1_1device__specific_1_1matrix__axpy__template.html":[6,0,0,2,30],
-"classviennacl_1_1device__specific_1_1matrix__axpy__template.html#a12d1fe1746cfbde6fff6163b0cf15c75":[6,0,0,2,30,1],
-"classviennacl_1_1device__specific_1_1matrix__axpy__template.html#a3b489a3a6960699bfb85ffae95273882":[6,0,0,2,30,2],
-"classviennacl_1_1device__specific_1_1matrix__axpy__template.html#aea91e39d4f34f999adc215875681f2d1":[6,0,0,2,30,0],
-"classviennacl_1_1device__specific_1_1matrix__product__template.html":[6,0,0,2,32],
-"classviennacl_1_1device__specific_1_1matrix__product__template.html#adb611fc879d3ca49a09d5c153240b620":[6,0,0,2,32,0],
-"classviennacl_1_1device__specific_1_1matrix__product__template.html#adbdee8eaf37ad244963f8c7e345624af":[6,0,0,2,32,1],
-"classviennacl_1_1device__specific_1_1reduction__template.html":[6,0,0,2,34],
-"classviennacl_1_1device__specific_1_1reduction__template.html#a259dc65aea9ba0534c06eee6d340e71a":[6,0,0,2,34,1],
-"classviennacl_1_1device__specific_1_1reduction__template.html#a387c3298d7df041316e29d0f22c0bea0":[6,0,0,2,34,0],
-"classviennacl_1_1device__specific_1_1row__wise__reduction__template.html":[6,0,0,2,36],
-"classviennacl_1_1device__specific_1_1row__wise__reduction__template.html#a27b5b2c06f3ec88c10726a40a25c1030":[6,0,0,2,36,1],
-"classviennacl_1_1device__specific_1_1row__wise__reduction__template.html#ac77f0580e344b4f4f9e73a6d9c16fd5f":[6,0,0,2,36,0],
-"classviennacl_1_1device__specific_1_1statements__container.html":[6,0,0,2,37],
-"classviennacl_1_1device__specific_1_1statements__container.html#a186e8a37443fdbc8deca9fc3f5fc64d5":[6,0,0,2,37,5],
-"classviennacl_1_1device__specific_1_1statements__container.html#a2ee4b4db81b4960e0c3a805984331f71":[6,0,0,2,37,4],
-"classviennacl_1_1device__specific_1_1statements__container.html#a4128093f62c7867fc9145c50d9687be3":[6,0,0,2,37,2],
-"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1":[6,0,0,2,37,1],
-"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1acc9db2573a2cc4f40b3c0affee6a1225":[6,0,0,2,37,1,0],
-"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1ad10a771fce71c517b21d54011e2a1a2a":[6,0,0,2,37,1,1],
-"classviennacl_1_1device__specific_1_1statements__container.html#a77ce2e7a0060837808fd2643577c9d79":[6,0,0,2,37,0],
-"classviennacl_1_1device__specific_1_1statements__container.html#ac1aa567292f542539cb671ba204204dc":[6,0,0,2,37,6],
-"classviennacl_1_1device__specific_1_1statements__container.html#aeb2549ca85167d6e04da6844205ec0ca":[6,0,0,2,37,3],
-"classviennacl_1_1device__specific_1_1symbolic__binder.html":[6,0,0,2,38],
-"classviennacl_1_1device__specific_1_1symbolic__binder.html#a6a21d41bffc7e3f247f9cdf82e7a54a3":[6,0,0,2,38,1],
-"classviennacl_1_1device__specific_1_1symbolic__binder.html#a9b5f495b51c144ff02929ef4ecbbe2cf":[6,0,0,2,38,0],
-"classviennacl_1_1device__specific_1_1symbolic__binder.html#aca3fec6c8fc0cfdb02ae04c6b6625601":[6,0,0,2,38,2],
-"classviennacl_1_1device__specific_1_1template__base.html":[6,0,0,2,39],
-"classviennacl_1_1device__specific_1_1template__base.html#a18401969ee8142450a491085e92affe3":[6,0,0,2,39,4],
-"classviennacl_1_1device__specific_1_1template__base.html#a1f063c861f03703b8d7c039698f754d5":[6,0,0,2,39,8],
-"classviennacl_1_1device__specific_1_1template__base.html#a313b8339e22e2a1fdd5c2c885619f1ef":[6,0,0,2,39,9],
-"classviennacl_1_1device__specific_1_1template__base.html#a315ba8b58a1c0c2bd3d60383aab0fb88":[6,0,0,2,39,7],
-"classviennacl_1_1device__specific_1_1template__base.html#a83880c9e4b8f554dd6d26a112b54d08b":[6,0,0,2,39,3],
-"classviennacl_1_1device__specific_1_1template__base.html#a86aa320138e6af384f6cb7bf2309c265":[6,0,0,2,39,5],
-"classviennacl_1_1device__specific_1_1template__base.html#ad2ea7f528b5c3cad8bee3ac4fefc3a3b":[6,0,0,2,39,6],
-"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html":[6,0,0,2,39,0],
-"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a28538108e34d4f883c824237496b08de":[6,0,0,2,39,0,0],
-"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a5006fdfa37fab3bc400e36b3ebbbe178":[6,0,0,2,39,0,1],
-"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a981789b4678fc6b6c6d18eab7da5d049":[6,0,0,2,39,0,2],
-"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#ab3a32adb953850e788d550006680a25a":[6,0,0,2,39,0,3],
-"classviennacl_1_1device__specific_1_1template__base__impl.html":[6,0,0,2,40],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#a1379e9994ab8fa2e9b8bc8a748e48cb3":[6,0,0,2,40,3],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#a68e0fd6874120ec954fe8ae5f809e090":[6,0,0,2,40,2],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#aaea985e5300ec4a2f938a98bf5585d31":[6,0,0,2,40,1],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#ac1a2b570d477d82f9cbd3d88dcb6e8c2":[6,0,0,2,40,5],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#ad3dd3fddf4d52fd09cac0118cc993c70":[6,0,0,2,40,4],
-"classviennacl_1_1device__specific_1_1template__base__impl.html#addc1be148eddeb501c37091e88363098":[6,0,0,2,40,0],
+"classviennacl_1_1device__specific_1_1matrix__product__template.html":[6,0,0,2,30],
+"classviennacl_1_1device__specific_1_1matrix__product__template.html#adb611fc879d3ca49a09d5c153240b620":[6,0,0,2,30,0],
+"classviennacl_1_1device__specific_1_1matrix__product__template.html#adbdee8eaf37ad244963f8c7e345624af":[6,0,0,2,30,1],
+"classviennacl_1_1device__specific_1_1statements__container.html":[6,0,0,2,31],
+"classviennacl_1_1device__specific_1_1statements__container.html#a186e8a37443fdbc8deca9fc3f5fc64d5":[6,0,0,2,31,5],
+"classviennacl_1_1device__specific_1_1statements__container.html#a2ee4b4db81b4960e0c3a805984331f71":[6,0,0,2,31,4],
+"classviennacl_1_1device__specific_1_1statements__container.html#a4128093f62c7867fc9145c50d9687be3":[6,0,0,2,31,2],
+"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1":[6,0,0,2,31,1],
+"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1acc9db2573a2cc4f40b3c0affee6a1225":[6,0,0,2,31,1,0],
+"classviennacl_1_1device__specific_1_1statements__container.html#a4c52fdf9acbc50e9ae769e336679d5f1ad10a771fce71c517b21d54011e2a1a2a":[6,0,0,2,31,1,1],
+"classviennacl_1_1device__specific_1_1statements__container.html#a77ce2e7a0060837808fd2643577c9d79":[6,0,0,2,31,0],
+"classviennacl_1_1device__specific_1_1statements__container.html#ac1aa567292f542539cb671ba204204dc":[6,0,0,2,31,6],
+"classviennacl_1_1device__specific_1_1statements__container.html#aeb2549ca85167d6e04da6844205ec0ca":[6,0,0,2,31,3],
+"classviennacl_1_1device__specific_1_1symbolic__binder.html":[6,0,0,2,32],
+"classviennacl_1_1device__specific_1_1symbolic__binder.html#a6a21d41bffc7e3f247f9cdf82e7a54a3":[6,0,0,2,32,1],
+"classviennacl_1_1device__specific_1_1symbolic__binder.html#a9b5f495b51c144ff02929ef4ecbbe2cf":[6,0,0,2,32,0],
+"classviennacl_1_1device__specific_1_1symbolic__binder.html#aca3fec6c8fc0cfdb02ae04c6b6625601":[6,0,0,2,32,2],
+"classviennacl_1_1device__specific_1_1template__base.html":[6,0,0,2,33],
+"classviennacl_1_1device__specific_1_1template__base.html#a18401969ee8142450a491085e92affe3":[6,0,0,2,33,4],
+"classviennacl_1_1device__specific_1_1template__base.html#a1f063c861f03703b8d7c039698f754d5":[6,0,0,2,33,8],
+"classviennacl_1_1device__specific_1_1template__base.html#a313b8339e22e2a1fdd5c2c885619f1ef":[6,0,0,2,33,9],
+"classviennacl_1_1device__specific_1_1template__base.html#a315ba8b58a1c0c2bd3d60383aab0fb88":[6,0,0,2,33,7],
+"classviennacl_1_1device__specific_1_1template__base.html#a83880c9e4b8f554dd6d26a112b54d08b":[6,0,0,2,33,3],
+"classviennacl_1_1device__specific_1_1template__base.html#a86aa320138e6af384f6cb7bf2309c265":[6,0,0,2,33,5],
+"classviennacl_1_1device__specific_1_1template__base.html#ad2ea7f528b5c3cad8bee3ac4fefc3a3b":[6,0,0,2,33,6],
+"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html":[6,0,0,2,33,0],
+"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a28538108e34d4f883c824237496b08de":[6,0,0,2,33,0,0],
+"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a5006fdfa37fab3bc400e36b3ebbbe178":[6,0,0,2,33,0,1],
+"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#a981789b4678fc6b6c6d18eab7da5d049":[6,0,0,2,33,0,2],
+"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#ab3a32adb953850e788d550006680a25a":[6,0,0,2,33,0,3],
+"classviennacl_1_1device__specific_1_1template__base__impl.html":[6,0,0,2,34],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#a1379e9994ab8fa2e9b8bc8a748e48cb3":[6,0,0,2,34,3],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#a68e0fd6874120ec954fe8ae5f809e090":[6,0,0,2,34,2],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#aaea985e5300ec4a2f938a98bf5585d31":[6,0,0,2,34,1],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#ac1a2b570d477d82f9cbd3d88dcb6e8c2":[6,0,0,2,34,5],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#ad3dd3fddf4d52fd09cac0118cc993c70":[6,0,0,2,34,4],
+"classviennacl_1_1device__specific_1_1template__base__impl.html#addc1be148eddeb501c37091e88363098":[6,0,0,2,34,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html":[6,0,0,2,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#a5b09f3b2df4b87bfd37955183da2e068":[6,0,0,2,1,0,3],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#a87af629fb274204628a1ad6539c44535":[6,0,0,2,1,0,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#ace084027c47cb4c20b091e33774dcfbd":[6,0,0,2,1,0,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html#adb18331e422fee5141086cad436f265c":[6,0,0,2,1,0,1],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html":[6,0,0,2,1,1],
-"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#a985282bbdfb34ae6777efc4737d45c00":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#ad3a7c359b39226b4c63c4efb7e246b35":[6,0,0,2,1,1,1],
+"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aeafc307c76220bbc238bd7147a884c17":[6,0,0,2,1,1,0],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html#aef355f4ccd06d80399b9561283c66eb6":[6,0,0,2,1,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html":[6,0,0,2,1,2],
 "classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html#a3bd51f61962e2b5ed602d3a19a726cb7":[6,0,0,2,1,2,1],
@@ -191,14 +162,6 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html#aa2a76505b4c45bda548d59feca925d1a":[6,0,0,2,2,17,3],
 "classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html#aaae555431f1866563c9ae8253bcea1db":[6,0,0,2,2,17,4],
 "classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html#ad7761413a92593a764db3dbbd01c5c8f":[6,0,0,2,2,17,1],
-"classviennacl_1_1device__specific_1_1vector__axpy__parameters.html":[6,0,0,2,41],
-"classviennacl_1_1device__specific_1_1vector__axpy__parameters.html#a2c28abc31fcc29a2af1e90144371eeee":[6,0,0,2,41,2],
-"classviennacl_1_1device__specific_1_1vector__axpy__parameters.html#a6b24918cb443d632108b5e963999e9d1":[6,0,0,2,41,0],
-"classviennacl_1_1device__specific_1_1vector__axpy__parameters.html#af40787b9ff352e215522eaba0a11279a":[6,0,0,2,41,1],
-"classviennacl_1_1device__specific_1_1vector__axpy__template.html":[6,0,0,2,42],
-"classviennacl_1_1device__specific_1_1vector__axpy__template.html#a48722b720b0678f89786182b268b9e60":[6,0,0,2,42,0],
-"classviennacl_1_1device__specific_1_1vector__axpy__template.html#a50549ae7334802a367e5568bf9e1b0ea":[6,0,0,2,42,1],
-"classviennacl_1_1device__specific_1_1vector__axpy__template.html#a950bc84f7f5240d3b5fe3d584c9a0bfa":[6,0,0,2,42,2],
 "classviennacl_1_1ell__matrix.html":[6,0,0,25],
 "classviennacl_1_1ell__matrix.html#a0f64e3ac10fd1872162c14c5bc96a60b":[6,0,0,25,7],
 "classviennacl_1_1ell__matrix.html#a1260f11302263435b8f6de4a4c0ef4b6":[6,0,0,25,8],
@@ -220,34 +183,71 @@ var NAVTREEINDEX2 =
 "classviennacl_1_1ell__matrix.html#afeb18c524920cfa52a7d56cd0b31b3c1":[6,0,0,25,18],
 "classviennacl_1_1ell__matrix.html#aff440baf9a08f63a1aa886990aaf406b":[6,0,0,25,5],
 "classviennacl_1_1entry__proxy.html":[6,0,0,27],
-"classviennacl_1_1entry__proxy.html#a1501c30738b60067172267d936c58dcb":[6,0,0,27,6],
-"classviennacl_1_1entry__proxy.html#a37b3fb6e74d991af47f8d32f1dda6c23":[6,0,0,27,4],
-"classviennacl_1_1entry__proxy.html#a48baf86c6dd5f920bc55b011d832788d":[6,0,0,27,2],
-"classviennacl_1_1entry__proxy.html#a59ddb22fd76964d1e5aae646473f9037":[6,0,0,27,10],
-"classviennacl_1_1entry__proxy.html#a5a5957e985504d3e7cf499407f25c9f2":[6,0,0,27,7],
-"classviennacl_1_1entry__proxy.html#a63ef5534007af719594dc60d0c5781f1":[6,0,0,27,1],
-"classviennacl_1_1entry__proxy.html#a771d0d5e6f898d1680b3f8b6059d31ac":[6,0,0,27,8],
-"classviennacl_1_1entry__proxy.html#a7bf17a30153814b8e7855faf18fdd768":[6,0,0,27,0],
-"classviennacl_1_1entry__proxy.html#a8a00214579b33b0f5d6e022cfd10bedd":[6,0,0,27,5],
-"classviennacl_1_1entry__proxy.html#ac21d5341e24b2aa63ed578f8c15afee0":[6,0,0,27,11],
-"classviennacl_1_1entry__proxy.html#ac4d407afb54158096a97a560ec9b169e":[6,0,0,27,9],
-"classviennacl_1_1entry__proxy.html#adc55b3b64bb7f9e78851d294639a17ba":[6,0,0,27,3],
+"classviennacl_1_1entry__proxy.html#a20d1e6598ba396eca5441e81866692bb":[6,0,0,27,6],
+"classviennacl_1_1entry__proxy.html#a42a889aa89772a30c2d58d5588a3ac04":[6,0,0,27,1],
+"classviennacl_1_1entry__proxy.html#a4433439fd4233b8bc585d8d8f2cc7619":[6,0,0,27,3],
+"classviennacl_1_1entry__proxy.html#a5aab26f84f0a0f33a16c801826e8b5aa":[6,0,0,27,0],
+"classviennacl_1_1entry__proxy.html#a719287b50d86b5c8a047af7dbe4a5b3a":[6,0,0,27,4],
+"classviennacl_1_1entry__proxy.html#a7219f5d36ca71d3bab8987747cb77d1c":[6,0,0,27,10],
+"classviennacl_1_1entry__proxy.html#a9e5cbe868cfad0720aba407d149c75e1":[6,0,0,27,7],
+"classviennacl_1_1entry__proxy.html#ab12fabdb323eefb4892edde6f7b3bf16":[6,0,0,27,8],
+"classviennacl_1_1entry__proxy.html#acf681a2389ab0b31b5f660205f39ab77":[6,0,0,27,2],
+"classviennacl_1_1entry__proxy.html#adc3fc7c7cb5e7602eedd2d3b4ce35e1c":[6,0,0,27,5],
+"classviennacl_1_1entry__proxy.html#ae0c4cf27e795235d75556894e677e0af":[6,0,0,27,11],
+"classviennacl_1_1entry__proxy.html#aeb73ef2abb2e995991e5ee4d10dfb099":[6,0,0,27,9],
 "classviennacl_1_1hankel__matrix.html":[6,0,0,29],
-"classviennacl_1_1hankel__matrix.html#a1fbac16688ba2b0a19d01fd7a8fab24f":[6,0,0,29,2],
-"classviennacl_1_1hankel__matrix.html#a2ca803773036e3301662f3a4ced06513":[6,0,0,29,5],
-"classviennacl_1_1hankel__matrix.html#a3a303ed0b61a75c3ffd75112bf61b558":[6,0,0,29,12],
-"classviennacl_1_1hankel__matrix.html#a43654fc305980d2a437769d12d5cc84f":[6,0,0,29,4],
-"classviennacl_1_1hankel__matrix.html#a7e7f884fed71f2788b57a130bcfbf4a0":[6,0,0,29,7],
-"classviennacl_1_1hankel__matrix.html#a993abaae40c5fbb82c3317ae34ac66b2":[6,0,0,29,8],
-"classviennacl_1_1hankel__matrix.html#aaa2c575a8c1610216885136d43625749":[6,0,0,29,10],
-"classviennacl_1_1hankel__matrix.html#aaf5e49a335315a70ff47f3ff8cc4242d":[6,0,0,29,6],
-"classviennacl_1_1hankel__matrix.html#abdb174b8cb98f87d0092b25ebf5a3c64":[6,0,0,29,9],
-"classviennacl_1_1hankel__matrix.html#ac34afa167dfc0fb8dc91757bb677eec9":[6,0,0,29,3],
-"classviennacl_1_1hankel__matrix.html#ae413c0e546c764e3fcf919cb0248739a":[6,0,0,29,11],
-"classviennacl_1_1hankel__matrix.html#af0cf795b18e66655356e2e27fa66d4c7":[6,0,0,29,0],
-"classviennacl_1_1hankel__matrix.html#afd888bb3d2508de274684d1cb8fe5d0b":[6,0,0,29,1],
+"classviennacl_1_1hankel__matrix.html#a20b24d60a29462b8e683e471a1b9dbbc":[6,0,0,29,4],
+"classviennacl_1_1hankel__matrix.html#a2965b9cc1428525b503791ff404ac2f1":[6,0,0,29,12],
+"classviennacl_1_1hankel__matrix.html#a39d10d5bab1e2564a7d34864a5ea38bf":[6,0,0,29,10],
+"classviennacl_1_1hankel__matrix.html#a44bd0dc3e75be825b2383665d1473dbe":[6,0,0,29,8],
+"classviennacl_1_1hankel__matrix.html#a5f49dd26c680c8c03f576cc02f2724f0":[6,0,0,29,3],
+"classviennacl_1_1hankel__matrix.html#a6b584238a8f38c32facfe9dbf3e2792b":[6,0,0,29,0],
+"classviennacl_1_1hankel__matrix.html#a70394fe33c8d39dc5cf0d892cbc4d33d":[6,0,0,29,7],
+"classviennacl_1_1hankel__matrix.html#a724654e6113cca8296d33d3f080c0481":[6,0,0,29,6],
+"classviennacl_1_1hankel__matrix.html#a9336c061fc3ba521106feabe826ae359":[6,0,0,29,9],
+"classviennacl_1_1hankel__matrix.html#abc7d6eeffe38e08ed8374d351b2fc858":[6,0,0,29,2],
+"classviennacl_1_1hankel__matrix.html#abd607e8fd04765fc5693feee660e268c":[6,0,0,29,1],
+"classviennacl_1_1hankel__matrix.html#ad2f2c36d273f68fabc8f0648eb005916":[6,0,0,29,5],
+"classviennacl_1_1hankel__matrix.html#ae1fe055fd4987e7ccc9585eaa169ebb6":[6,0,0,29,11],
 "classviennacl_1_1hyb__matrix.html":[6,0,0,30],
-"classviennacl_1_1hyb__matrix.html#a2b1b27a7e14035e94742129e5b6c00b5":[6,0,0,30,12],
-"classviennacl_1_1hyb__matrix.html#a2f620a72f3f44c563dd9fdcd9c788324":[6,0,0,30,15],
-"classviennacl_1_1hyb__matrix.html#a3863e14e65c82bffbd5ac3f42ae72ffc":[6,0,0,30,7]
+"classviennacl_1_1hyb__matrix.html#a0394426fd3b91afe253b64fbbfee97b1":[6,0,0,30,2],
+"classviennacl_1_1hyb__matrix.html#a24b112fc2e22907c32646227831d443a":[6,0,0,30,3],
+"classviennacl_1_1hyb__matrix.html#a321b40813370fc067e3b49afed3da469":[6,0,0,30,18],
+"classviennacl_1_1hyb__matrix.html#a4b3f5963def504d05e7ab97b972067f0":[6,0,0,30,9],
+"classviennacl_1_1hyb__matrix.html#a71a65b6963fe30384f160f4cf6c189c8":[6,0,0,30,15],
+"classviennacl_1_1hyb__matrix.html#a78944df9433891f6654713dbbf34ed93":[6,0,0,30,4],
+"classviennacl_1_1hyb__matrix.html#a83cb07a6aa15fcf960b40b4a82fdc574":[6,0,0,30,10],
+"classviennacl_1_1hyb__matrix.html#a85c8cfa2f303c11c2e8ebea46e4ea400":[6,0,0,30,11],
+"classviennacl_1_1hyb__matrix.html#a8e95fcc738d25bcbf274dbfd538f000f":[6,0,0,30,16],
+"classviennacl_1_1hyb__matrix.html#a98dfc47bcf5178ccd6c888f39b2ec0e4":[6,0,0,30,5],
+"classviennacl_1_1hyb__matrix.html#a9a02c98d000f3d316c297300a8117246":[6,0,0,30,0],
+"classviennacl_1_1hyb__matrix.html#ab5f077832dd0efade9f5037327a1786d":[6,0,0,30,17],
+"classviennacl_1_1hyb__matrix.html#ac80cf4d3ab3ab38f398405ecf88419cd":[6,0,0,30,14],
+"classviennacl_1_1hyb__matrix.html#ac93fc5b3db82256f22d780618ad362db":[6,0,0,30,7],
+"classviennacl_1_1hyb__matrix.html#acd8b0197ad9c5a92ed26cf6ec3ce6137":[6,0,0,30,12],
+"classviennacl_1_1hyb__matrix.html#ad283de5ab491d075b34788c3293890ce":[6,0,0,30,8],
+"classviennacl_1_1hyb__matrix.html#aea26738cc380b7355a9ca42d0c47497d":[6,0,0,30,19],
+"classviennacl_1_1hyb__matrix.html#aed5ff60ddfef1cd59108064a5d4cdd7f":[6,0,0,30,13],
+"classviennacl_1_1hyb__matrix.html#af433c1695c1607b3b4f81a464bda22b6":[6,0,0,30,1],
+"classviennacl_1_1hyb__matrix.html#af90d7f7564c2e70301ea71f7a994f245":[6,0,0,30,6],
+"classviennacl_1_1identity__matrix.html":[6,0,0,31],
+"classviennacl_1_1identity__matrix.html#a08fccf1a11df6b16574d06c518748525":[6,0,0,31,0],
+"classviennacl_1_1identity__matrix.html#ae2a1c61b696a5f38b99d7acdc05068e7":[6,0,0,31,1],
+"classviennacl_1_1identity__matrix.html#af01206e89630a06d934a98b4be3ecc1d":[6,0,0,31,2],
+"classviennacl_1_1implicit__matrix__base.html":[6,0,0,32],
+"classviennacl_1_1implicit__matrix__base.html#a08b29796df09ce2c433853deeb6a2875":[6,0,0,32,3],
+"classviennacl_1_1implicit__matrix__base.html#a09e778701dce3591aecccd5126209a13":[6,0,0,32,2],
+"classviennacl_1_1implicit__matrix__base.html#a3497c22b962d0bf7931ef7148f90c805":[6,0,0,32,0],
+"classviennacl_1_1implicit__matrix__base.html#a6873916ea820179b0bb9c6cafa8e6b00":[6,0,0,32,14],
+"classviennacl_1_1implicit__matrix__base.html#a72554b23195ee6aa7adb6ee83a766a5e":[6,0,0,32,1],
+"classviennacl_1_1implicit__matrix__base.html#a7c5fd51dfd9b251c2a6163ebbb1b77e4":[6,0,0,32,10],
+"classviennacl_1_1implicit__matrix__base.html#a7d7d00f4524de1613292047544be9462":[6,0,0,32,15],
+"classviennacl_1_1implicit__matrix__base.html#a8429b5d40fdc00dfb88b7494c6f4cd90":[6,0,0,32,8],
+"classviennacl_1_1implicit__matrix__base.html#a8e341c7bc14d2bae3627f40aa9c0e761":[6,0,0,32,9],
+"classviennacl_1_1implicit__matrix__base.html#a96d2da75a531df0ed268b21bb667831e":[6,0,0,32,5],
+"classviennacl_1_1implicit__matrix__base.html#aaef546a92fbce4acd13c6739a2583c70":[6,0,0,32,11],
+"classviennacl_1_1implicit__matrix__base.html#adb2478453dc7af39d89e8140abd53c7f":[6,0,0,32,7],
+"classviennacl_1_1implicit__matrix__base.html#ae3983c75190de384eff1a9f79b54acfd":[6,0,0,32,4],
+"classviennacl_1_1implicit__matrix__base.html#aefc5b37eff2f65fd79dd9ca814cba064":[6,0,0,32,6],
+"classviennacl_1_1implicit__matrix__base.html#af45a73be66586ba3d7e64ea917e0a072":[6,0,0,32,13]
 };
