@@ -1,42 +1,5 @@
 var NAVTREEINDEX3 =
 {
-"classviennacl_1_1hyb__matrix.html#a4a711db273189338d5c47793777f7a98":[6,0,0,30,18],
-"classviennacl_1_1hyb__matrix.html#a69cbf2163826b43e4cb6717199fd0474":[6,0,0,30,16],
-"classviennacl_1_1hyb__matrix.html#a6bb63193628710851ff6da33f70a1ce9":[6,0,0,30,6],
-"classviennacl_1_1hyb__matrix.html#a7ae9a356c47a3298619625df2392eb4e":[6,0,0,30,17],
-"classviennacl_1_1hyb__matrix.html#a829531b89c462d336136881073bb5fc4":[6,0,0,30,1],
-"classviennacl_1_1hyb__matrix.html#a933565e3dda939889ac55a64decbc96f":[6,0,0,30,13],
-"classviennacl_1_1hyb__matrix.html#a94d49d42b85e5424296c47823d036dfc":[6,0,0,30,9],
-"classviennacl_1_1hyb__matrix.html#a99f19b7f1f18c18ec9f86920548f72bb":[6,0,0,30,11],
-"classviennacl_1_1hyb__matrix.html#ab5017072236a32e18afbca82b02dec86":[6,0,0,30,0],
-"classviennacl_1_1hyb__matrix.html#ac062f8671868c51dd2b4eeab4cdb9168":[6,0,0,30,14],
-"classviennacl_1_1hyb__matrix.html#ac6d3dd46446e7aecfad31403e5a6857d":[6,0,0,30,8],
-"classviennacl_1_1hyb__matrix.html#ace03d552e9b1e5ae6de9484a8a1218ae":[6,0,0,30,5],
-"classviennacl_1_1hyb__matrix.html#ad6a8c43b8c110e6dc7377eecaf4fce7c":[6,0,0,30,2],
-"classviennacl_1_1hyb__matrix.html#ad937b9563e4c764fd4bd7858b3d95803":[6,0,0,30,3],
-"classviennacl_1_1hyb__matrix.html#adc4674678fa747c72ef2937fb7cef141":[6,0,0,30,4],
-"classviennacl_1_1hyb__matrix.html#ae35b2e77d7d4ecb2ea13770a5c3f4670":[6,0,0,30,10],
-"classviennacl_1_1hyb__matrix.html#aea26738cc380b7355a9ca42d0c47497d":[6,0,0,30,19],
-"classviennacl_1_1identity__matrix.html":[6,0,0,31],
-"classviennacl_1_1identity__matrix.html#a08fccf1a11df6b16574d06c518748525":[6,0,0,31,0],
-"classviennacl_1_1identity__matrix.html#ae2a1c61b696a5f38b99d7acdc05068e7":[6,0,0,31,1],
-"classviennacl_1_1identity__matrix.html#af01206e89630a06d934a98b4be3ecc1d":[6,0,0,31,2],
-"classviennacl_1_1implicit__matrix__base.html":[6,0,0,32],
-"classviennacl_1_1implicit__matrix__base.html#a08b29796df09ce2c433853deeb6a2875":[6,0,0,32,3],
-"classviennacl_1_1implicit__matrix__base.html#a09e778701dce3591aecccd5126209a13":[6,0,0,32,2],
-"classviennacl_1_1implicit__matrix__base.html#a3497c22b962d0bf7931ef7148f90c805":[6,0,0,32,0],
-"classviennacl_1_1implicit__matrix__base.html#a6873916ea820179b0bb9c6cafa8e6b00":[6,0,0,32,14],
-"classviennacl_1_1implicit__matrix__base.html#a72554b23195ee6aa7adb6ee83a766a5e":[6,0,0,32,1],
-"classviennacl_1_1implicit__matrix__base.html#a7c5fd51dfd9b251c2a6163ebbb1b77e4":[6,0,0,32,10],
-"classviennacl_1_1implicit__matrix__base.html#a7d7d00f4524de1613292047544be9462":[6,0,0,32,15],
-"classviennacl_1_1implicit__matrix__base.html#a8429b5d40fdc00dfb88b7494c6f4cd90":[6,0,0,32,8],
-"classviennacl_1_1implicit__matrix__base.html#a8e341c7bc14d2bae3627f40aa9c0e761":[6,0,0,32,9],
-"classviennacl_1_1implicit__matrix__base.html#a96d2da75a531df0ed268b21bb667831e":[6,0,0,32,5],
-"classviennacl_1_1implicit__matrix__base.html#aaef546a92fbce4acd13c6739a2583c70":[6,0,0,32,11],
-"classviennacl_1_1implicit__matrix__base.html#adb2478453dc7af39d89e8140abd53c7f":[6,0,0,32,7],
-"classviennacl_1_1implicit__matrix__base.html#ae3983c75190de384eff1a9f79b54acfd":[6,0,0,32,4],
-"classviennacl_1_1implicit__matrix__base.html#aefc5b37eff2f65fd79dd9ca814cba064":[6,0,0,32,6],
-"classviennacl_1_1implicit__matrix__base.html#af45a73be66586ba3d7e64ea917e0a072":[6,0,0,32,13],
 "classviennacl_1_1implicit__matrix__base.html#af9f3f82b9615ef64a728a3c8c9a1e618":[6,0,0,32,12],
 "classviennacl_1_1implicit__vector__base.html":[6,0,0,33],
 "classviennacl_1_1implicit__vector__base.html#a1901e1215ad17019d70861872892720f":[6,0,0,33,12],
@@ -249,5 +212,42 @@ var NAVTREEINDEX3 =
 "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#a79daf8cac6fca57ae1dc2ea488dc002c":[6,0,0,4,2,1,1,4],
 "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#a7aeb0270c45e9014c653b6b3dc1d4a14":[6,0,0,4,2,1,1,3],
 "classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#a7ceeb417b69da1ba6caac9fe8bdbc208":[6,0,0,4,2,1,1,5],
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#a9dcb565b5e32f699093588da15f6a5f7":[6,0,0,4,2,1,1,2]
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#a9dcb565b5e32f699093588da15f6a5f7":[6,0,0,4,2,1,1,2],
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#abd8d8d36fae742959c19c22a07875bc5":[6,0,0,4,2,1,1,1],
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html":[6,0,0,4,2,1,2],
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#a604e60dc99c37ef48e02e3960f6df759":[6,0,0,4,2,1,2,1],
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#acb8732451cd6eaae7f92087d4d883d96":[6,0,0,4,2,1,2,0],
+"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#acd0ecce3aed3f3c8a04afc061f1871a5":[6,0,0,4,2,1,2,2],
+"classviennacl_1_1linalg_1_1ichol0__precond.html":[6,0,0,4,23],
+"classviennacl_1_1linalg_1_1ichol0__precond.html#a431693cf0774cf49ec60eebd805152de":[6,0,0,4,23,1],
+"classviennacl_1_1linalg_1_1ichol0__precond.html#a4fbac6baaa6fd94902567eb1cfc74e82":[6,0,0,4,23,0],
+"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,24],
+"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a0cc1dc911ce7e1f1acd40d524244667a":[6,0,0,4,24,1],
+"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a613c6f3b14c46cc1e1358a6a594ee191":[6,0,0,4,24,0],
+"classviennacl_1_1linalg_1_1ichol0__tag.html":[6,0,0,4,25],
+"classviennacl_1_1linalg_1_1ilu0__precond.html":[6,0,0,4,26],
+"classviennacl_1_1linalg_1_1ilu0__precond.html#a5672c4943e306385410d73efd91960dc":[6,0,0,4,26,0],
+"classviennacl_1_1linalg_1_1ilu0__precond.html#a8db3e19fec4a17cae6d053538cf77ae2":[6,0,0,4,26,1],
+"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,27],
+"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a2c0ec29b202b93e8e726d214bfa64292":[6,0,0,4,27,1],
+"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a637d8d7d83c00908f5f23a9f1fd71dad":[6,0,0,4,27,2],
+"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#aebce3731635029f94cfb313d120d7be1":[6,0,0,4,27,0],
+"classviennacl_1_1linalg_1_1ilu0__tag.html":[6,0,0,4,28],
+"classviennacl_1_1linalg_1_1ilu0__tag.html#a80e9be92f4b0b34a8150b6362cb7e969":[6,0,0,4,28,1],
+"classviennacl_1_1linalg_1_1ilu0__tag.html#a95868f0f04b78bf99db86ca3380d8f43":[6,0,0,4,28,2],
+"classviennacl_1_1linalg_1_1ilu0__tag.html#ad22376628d618b874c2e58284ff2f826":[6,0,0,4,28,0],
+"classviennacl_1_1linalg_1_1ilut__precond.html":[6,0,0,4,29],
+"classviennacl_1_1linalg_1_1ilut__precond.html#aa8820208575dcf0bb050733207cf11fc":[6,0,0,4,29,0],
+"classviennacl_1_1linalg_1_1ilut__precond.html#adac3c5170d4b28b91cb98c46bef54f15":[6,0,0,4,29,1],
+"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,30],
+"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a5bca4b3cf01205aeb44203168747332a":[6,0,0,4,30,0],
+"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a6676c29c3bcf642f8784f5ff85f9ba86":[6,0,0,4,30,1],
+"classviennacl_1_1linalg_1_1ilut__tag.html":[6,0,0,4,31],
+"classviennacl_1_1linalg_1_1ilut__tag.html#a02dbeda262b47dd51d3092e9b9767051":[6,0,0,4,31,3],
+"classviennacl_1_1linalg_1_1ilut__tag.html#a2042190ce53f7a4bb28356ffd3103a89":[6,0,0,4,31,6],
+"classviennacl_1_1linalg_1_1ilut__tag.html#a809b29595b202b2b777a3ee41606b856":[6,0,0,4,31,2],
+"classviennacl_1_1linalg_1_1ilut__tag.html#ab151e8e08b42253c3de75a8a70047596":[6,0,0,4,31,5],
+"classviennacl_1_1linalg_1_1ilut__tag.html#ac272b45338e4d7bbdf3f52bd8c42cdaf":[6,0,0,4,31,0],
+"classviennacl_1_1linalg_1_1ilut__tag.html#aca7455c7477b07d9eaefa0f24bbe8f4b":[6,0,0,4,31,4],
+"classviennacl_1_1linalg_1_1ilut__tag.html#af5bfec0fd5341c7547cfaa3a1e179699":[6,0,0,4,31,1]
 };
