@@ -1,42 +1,5 @@
 var NAVTREEINDEX4 =
 {
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html#abd8d8d36fae742959c19c22a07875bc5":[6,0,0,4,2,1,1,1],
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html":[6,0,0,4,2,1,2],
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#a604e60dc99c37ef48e02e3960f6df759":[6,0,0,4,2,1,2,1],
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#acb8732451cd6eaae7f92087d4d883d96":[6,0,0,4,2,1,2,0],
-"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html#acd0ecce3aed3f3c8a04afc061f1871a5":[6,0,0,4,2,1,2,2],
-"classviennacl_1_1linalg_1_1ichol0__precond.html":[6,0,0,4,23],
-"classviennacl_1_1linalg_1_1ichol0__precond.html#a431693cf0774cf49ec60eebd805152de":[6,0,0,4,23,1],
-"classviennacl_1_1linalg_1_1ichol0__precond.html#a4fbac6baaa6fd94902567eb1cfc74e82":[6,0,0,4,23,0],
-"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,24],
-"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a0cc1dc911ce7e1f1acd40d524244667a":[6,0,0,4,24,1],
-"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a613c6f3b14c46cc1e1358a6a594ee191":[6,0,0,4,24,0],
-"classviennacl_1_1linalg_1_1ichol0__tag.html":[6,0,0,4,25],
-"classviennacl_1_1linalg_1_1ilu0__precond.html":[6,0,0,4,26],
-"classviennacl_1_1linalg_1_1ilu0__precond.html#a5672c4943e306385410d73efd91960dc":[6,0,0,4,26,0],
-"classviennacl_1_1linalg_1_1ilu0__precond.html#a8db3e19fec4a17cae6d053538cf77ae2":[6,0,0,4,26,1],
-"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,27],
-"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a2c0ec29b202b93e8e726d214bfa64292":[6,0,0,4,27,1],
-"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a637d8d7d83c00908f5f23a9f1fd71dad":[6,0,0,4,27,2],
-"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#aebce3731635029f94cfb313d120d7be1":[6,0,0,4,27,0],
-"classviennacl_1_1linalg_1_1ilu0__tag.html":[6,0,0,4,28],
-"classviennacl_1_1linalg_1_1ilu0__tag.html#a80e9be92f4b0b34a8150b6362cb7e969":[6,0,0,4,28,1],
-"classviennacl_1_1linalg_1_1ilu0__tag.html#a95868f0f04b78bf99db86ca3380d8f43":[6,0,0,4,28,2],
-"classviennacl_1_1linalg_1_1ilu0__tag.html#ad22376628d618b874c2e58284ff2f826":[6,0,0,4,28,0],
-"classviennacl_1_1linalg_1_1ilut__precond.html":[6,0,0,4,29],
-"classviennacl_1_1linalg_1_1ilut__precond.html#aa8820208575dcf0bb050733207cf11fc":[6,0,0,4,29,0],
-"classviennacl_1_1linalg_1_1ilut__precond.html#adac3c5170d4b28b91cb98c46bef54f15":[6,0,0,4,29,1],
-"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[6,0,0,4,30],
-"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a5bca4b3cf01205aeb44203168747332a":[6,0,0,4,30,0],
-"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html#a6676c29c3bcf642f8784f5ff85f9ba86":[6,0,0,4,30,1],
-"classviennacl_1_1linalg_1_1ilut__tag.html":[6,0,0,4,31],
-"classviennacl_1_1linalg_1_1ilut__tag.html#a02dbeda262b47dd51d3092e9b9767051":[6,0,0,4,31,3],
-"classviennacl_1_1linalg_1_1ilut__tag.html#a2042190ce53f7a4bb28356ffd3103a89":[6,0,0,4,31,6],
-"classviennacl_1_1linalg_1_1ilut__tag.html#a809b29595b202b2b777a3ee41606b856":[6,0,0,4,31,2],
-"classviennacl_1_1linalg_1_1ilut__tag.html#ab151e8e08b42253c3de75a8a70047596":[6,0,0,4,31,5],
-"classviennacl_1_1linalg_1_1ilut__tag.html#ac272b45338e4d7bbdf3f52bd8c42cdaf":[6,0,0,4,31,0],
-"classviennacl_1_1linalg_1_1ilut__tag.html#aca7455c7477b07d9eaefa0f24bbe8f4b":[6,0,0,4,31,4],
-"classviennacl_1_1linalg_1_1ilut__tag.html#af5bfec0fd5341c7547cfaa3a1e179699":[6,0,0,4,31,1],
 "classviennacl_1_1linalg_1_1jacobi__precond.html":[6,0,0,4,32],
 "classviennacl_1_1linalg_1_1jacobi__precond.html#a4dc33d4e561b2f29bd37131a1c015622":[6,0,0,4,32,2],
 "classviennacl_1_1linalg_1_1jacobi__precond.html#a5d3e48bbec7300c929d58e445455f4dc":[6,0,0,4,32,1],
@@ -85,11 +48,7 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1linalg_1_1nmf__config.html#af13bdd7b8374d0968e87511ad840d918":[6,0,0,4,38,9],
 "classviennacl_1_1linalg_1_1no__precond.html":[6,0,0,4,39],
 "classviennacl_1_1linalg_1_1no__precond.html#af18336a2ed53dadf3a9ef61ea7bede00":[6,0,0,4,39,0],
-"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html":[6,0,0,4,3,0,12],
-"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html":[6,0,0,4,3,0,16],
-"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html":[6,0,0,4,3,0,19],
-"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html":[6,0,0,4,3,0,26],
-"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html":[6,0,0,4,3,0,29],
+"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html":[6,0,0,4,3,0,18],
 "classviennacl_1_1linalg_1_1power__iter__tag.html":[6,0,0,4,40],
 "classviennacl_1_1linalg_1_1power__iter__tag.html#a2940a548e8543936ffdd93170ab8b8ce":[6,0,0,4,40,1],
 "classviennacl_1_1linalg_1_1power__iter__tag.html#a79f4ba9e23ebb8692badacdfd32d246e":[6,0,0,4,40,3],
@@ -116,21 +75,21 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#a964acb6fb9cda96c9ff15ad9e60dadb4":[6,0,0,4,45,0],
 "classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html#aabfc6ef7298c66e9189107614fe1a297":[6,0,0,4,45,1],
 "classviennacl_1_1matrix.html":[6,0,0,62],
-"classviennacl_1_1matrix.html#a34d423d6d88dc159ffe2dde7415622c9":[6,0,0,62,12],
-"classviennacl_1_1matrix.html#a4ee409dd9bb90fb9324758e786a9220c":[6,0,0,62,7],
-"classviennacl_1_1matrix.html#a4f2838c746c5a8db1377898ee44489e0":[6,0,0,62,1],
-"classviennacl_1_1matrix.html#a52fe7272d3d01be023e7e80d2e31085c":[6,0,0,62,9],
-"classviennacl_1_1matrix.html#a677954883f3e9baac8fabfc61879a045":[6,0,0,62,4],
-"classviennacl_1_1matrix.html#a743efa0137f5f82478a8a1b615a738a4":[6,0,0,62,3],
-"classviennacl_1_1matrix.html#a749eaf9d08a857f67a2b0d2c6303e125":[6,0,0,62,13],
-"classviennacl_1_1matrix.html#a79ae164ce8f984f303304d90f042bdcf":[6,0,0,62,8],
-"classviennacl_1_1matrix.html#a8467bf0d29df43906d388c961ad6a573":[6,0,0,62,0],
-"classviennacl_1_1matrix.html#a85f7c011fe21676c6a790d770e817787":[6,0,0,62,6],
-"classviennacl_1_1matrix.html#a9004170f7d1aca2ef3379927170f4564":[6,0,0,62,2],
-"classviennacl_1_1matrix.html#a912547a8b6b58c92375f84e27bb6d054":[6,0,0,62,14],
-"classviennacl_1_1matrix.html#aaaf86c2934b1e93a48c616d0c915f76c":[6,0,0,62,5],
-"classviennacl_1_1matrix.html#ac107fa1b6d0c38aebec23e3752f24715":[6,0,0,62,11],
-"classviennacl_1_1matrix.html#adf2592ae9254d226e24a26389a04721c":[6,0,0,62,10],
+"classviennacl_1_1matrix.html#a1de4d71a10ba9b60a01005bae51027b5":[6,0,0,62,0],
+"classviennacl_1_1matrix.html#a69431725e09b2b73606dee084c962d7f":[6,0,0,62,14],
+"classviennacl_1_1matrix.html#a8a5ce7e676c57d1f0acd746951d32fec":[6,0,0,62,9],
+"classviennacl_1_1matrix.html#a997df903eca9afe7f58d7932c7aa5c8e":[6,0,0,62,11],
+"classviennacl_1_1matrix.html#aa1d160f8ee553be461e27550d33a774e":[6,0,0,62,1],
+"classviennacl_1_1matrix.html#aacc576b44b1377555030469c493a2b9e":[6,0,0,62,13],
+"classviennacl_1_1matrix.html#ab3ef00115276f179a8cd2172f9738e33":[6,0,0,62,3],
+"classviennacl_1_1matrix.html#ab8eb950050017f961faf5ac0184e934c":[6,0,0,62,8],
+"classviennacl_1_1matrix.html#ac3cd72a83b58d55a61357669bee23b38":[6,0,0,62,2],
+"classviennacl_1_1matrix.html#ac8dad9e664244e4a6dd9f45e061a4adc":[6,0,0,62,7],
+"classviennacl_1_1matrix.html#ad5fde9fad4e61456dfd9a4818bf210d0":[6,0,0,62,10],
+"classviennacl_1_1matrix.html#adae9b1fad83885bd3162031e012ed3ea":[6,0,0,62,4],
+"classviennacl_1_1matrix.html#adde2f19fc84b9d96db059b9bb9af448d":[6,0,0,62,5],
+"classviennacl_1_1matrix.html#aeab900b21767b83178cc4bd3ce303d41":[6,0,0,62,12],
+"classviennacl_1_1matrix.html#aedafac235f345bca2e555930a748415d":[6,0,0,62,6],
 "classviennacl_1_1matrix__base.html":[6,0,0,63],
 "classviennacl_1_1matrix__base.html#a00e30fdc61081a73995b54175a91d220":[6,0,0,63,21],
 "classviennacl_1_1matrix__base.html#a033e870a0bee332152772e7320b674f7":[6,0,0,63,53],
@@ -205,16 +164,16 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1matrix__expression.html#aa2c582e8d2c1cafbf2ffdf05c9fdfaca":[6,0,0,64,2],
 "classviennacl_1_1matrix__expression.html#ad8516f3a2ef4db4d5379fb64832fd39f":[6,0,0,64,5],
 "classviennacl_1_1matrix__iterator.html":[6,0,0,65],
-"classviennacl_1_1matrix__iterator.html#a15bda6557c012f86dc73d712bc71d7f3":[6,0,0,65,7],
-"classviennacl_1_1matrix__iterator.html#a1837364083cd08f862d3ea5608af5f82":[6,0,0,65,2],
-"classviennacl_1_1matrix__iterator.html#a3ff1ff49f79aea6ba824ecdb460ecc14":[6,0,0,65,1],
-"classviennacl_1_1matrix__iterator.html#a839f7b14cdb91361b88dd6b230d6b505":[6,0,0,65,8],
-"classviennacl_1_1matrix__iterator.html#a9b8eeaefaa8bf5276b8d63cf3a471ade":[6,0,0,65,4],
-"classviennacl_1_1matrix__iterator.html#ab0dc7706eacde70d1857372b602b6bad":[6,0,0,65,3],
-"classviennacl_1_1matrix__iterator.html#ab5b8c98222880e6ae5f92d54c7d06e14":[6,0,0,65,6],
-"classviennacl_1_1matrix__iterator.html#ae11cd06a58c70e8a4f90fd5e1946a9ee":[6,0,0,65,0],
-"classviennacl_1_1matrix__iterator.html#ae473cc7d80378c7384b365d4959457df":[6,0,0,65,5],
-"classviennacl_1_1matrix__iterator.html#af1aee4972f71999a4f46dac773543530":[6,0,0,65,9],
+"classviennacl_1_1matrix__iterator.html#a121be30f9b9c7585e30d14dd0cdcc6a3":[6,0,0,65,0],
+"classviennacl_1_1matrix__iterator.html#a1d773c1b5ee19bc68b400442a9550e2e":[6,0,0,65,4],
+"classviennacl_1_1matrix__iterator.html#a2cab0902708eef3409d060525e7b1bd3":[6,0,0,65,7],
+"classviennacl_1_1matrix__iterator.html#a4801a7780c28b98488cfb2bf75c668c3":[6,0,0,65,6],
+"classviennacl_1_1matrix__iterator.html#a4ef6bffdf5f728b0bbba6ba175a0a4d9":[6,0,0,65,8],
+"classviennacl_1_1matrix__iterator.html#a6831a7e228fd80e84711d82e2362c6db":[6,0,0,65,5],
+"classviennacl_1_1matrix__iterator.html#a70cfd358baf22f4ee9570f1a6b7c1701":[6,0,0,65,2],
+"classviennacl_1_1matrix__iterator.html#a817d81d889d73ac2dc6e6177e062bd7a":[6,0,0,65,1],
+"classviennacl_1_1matrix__iterator.html#a895218ddd37e5f964c30bc89d0cd1781":[6,0,0,65,9],
+"classviennacl_1_1matrix__iterator.html#ac35c319df57718089c7f39d97733e1ba":[6,0,0,65,3],
 "classviennacl_1_1matrix__range.html":[6,0,0,66],
 "classviennacl_1_1matrix__range.html#a100b1ddda26bfd792b34b666c0dc23e2":[6,0,0,66,8],
 "classviennacl_1_1matrix__range.html#a1d46c33083bf7c74898c69801c25e8cb":[6,0,0,66,10],
@@ -249,5 +208,46 @@ var NAVTREEINDEX4 =
 "classviennacl_1_1matrix__slice.html#afe786a1f980fa21ff95d338784021598":[6,0,0,68,2],
 "classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[6,0,0,69],
 "classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#a1405263a01e16f7bcd4c09fb8eb29bc7":[6,0,0,69,0],
-"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aabe80bdcb1d57191aff173806d0b3e31":[6,0,0,69,1]
+"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aabe80bdcb1d57191aff173806d0b3e31":[6,0,0,69,1],
+"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aef18c078f89c2851229dd91422fed2db":[6,0,0,69,2],
+"classviennacl_1_1memory__exception.html":[6,0,0,70],
+"classviennacl_1_1memory__exception.html#a0e8dfdd960da56daa8616f11780ffc3c":[6,0,0,70,2],
+"classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4":[6,0,0,70,3],
+"classviennacl_1_1memory__exception.html#a6ea59387f3ccdba0c559cb6a186ad7cc":[6,0,0,70,1],
+"classviennacl_1_1memory__exception.html#abe5d81175f7dd39579b6337b90ea21ca":[6,0,0,70,0],
+"classviennacl_1_1ocl_1_1backend.html":[6,0,0,5,1],
+"classviennacl_1_1ocl_1_1build__program__failure.html":[6,0,0,5,2],
+"classviennacl_1_1ocl_1_1command__queue.html":[6,0,0,5,3],
+"classviennacl_1_1ocl_1_1command__queue.html#a31862d3455bd31b51ecdcdadebbbde79":[6,0,0,5,3,2],
+"classviennacl_1_1ocl_1_1command__queue.html#a4516024c4cec5147e582ca85e0fe1f00":[6,0,0,5,3,4],
+"classviennacl_1_1ocl_1_1command__queue.html#a670f2d080528e50d64d3912567708754":[6,0,0,5,3,5],
+"classviennacl_1_1ocl_1_1command__queue.html#a932d287769eebe9ef045ab85b4575706":[6,0,0,5,3,7],
+"classviennacl_1_1ocl_1_1command__queue.html#a93a510254baa209cbfcab51eda30e780":[6,0,0,5,3,1],
+"classviennacl_1_1ocl_1_1command__queue.html#ab38b51dc74556adb044ea9f8e4c458e9":[6,0,0,5,3,6],
+"classviennacl_1_1ocl_1_1command__queue.html#ae2e51d158444a51341af30cebc5cf88b":[6,0,0,5,3,3],
+"classviennacl_1_1ocl_1_1command__queue.html#af9ace720a0aae631ac5eaf791c6c6160":[6,0,0,5,3,8],
+"classviennacl_1_1ocl_1_1command__queue.html#afe48096ca16c17701bc016df6854ca80":[6,0,0,5,3,0],
+"classviennacl_1_1ocl_1_1compiler__not__available.html":[6,0,0,5,4],
+"classviennacl_1_1ocl_1_1context.html":[6,0,0,5,5],
+"classviennacl_1_1ocl_1_1context.html#a0f1a9e025d6fcdd44b21d8f80fa8c446":[6,0,0,5,5,0],
+"classviennacl_1_1ocl_1_1context.html#a122abd131e682733ff44bdf480365ba2":[6,0,0,5,5,23],
+"classviennacl_1_1ocl_1_1context.html#a1b1339c711fd666c8bdc9104f47670d4":[6,0,0,5,5,25],
+"classviennacl_1_1ocl_1_1context.html#a2579803294df7a517efc5551e02ca9ec":[6,0,0,5,5,7],
+"classviennacl_1_1ocl_1_1context.html#a27347b71cec98f6636de39e91e767f4f":[6,0,0,5,5,21],
+"classviennacl_1_1ocl_1_1context.html#a2af175f7e99efa33ad852ab3d871f666":[6,0,0,5,5,22],
+"classviennacl_1_1ocl_1_1context.html#a3b505875590e899db5538daf05f74b05":[6,0,0,5,5,6],
+"classviennacl_1_1ocl_1_1context.html#a43602c712b8c33cf6c9c5eeebdbe0eb7":[6,0,0,5,5,35],
+"classviennacl_1_1ocl_1_1context.html#a4ad17f85bfc2e5715c9e327c40138d43":[6,0,0,5,5,42],
+"classviennacl_1_1ocl_1_1context.html#a4f0b8c81dad769f6efffe2d2069101f8":[6,0,0,5,5,8],
+"classviennacl_1_1ocl_1_1context.html#a4f89a62af0d767fd8a4f5f07323447ea":[6,0,0,5,5,38],
+"classviennacl_1_1ocl_1_1context.html#a562e2d1a9a55e647570734c4f62a22e2":[6,0,0,5,5,9],
+"classviennacl_1_1ocl_1_1context.html#a566dfbe8b8e1588ae21c50091682d1ce":[6,0,0,5,5,19],
+"classviennacl_1_1ocl_1_1context.html#a611d95b11db04230f63e37bfeae911db":[6,0,0,5,5,32],
+"classviennacl_1_1ocl_1_1context.html#a6aa5ef5cb563ed047ff72f286eb5718b":[6,0,0,5,5,10],
+"classviennacl_1_1ocl_1_1context.html#a734307b352a0137c93f22cfebed89dfe":[6,0,0,5,5,2],
+"classviennacl_1_1ocl_1_1context.html#a7ccf3c2f3be355f39ea07cfea9600369":[6,0,0,5,5,1],
+"classviennacl_1_1ocl_1_1context.html#a7e593822095e5680fc8de44e34cb4131":[6,0,0,5,5,34],
+"classviennacl_1_1ocl_1_1context.html#a83052a42aed14d8ff9d3df4773908f64":[6,0,0,5,5,27],
+"classviennacl_1_1ocl_1_1context.html#a85373fa81be824eef324579bf429d201":[6,0,0,5,5,41],
+"classviennacl_1_1ocl_1_1context.html#a8ac887230ee381a0f5f9df2a22129155":[6,0,0,5,5,37]
 };
