@@ -1,46 +1,5 @@
 var NAVTREEINDEX5 =
 {
-"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html#aef18c078f89c2851229dd91422fed2db":[6,0,0,69,2],
-"classviennacl_1_1memory__exception.html":[6,0,0,70],
-"classviennacl_1_1memory__exception.html#a0e8dfdd960da56daa8616f11780ffc3c":[6,0,0,70,2],
-"classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4":[6,0,0,70,3],
-"classviennacl_1_1memory__exception.html#a6ea59387f3ccdba0c559cb6a186ad7cc":[6,0,0,70,1],
-"classviennacl_1_1memory__exception.html#abe5d81175f7dd39579b6337b90ea21ca":[6,0,0,70,0],
-"classviennacl_1_1ocl_1_1backend.html":[6,0,0,5,1],
-"classviennacl_1_1ocl_1_1build__program__failure.html":[6,0,0,5,2],
-"classviennacl_1_1ocl_1_1command__queue.html":[6,0,0,5,3],
-"classviennacl_1_1ocl_1_1command__queue.html#a31862d3455bd31b51ecdcdadebbbde79":[6,0,0,5,3,2],
-"classviennacl_1_1ocl_1_1command__queue.html#a4516024c4cec5147e582ca85e0fe1f00":[6,0,0,5,3,4],
-"classviennacl_1_1ocl_1_1command__queue.html#a670f2d080528e50d64d3912567708754":[6,0,0,5,3,5],
-"classviennacl_1_1ocl_1_1command__queue.html#a932d287769eebe9ef045ab85b4575706":[6,0,0,5,3,7],
-"classviennacl_1_1ocl_1_1command__queue.html#a93a510254baa209cbfcab51eda30e780":[6,0,0,5,3,1],
-"classviennacl_1_1ocl_1_1command__queue.html#ab38b51dc74556adb044ea9f8e4c458e9":[6,0,0,5,3,6],
-"classviennacl_1_1ocl_1_1command__queue.html#ae2e51d158444a51341af30cebc5cf88b":[6,0,0,5,3,3],
-"classviennacl_1_1ocl_1_1command__queue.html#af9ace720a0aae631ac5eaf791c6c6160":[6,0,0,5,3,8],
-"classviennacl_1_1ocl_1_1command__queue.html#afe48096ca16c17701bc016df6854ca80":[6,0,0,5,3,0],
-"classviennacl_1_1ocl_1_1compiler__not__available.html":[6,0,0,5,4],
-"classviennacl_1_1ocl_1_1context.html":[6,0,0,5,5],
-"classviennacl_1_1ocl_1_1context.html#a0f1a9e025d6fcdd44b21d8f80fa8c446":[6,0,0,5,5,0],
-"classviennacl_1_1ocl_1_1context.html#a122abd131e682733ff44bdf480365ba2":[6,0,0,5,5,23],
-"classviennacl_1_1ocl_1_1context.html#a1b1339c711fd666c8bdc9104f47670d4":[6,0,0,5,5,25],
-"classviennacl_1_1ocl_1_1context.html#a2579803294df7a517efc5551e02ca9ec":[6,0,0,5,5,7],
-"classviennacl_1_1ocl_1_1context.html#a27347b71cec98f6636de39e91e767f4f":[6,0,0,5,5,21],
-"classviennacl_1_1ocl_1_1context.html#a2af175f7e99efa33ad852ab3d871f666":[6,0,0,5,5,22],
-"classviennacl_1_1ocl_1_1context.html#a3b505875590e899db5538daf05f74b05":[6,0,0,5,5,6],
-"classviennacl_1_1ocl_1_1context.html#a43602c712b8c33cf6c9c5eeebdbe0eb7":[6,0,0,5,5,35],
-"classviennacl_1_1ocl_1_1context.html#a4ad17f85bfc2e5715c9e327c40138d43":[6,0,0,5,5,42],
-"classviennacl_1_1ocl_1_1context.html#a4f0b8c81dad769f6efffe2d2069101f8":[6,0,0,5,5,8],
-"classviennacl_1_1ocl_1_1context.html#a4f89a62af0d767fd8a4f5f07323447ea":[6,0,0,5,5,38],
-"classviennacl_1_1ocl_1_1context.html#a562e2d1a9a55e647570734c4f62a22e2":[6,0,0,5,5,9],
-"classviennacl_1_1ocl_1_1context.html#a566dfbe8b8e1588ae21c50091682d1ce":[6,0,0,5,5,19],
-"classviennacl_1_1ocl_1_1context.html#a611d95b11db04230f63e37bfeae911db":[6,0,0,5,5,32],
-"classviennacl_1_1ocl_1_1context.html#a6aa5ef5cb563ed047ff72f286eb5718b":[6,0,0,5,5,10],
-"classviennacl_1_1ocl_1_1context.html#a734307b352a0137c93f22cfebed89dfe":[6,0,0,5,5,2],
-"classviennacl_1_1ocl_1_1context.html#a7ccf3c2f3be355f39ea07cfea9600369":[6,0,0,5,5,1],
-"classviennacl_1_1ocl_1_1context.html#a7e593822095e5680fc8de44e34cb4131":[6,0,0,5,5,34],
-"classviennacl_1_1ocl_1_1context.html#a83052a42aed14d8ff9d3df4773908f64":[6,0,0,5,5,27],
-"classviennacl_1_1ocl_1_1context.html#a85373fa81be824eef324579bf429d201":[6,0,0,5,5,41],
-"classviennacl_1_1ocl_1_1context.html#a8ac887230ee381a0f5f9df2a22129155":[6,0,0,5,5,37],
 "classviennacl_1_1ocl_1_1context.html#a9094ac71f0cdf80df698c0c84ebb483d":[6,0,0,5,5,3],
 "classviennacl_1_1ocl_1_1context.html#a93e86f0d0b9fbd725fcce5af704a45a0":[6,0,0,5,5,4],
 "classviennacl_1_1ocl_1_1context.html#a9a4b85b384428c041f357fb53ce18bdb":[6,0,0,5,5,44],
@@ -249,5 +208,46 @@ var NAVTREEINDEX5 =
 "classviennacl_1_1ocl_1_1kernel.html#af7841ba1a1ea1ad158589930be999323":[6,0,0,5,54,25],
 "classviennacl_1_1ocl_1_1kernel.html#af8109360bccd0b7e0d8336c6f54cd4e7":[6,0,0,5,54,8],
 "classviennacl_1_1ocl_1_1kernel.html#af98037d6b6fdedf37c9f5bfb58b0fe9e":[6,0,0,5,54,28],
-"classviennacl_1_1ocl_1_1kernel.html#afead907f705173e817c44c4e6bc3df03":[6,0,0,5,54,47]
+"classviennacl_1_1ocl_1_1kernel.html#afead907f705173e817c44c4e6bc3df03":[6,0,0,5,54,47],
+"classviennacl_1_1ocl_1_1kernel__not__found.html":[6,0,0,5,55],
+"classviennacl_1_1ocl_1_1kernel__not__found.html#aa7ee919346ae1f9212c70e73cdffc15d":[6,0,0,5,55,0],
+"classviennacl_1_1ocl_1_1local__mem.html":[6,0,0,5,56],
+"classviennacl_1_1ocl_1_1local__mem.html#a1a8c71fddf7925f521d032cde035cf76":[6,0,0,5,56,1],
+"classviennacl_1_1ocl_1_1local__mem.html#a1dccdf744db1d2ac46881cb65faccc71":[6,0,0,5,56,0],
+"classviennacl_1_1ocl_1_1local__mem.html#a845262096501aff97d000edc96fa7900":[6,0,0,5,56,2],
+"classviennacl_1_1ocl_1_1map__failure.html":[6,0,0,5,57],
+"classviennacl_1_1ocl_1_1mem__copy__overlap.html":[6,0,0,5,58],
+"classviennacl_1_1ocl_1_1mem__object__allocation__failure.html":[6,0,0,5,59],
+"classviennacl_1_1ocl_1_1out__of__host__memory.html":[6,0,0,5,60],
+"classviennacl_1_1ocl_1_1out__of__resources.html":[6,0,0,5,61],
+"classviennacl_1_1ocl_1_1platform.html":[6,0,0,5,63],
+"classviennacl_1_1ocl_1_1platform.html#a4d375c5d57800c31f6892235ba305f7d":[6,0,0,5,63,1],
+"classviennacl_1_1ocl_1_1platform.html#a6572ef45a7546c2d228b42ca92dfe401":[6,0,0,5,63,6],
+"classviennacl_1_1ocl_1_1platform.html#a917f8690fa543677a7f0df9aa90b90a8":[6,0,0,5,63,4],
+"classviennacl_1_1ocl_1_1platform.html#ab935700ab7ff9297250646e1c7e793be":[6,0,0,5,63,2],
+"classviennacl_1_1ocl_1_1platform.html#ac570aa63d292d47da2258136bef5f6e9":[6,0,0,5,63,5],
+"classviennacl_1_1ocl_1_1platform.html#afaa563522ebe9ce7b80ef02c40e7fe31":[6,0,0,5,63,3],
+"classviennacl_1_1ocl_1_1platform.html#afd82f90092841f111e70e5e7b8afbcec":[6,0,0,5,63,0],
+"classviennacl_1_1ocl_1_1profiling__info__not__available.html":[6,0,0,5,64],
+"classviennacl_1_1ocl_1_1program.html":[6,0,0,5,65],
+"classviennacl_1_1ocl_1_1program.html#a108f2fd60c48c4d01fa8c706837aac16":[6,0,0,5,65,7],
+"classviennacl_1_1ocl_1_1program.html#a117eef2c7894ab1d794bc115d2a23f4a":[6,0,0,5,65,4],
+"classviennacl_1_1ocl_1_1program.html#a200a9787e1bfcc1edd51e81afde01599":[6,0,0,5,65,1],
+"classviennacl_1_1ocl_1_1program.html#a7c0474f0a8bbb734254d37905761ba77":[6,0,0,5,65,5],
+"classviennacl_1_1ocl_1_1program.html#a956fa101a29331dba0ec621a95cfab28":[6,0,0,5,65,6],
+"classviennacl_1_1ocl_1_1program.html#a9ecf10d4388064be1b10aa69de63d648":[6,0,0,5,65,2],
+"classviennacl_1_1ocl_1_1program.html#aa4f77fdcd02daa7d71627dc20117ba75":[6,0,0,5,65,3],
+"classviennacl_1_1ocl_1_1program.html#aca261f14e968b1817329fd70feffc18f":[6,0,0,5,65,0],
+"classviennacl_1_1ocl_1_1program.html#acd547941bc65e0a26eb2d6a9c3e4c29f":[6,0,0,5,65,8],
+"classviennacl_1_1ocl_1_1program__not__found.html":[6,0,0,5,66],
+"classviennacl_1_1ocl_1_1program__not__found.html#ac46c9ab5d6134bba279ac0aa7939d72e":[6,0,0,5,66,0],
+"classviennacl_1_1ocl_1_1queue__not__found.html":[6,0,0,5,67],
+"classviennacl_1_1ocl_1_1queue__not__found.html#a59470634f347e3bda949857a479fbad3":[6,0,0,5,67,0],
+"classviennacl_1_1ocl_1_1unknown__error.html":[6,0,0,5,69],
+"classviennacl_1_1scalar.html":[6,0,0,134],
+"classviennacl_1_1scalar.html#a039864953bf3d52090a2745d2fe6fd7d":[6,0,0,134,36],
+"classviennacl_1_1scalar.html#a08003a51f240beb986e87e89c3e5aadb":[6,0,0,134,26],
+"classviennacl_1_1scalar.html#a0c8acf00720f9f1e6905afa49f161195":[6,0,0,134,42],
+"classviennacl_1_1scalar.html#a0e537abe4622c337c128fdeb69fa7bc3":[6,0,0,134,13],
+"classviennacl_1_1scalar.html#a0fb54e68e728d5498beccd8f576f2824":[6,0,0,134,4]
 };
