@@ -1,89 +1,48 @@
 var NAVTREEINDEX6 =
 {
-"classviennacl_1_1ocl_1_1kernel__not__found.html":[6,0,0,5,55],
-"classviennacl_1_1ocl_1_1kernel__not__found.html#aa7ee919346ae1f9212c70e73cdffc15d":[6,0,0,5,55,0],
-"classviennacl_1_1ocl_1_1local__mem.html":[6,0,0,5,56],
-"classviennacl_1_1ocl_1_1local__mem.html#a1a8c71fddf7925f521d032cde035cf76":[6,0,0,5,56,1],
-"classviennacl_1_1ocl_1_1local__mem.html#a1dccdf744db1d2ac46881cb65faccc71":[6,0,0,5,56,0],
-"classviennacl_1_1ocl_1_1local__mem.html#a845262096501aff97d000edc96fa7900":[6,0,0,5,56,2],
-"classviennacl_1_1ocl_1_1map__failure.html":[6,0,0,5,57],
-"classviennacl_1_1ocl_1_1mem__copy__overlap.html":[6,0,0,5,58],
-"classviennacl_1_1ocl_1_1mem__object__allocation__failure.html":[6,0,0,5,59],
-"classviennacl_1_1ocl_1_1out__of__host__memory.html":[6,0,0,5,60],
-"classviennacl_1_1ocl_1_1out__of__resources.html":[6,0,0,5,61],
-"classviennacl_1_1ocl_1_1platform.html":[6,0,0,5,63],
-"classviennacl_1_1ocl_1_1platform.html#a4d375c5d57800c31f6892235ba305f7d":[6,0,0,5,63,1],
-"classviennacl_1_1ocl_1_1platform.html#a6572ef45a7546c2d228b42ca92dfe401":[6,0,0,5,63,6],
-"classviennacl_1_1ocl_1_1platform.html#a917f8690fa543677a7f0df9aa90b90a8":[6,0,0,5,63,4],
-"classviennacl_1_1ocl_1_1platform.html#ab935700ab7ff9297250646e1c7e793be":[6,0,0,5,63,2],
-"classviennacl_1_1ocl_1_1platform.html#ac570aa63d292d47da2258136bef5f6e9":[6,0,0,5,63,5],
-"classviennacl_1_1ocl_1_1platform.html#afaa563522ebe9ce7b80ef02c40e7fe31":[6,0,0,5,63,3],
-"classviennacl_1_1ocl_1_1platform.html#afd82f90092841f111e70e5e7b8afbcec":[6,0,0,5,63,0],
-"classviennacl_1_1ocl_1_1profiling__info__not__available.html":[6,0,0,5,64],
-"classviennacl_1_1ocl_1_1program.html":[6,0,0,5,65],
-"classviennacl_1_1ocl_1_1program.html#a108f2fd60c48c4d01fa8c706837aac16":[6,0,0,5,65,7],
-"classviennacl_1_1ocl_1_1program.html#a117eef2c7894ab1d794bc115d2a23f4a":[6,0,0,5,65,4],
-"classviennacl_1_1ocl_1_1program.html#a200a9787e1bfcc1edd51e81afde01599":[6,0,0,5,65,1],
-"classviennacl_1_1ocl_1_1program.html#a7c0474f0a8bbb734254d37905761ba77":[6,0,0,5,65,5],
-"classviennacl_1_1ocl_1_1program.html#a956fa101a29331dba0ec621a95cfab28":[6,0,0,5,65,6],
-"classviennacl_1_1ocl_1_1program.html#a9ecf10d4388064be1b10aa69de63d648":[6,0,0,5,65,2],
-"classviennacl_1_1ocl_1_1program.html#aa4f77fdcd02daa7d71627dc20117ba75":[6,0,0,5,65,3],
-"classviennacl_1_1ocl_1_1program.html#aca261f14e968b1817329fd70feffc18f":[6,0,0,5,65,0],
-"classviennacl_1_1ocl_1_1program.html#acd547941bc65e0a26eb2d6a9c3e4c29f":[6,0,0,5,65,8],
-"classviennacl_1_1ocl_1_1program__not__found.html":[6,0,0,5,66],
-"classviennacl_1_1ocl_1_1program__not__found.html#ac46c9ab5d6134bba279ac0aa7939d72e":[6,0,0,5,66,0],
-"classviennacl_1_1ocl_1_1queue__not__found.html":[6,0,0,5,67],
-"classviennacl_1_1ocl_1_1queue__not__found.html#a59470634f347e3bda949857a479fbad3":[6,0,0,5,67,0],
-"classviennacl_1_1ocl_1_1unknown__error.html":[6,0,0,5,69],
-"classviennacl_1_1scalar.html":[6,0,0,134],
-"classviennacl_1_1scalar.html#a08c2d9ff4896a158886dcd25e5adb8d3":[6,0,0,134,38],
-"classviennacl_1_1scalar.html#a0d3e0ad91f3fcd6b01421a8736a09f56":[6,0,0,134,2],
-"classviennacl_1_1scalar.html#a1158f00ae60e1814779bc280019b77fb":[6,0,0,134,13],
-"classviennacl_1_1scalar.html#a1edb6d67dceb3c1e0a35b296a25ff247":[6,0,0,134,17],
-"classviennacl_1_1scalar.html#a2402edbb5081a3129c3ed51cae1c821a":[6,0,0,134,18],
-"classviennacl_1_1scalar.html#a247ef5ba45ecfa89cf77f88f1ea944c0":[6,0,0,134,21],
-"classviennacl_1_1scalar.html#a2550463c69ac48380b81784c2d033835":[6,0,0,134,5],
-"classviennacl_1_1scalar.html#a29593690a9b384bbfd5f6ec8b83420e8":[6,0,0,134,15],
-"classviennacl_1_1scalar.html#a2baf935224e17d6ff9d3dbd9a9e200ea":[6,0,0,134,33],
-"classviennacl_1_1scalar.html#a336274152948771e58a151ced13ab590":[6,0,0,134,36],
-"classviennacl_1_1scalar.html#a397022764ab50cb43eb26323d6289649":[6,0,0,134,14],
-"classviennacl_1_1scalar.html#a59a856b45ab90c25c50a28a87a5e96a6":[6,0,0,134,46],
-"classviennacl_1_1scalar.html#a633f9442401801c504485d3bf40137ae":[6,0,0,134,25],
-"classviennacl_1_1scalar.html#a64235c3e5db6f4ae8481f73262158da9":[6,0,0,134,16],
-"classviennacl_1_1scalar.html#a6706e7de76559bbf0c59b080d8c23af8":[6,0,0,134,44],
-"classviennacl_1_1scalar.html#a677d9162e070ba140d32200dc8286d1c":[6,0,0,134,0],
-"classviennacl_1_1scalar.html#a67c0b9d5ee5e1525b17d51daa939ace2":[6,0,0,134,12],
-"classviennacl_1_1scalar.html#a6e015ff1e1e91d34b62cf84324aafed7":[6,0,0,134,27],
-"classviennacl_1_1scalar.html#a6f9bee9cfee9774b8152064f91db74a3":[6,0,0,134,22],
-"classviennacl_1_1scalar.html#a74523d98c54af86ddbfbd105b81b4cb4":[6,0,0,134,35],
-"classviennacl_1_1scalar.html#a74a7c48ebab16d449260ee545e8d4a16":[6,0,0,134,8],
-"classviennacl_1_1scalar.html#a77ed90aa6e021bb56a16036dff9bf840":[6,0,0,134,24],
-"classviennacl_1_1scalar.html#a7ce155edb3984c0d4ac55f176b2b98a8":[6,0,0,134,42],
-"classviennacl_1_1scalar.html#a8454ca86b8e813bbcc9dd8d2848ae661":[6,0,0,134,41],
-"classviennacl_1_1scalar.html#a86fc93687caec15554bf9899b8b4b5fe":[6,0,0,134,37],
-"classviennacl_1_1scalar.html#a886772924333d38c331ff6075f52aaee":[6,0,0,134,6],
-"classviennacl_1_1scalar.html#a8b1050438e0ac684bc427c28ca518c72":[6,0,0,134,43],
-"classviennacl_1_1scalar.html#a8b356ca09132e5f02b1ed3d98c3d56a6":[6,0,0,134,20],
-"classviennacl_1_1scalar.html#a8f1444dd3d6625ad55c9ee448a89bffc":[6,0,0,134,26],
-"classviennacl_1_1scalar.html#a8fdf64948b6d57df95d2eb948ec0d309":[6,0,0,134,19],
-"classviennacl_1_1scalar.html#a93ddffb91eb58839512f20e1f31e3eee":[6,0,0,134,3],
-"classviennacl_1_1scalar.html#a984dbf64266ea3c69a3881c3adc047c4":[6,0,0,134,11],
-"classviennacl_1_1scalar.html#a9e3fc554897e2d89583e44b23c5dbacb":[6,0,0,134,31],
-"classviennacl_1_1scalar.html#a9ed196c307e0d8651db96554f601ea0b":[6,0,0,134,28],
-"classviennacl_1_1scalar.html#aa21ce8cf63c4eb0ba5dc73cce6887edd":[6,0,0,134,34],
-"classviennacl_1_1scalar.html#aa7833efb94a6e4bef447de465ce792a3":[6,0,0,134,40],
-"classviennacl_1_1scalar.html#ab2648786b83a24feaeb3acee44d9d1f3":[6,0,0,134,29],
-"classviennacl_1_1scalar.html#ab6bdf457f3290743c79bc533eb9c6a45":[6,0,0,134,45],
-"classviennacl_1_1scalar.html#abc196fa7a5c88c211509bc08b6b3cffb":[6,0,0,134,23],
-"classviennacl_1_1scalar.html#abe064f0f208940ca6cf641e9f6c10d2e":[6,0,0,134,9],
-"classviennacl_1_1scalar.html#ace0a5bc265d1adb46887d9357d1a9a48":[6,0,0,134,39],
-"classviennacl_1_1scalar.html#ad055379bae77025ac33511134cd4d235":[6,0,0,134,32],
-"classviennacl_1_1scalar.html#adc0be626c3180f31f27a17ccb1e6826d":[6,0,0,134,1],
-"classviennacl_1_1scalar.html#ae23752527f0a3839de0ad8f4e58086e8":[6,0,0,134,4],
-"classviennacl_1_1scalar.html#ae5e3379620c912103a6ebf441f62ff74":[6,0,0,134,10],
-"classviennacl_1_1scalar.html#ae879be2125165b53e30fdf6a614d9ed2":[6,0,0,134,7],
-"classviennacl_1_1scalar.html#ae91913100fba02dc781872c78afc2eb1":[6,0,0,134,30],
-"classviennacl_1_1scalar.html#afa2d31bbedb21aeefd47b305e4638866":[6,0,0,134,47],
+"classviennacl_1_1scalar.html#a1348460f9568c82b03e702f0f462b103":[6,0,0,134,31],
+"classviennacl_1_1scalar.html#a13841f655ad0db828a051dc5c493f62e":[6,0,0,134,11],
+"classviennacl_1_1scalar.html#a20696140c3c8be4a8e57eac4c981e901":[6,0,0,134,16],
+"classviennacl_1_1scalar.html#a21cd5c847b58837aa3b9c14756a74e24":[6,0,0,134,45],
+"classviennacl_1_1scalar.html#a2848490d989bc3bbc43bce9c9e2e7e47":[6,0,0,134,47],
+"classviennacl_1_1scalar.html#a300abf63fd0a8c7d16a86b5c38fcba85":[6,0,0,134,19],
+"classviennacl_1_1scalar.html#a3a1c64828845f9cb3ff95c9b74d7d91e":[6,0,0,134,15],
+"classviennacl_1_1scalar.html#a40e8ee6244282b6fbf78721ad882d7f3":[6,0,0,134,43],
+"classviennacl_1_1scalar.html#a4796cc006370a23ad39c219345b8f9d1":[6,0,0,134,28],
+"classviennacl_1_1scalar.html#a4d3f381ef0e11f0982008478d6880260":[6,0,0,134,23],
+"classviennacl_1_1scalar.html#a4dd25a5b21b73666beb53be74c6600c0":[6,0,0,134,34],
+"classviennacl_1_1scalar.html#a5084e4fb32433ce7f89db0b360d02d6e":[6,0,0,134,12],
+"classviennacl_1_1scalar.html#a61edbb3444dc11d3f9a486471bb7c73f":[6,0,0,134,22],
+"classviennacl_1_1scalar.html#a61f087873af5cf044919a9d8cc65148b":[6,0,0,134,44],
+"classviennacl_1_1scalar.html#a62e91650a0e4c8bfea7295ec2ec135ae":[6,0,0,134,9],
+"classviennacl_1_1scalar.html#a69ce10d4e191713197693808422b44fa":[6,0,0,134,14],
+"classviennacl_1_1scalar.html#a6ade6278192bdccdea73d652572d0eff":[6,0,0,134,10],
+"classviennacl_1_1scalar.html#a6ae18afad2a90e658dad9f13590d6233":[6,0,0,134,24],
+"classviennacl_1_1scalar.html#a809eec0b71ad355e477d4373b752cdbc":[6,0,0,134,27],
+"classviennacl_1_1scalar.html#a86b08f019e042e64980409be388f964d":[6,0,0,134,17],
+"classviennacl_1_1scalar.html#a875ae8b5e6e94c647d7e936ceefcb6af":[6,0,0,134,1],
+"classviennacl_1_1scalar.html#a9a62e56c8941de87f86b6b7ccd4987e3":[6,0,0,134,7],
+"classviennacl_1_1scalar.html#a9aac3b41ba11b615ac4b7386760d8817":[6,0,0,134,37],
+"classviennacl_1_1scalar.html#aa6cfc729c8415bd77ead0279029ff10a":[6,0,0,134,0],
+"classviennacl_1_1scalar.html#aa99c65862c6bfdf615b500343a499a53":[6,0,0,134,46],
+"classviennacl_1_1scalar.html#aae8ff8c9d2f2c6a4f5dd949f357351fb":[6,0,0,134,38],
+"classviennacl_1_1scalar.html#ab3423f018ea6f514563afe6c9aa22b90":[6,0,0,134,5],
+"classviennacl_1_1scalar.html#ab66c8839c17398e14b580ce106a5065a":[6,0,0,134,18],
+"classviennacl_1_1scalar.html#abba3283c5cbc4b256b93d98cbeb7c547":[6,0,0,134,20],
+"classviennacl_1_1scalar.html#abca016cd21e4ad7b64613ce01f4b5d1b":[6,0,0,134,35],
+"classviennacl_1_1scalar.html#abe434dd18296ba57abd06953e18ff54d":[6,0,0,134,21],
+"classviennacl_1_1scalar.html#abf40c59a34e3ef69f94a6dce2864579a":[6,0,0,134,32],
+"classviennacl_1_1scalar.html#ac4a8f1294091d07ce08a843143447916":[6,0,0,134,39],
+"classviennacl_1_1scalar.html#ac9ae9cb3d8a2a4ac9b9f351b9c6728f0":[6,0,0,134,2],
+"classviennacl_1_1scalar.html#ad5a9f875223d34af2cf32c31fe38c7df":[6,0,0,134,29],
+"classviennacl_1_1scalar.html#ae52bd107e3502d5a3a617b5a2f5c2553":[6,0,0,134,8],
+"classviennacl_1_1scalar.html#ae930cde127fae5e9121b7fe1a70279d5":[6,0,0,134,41],
+"classviennacl_1_1scalar.html#af05f82cd1a2e83039743260ac20510d1":[6,0,0,134,25],
+"classviennacl_1_1scalar.html#af1efa3d0a079e942373354692ecd2645":[6,0,0,134,3],
+"classviennacl_1_1scalar.html#af534e2813fd3c2e452713b2744de19c8":[6,0,0,134,30],
+"classviennacl_1_1scalar.html#af82f32946ff33d23156c922a2be7c5c6":[6,0,0,134,40],
+"classviennacl_1_1scalar.html#afa017f43747cb3373bb3c7ef7b980c19":[6,0,0,134,33],
+"classviennacl_1_1scalar.html#afc9662763b781600f5daa2ae22961a29":[6,0,0,134,6],
 "classviennacl_1_1scalar__expression.html":[6,0,0,135],
 "classviennacl_1_1scalar__expression.html#a0193d061e7248e70783129db29a557d5":[6,0,0,135,3],
 "classviennacl_1_1scalar__expression.html#a53b924f0f346fb455ae3dc8a06f53c27":[6,0,0,135,1],
@@ -178,19 +137,19 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1sliced__ell__matrix.html#aec497ed037ef674d36729bda4db7e93f":[6,0,0,146,14],
 "classviennacl_1_1sliced__ell__matrix.html#af0672b686ad27ddcf948116bae059329":[6,0,0,146,2],
 "classviennacl_1_1toeplitz__matrix.html":[6,0,0,153],
-"classviennacl_1_1toeplitz__matrix.html#a0af2555299f10f2f56e2c58649463508":[6,0,0,153,4],
-"classviennacl_1_1toeplitz__matrix.html#a1522cb57680cd99ec5d1740ee99d2d60":[6,0,0,153,9],
-"classviennacl_1_1toeplitz__matrix.html#a1dd4cdc1c7548bba50af610bf44905f5":[6,0,0,153,11],
-"classviennacl_1_1toeplitz__matrix.html#a768848d0ac0636962b922470ce96b0b1":[6,0,0,153,2],
-"classviennacl_1_1toeplitz__matrix.html#a7d49889e7b1f9227660ed75eb769e736":[6,0,0,153,12],
-"classviennacl_1_1toeplitz__matrix.html#a84d02ddf2195dd6d5b5fd6498f200501":[6,0,0,153,10],
-"classviennacl_1_1toeplitz__matrix.html#a87aaa754492d520f8d5f376506d016d6":[6,0,0,153,3],
-"classviennacl_1_1toeplitz__matrix.html#a8827feaf51a55db8cb863590c9b6f555":[6,0,0,153,1],
-"classviennacl_1_1toeplitz__matrix.html#a9ebb8a923d7c1dfa27d6bef22c6e226e":[6,0,0,153,8],
-"classviennacl_1_1toeplitz__matrix.html#ab31a02a138d595d581541e67e9aa212e":[6,0,0,153,5],
-"classviennacl_1_1toeplitz__matrix.html#ab6d881291cd8d7711b49c1498e1cd3c2":[6,0,0,153,7],
-"classviennacl_1_1toeplitz__matrix.html#ace60368462f994e285c27150daa3eeab":[6,0,0,153,6],
-"classviennacl_1_1toeplitz__matrix.html#af5e843d27418c26c94680f70bf32b4d8":[6,0,0,153,0],
+"classviennacl_1_1toeplitz__matrix.html#a02da032567325736d8e42a0f1afc1434":[6,0,0,153,11],
+"classviennacl_1_1toeplitz__matrix.html#a177a397c0fec9467d3e85adac8b8472e":[6,0,0,153,9],
+"classviennacl_1_1toeplitz__matrix.html#a246b15c08c8f7c6bcd0d90c3ef62d230":[6,0,0,153,4],
+"classviennacl_1_1toeplitz__matrix.html#a27e7ab687472d5590f0b758ac7bf721a":[6,0,0,153,12],
+"classviennacl_1_1toeplitz__matrix.html#a40569bb6948d0eae678244eb5cac57a5":[6,0,0,153,1],
+"classviennacl_1_1toeplitz__matrix.html#a4270f98e47acf227d2ea894868213a4a":[6,0,0,153,8],
+"classviennacl_1_1toeplitz__matrix.html#a6ad1789b88235bdeddba34dcd139a142":[6,0,0,153,10],
+"classviennacl_1_1toeplitz__matrix.html#a81886bbfd3fab4c1051d1b284f2901c8":[6,0,0,153,7],
+"classviennacl_1_1toeplitz__matrix.html#abc3be2037d7dd180dcc096b14a49d7a1":[6,0,0,153,6],
+"classviennacl_1_1toeplitz__matrix.html#ac208edf451afb23b6b517887424399ce":[6,0,0,153,5],
+"classviennacl_1_1toeplitz__matrix.html#ac437a1cb3b3798fa0147b92bd8a3d79b":[6,0,0,153,0],
+"classviennacl_1_1toeplitz__matrix.html#ac56cd20ec4b03a4af7ed5498f48d4646":[6,0,0,153,2],
+"classviennacl_1_1toeplitz__matrix.html#aded8b43e7bda1df95bc777cfb718c67b":[6,0,0,153,3],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html":[6,0,0,8,3],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html#a0fc914cdbf7ee1a1a274795b0dd3d686":[6,0,0,8,3,8],
 "classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html#a2fd2bdc3fa5a1982d54db6e4c4146a04":[6,0,0,8,3,9],
@@ -249,5 +208,46 @@ var NAVTREEINDEX6 =
 "classviennacl_1_1tools_1_1shared__ptr.html":[6,0,0,8,9],
 "classviennacl_1_1tools_1_1shared__ptr.html#a0359c8b4d4a99d7496a3cbc8af50f2e9":[6,0,0,8,9,2],
 "classviennacl_1_1tools_1_1shared__ptr.html#a19cbbb3ca50f67ef4537baec91223314":[6,0,0,8,9,0],
-"classviennacl_1_1tools_1_1shared__ptr.html#a1befee22cae4f2f1b091ced117972abe":[6,0,0,8,9,6]
+"classviennacl_1_1tools_1_1shared__ptr.html#a1befee22cae4f2f1b091ced117972abe":[6,0,0,8,9,6],
+"classviennacl_1_1tools_1_1shared__ptr.html#a1f0fae94dcdff4c28eaf30ab12b07b58":[6,0,0,8,9,13],
+"classviennacl_1_1tools_1_1shared__ptr.html#a5ad52d0a07644c408c8ccf47b925fe9c":[6,0,0,8,9,11],
+"classviennacl_1_1tools_1_1shared__ptr.html#a658b230c38dc835c0f50c315494e51b3":[6,0,0,8,9,9],
+"classviennacl_1_1tools_1_1shared__ptr.html#a875b78f7a6290e6b0987f956d1fc5e33":[6,0,0,8,9,12],
+"classviennacl_1_1tools_1_1shared__ptr.html#a897c97936e57a9c51debb600881a6c00":[6,0,0,8,9,10],
+"classviennacl_1_1tools_1_1shared__ptr.html#a94b55605751a49602f2f1e8df576d740":[6,0,0,8,9,7],
+"classviennacl_1_1tools_1_1shared__ptr.html#a9c5a1acb01a2a96541f961d2ca07737e":[6,0,0,8,9,14],
+"classviennacl_1_1tools_1_1shared__ptr.html#ab2104fa6e839672da3c30400e8325e52":[6,0,0,8,9,15],
+"classviennacl_1_1tools_1_1shared__ptr.html#ab9d3450cc3e04af6bdc6bff612dc956c":[6,0,0,8,9,8],
+"classviennacl_1_1tools_1_1shared__ptr.html#ae6962753b5f7789dccb52041138b1171":[6,0,0,8,9,3],
+"classviennacl_1_1tools_1_1shared__ptr.html#aee7f42cfc5501572a40c0b1ab78d62bf":[6,0,0,8,9,5],
+"classviennacl_1_1tools_1_1shared__ptr.html#aefe4b5bbd5a4dd9636ecd60ee93ab64f":[6,0,0,8,9,1],
+"classviennacl_1_1tools_1_1shared__ptr.html#afdf25a5882d4b6e59387be662b686070":[6,0,0,8,9,4],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html":[6,0,0,8,10],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a081be125fc3eb501046cde54540402fb":[6,0,0,8,10,13],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a2507b267d71992e40afcfb62c4509e9c":[6,0,0,8,10,7],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a276f5aacea5626321de95330aff6cd5f":[6,0,0,8,10,12],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a29e3c8932f7e9dfcb122fe874691f247":[6,0,0,8,10,8],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a46620d6ed4860d68648c7f8fe9867f7b":[6,0,0,8,10,9],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a555a44840a7701fb71b963641bde311d":[6,0,0,8,10,0],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a9de1a5bd4859b425b6982a9c8d3cf0f6":[6,0,0,8,10,3],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aa0db2979027e767db60d46653524b3d4":[6,0,0,8,10,2],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aa50a78019bea41fc8d304cd2ff04abf8":[6,0,0,8,10,5],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aacb46899e0b307bd99fe1ce8315531ad":[6,0,0,8,10,11],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#abf62172bfdb5ad0fe5d65a7856cf64be":[6,0,0,8,10,6],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#ac0fb1b97a7ae4cbeea5e14658fa6adef":[6,0,0,8,10,4],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#ae403b59ea10272344a50b5120c52f7db":[6,0,0,8,10,10],
+"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#affcc73c4eb98e4b5f5742297be1bdcb2":[6,0,0,8,10,1],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html":[6,0,0,8,11],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a05167006e5e5582ae0a027b480cabdba":[6,0,0,8,11,18],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a255aebc44075b33387a151a412cbab5d":[6,0,0,8,11,3],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a25c6307db3fd2dbb791fe75fa2de4d5c":[6,0,0,8,11,12],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a36f987fc36cdf7d475335d03a1ad8f00":[6,0,0,8,11,9],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a3b2adf5c86682c548f57e55dc8657b90":[6,0,0,8,11,2],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a3fef8db019f55b71620578ef9115117c":[6,0,0,8,11,16],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a4d8c5ab6400e7065dc8d93bfab837e99":[6,0,0,8,11,4],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a70ff56b081a2e661121b6018774addaf":[6,0,0,8,11,1],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a741d9eba2d52286e13874d931c1368cc":[6,0,0,8,11,7],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a785391ab2d7630f7b806a38229868ef5":[6,0,0,8,11,14],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a7c8cce841ab671d71d97e911ed153f76":[6,0,0,8,11,17],
+"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a7ce6c3c960bf7c71b0d2d1ecede98048":[6,0,0,8,11,0]
 };
