@@ -1,46 +1,5 @@
 var NAVTREEINDEX7 =
 {
-"classviennacl_1_1tools_1_1shared__ptr.html#a1f0fae94dcdff4c28eaf30ab12b07b58":[6,0,0,8,9,13],
-"classviennacl_1_1tools_1_1shared__ptr.html#a5ad52d0a07644c408c8ccf47b925fe9c":[6,0,0,8,9,11],
-"classviennacl_1_1tools_1_1shared__ptr.html#a658b230c38dc835c0f50c315494e51b3":[6,0,0,8,9,9],
-"classviennacl_1_1tools_1_1shared__ptr.html#a875b78f7a6290e6b0987f956d1fc5e33":[6,0,0,8,9,12],
-"classviennacl_1_1tools_1_1shared__ptr.html#a897c97936e57a9c51debb600881a6c00":[6,0,0,8,9,10],
-"classviennacl_1_1tools_1_1shared__ptr.html#a94b55605751a49602f2f1e8df576d740":[6,0,0,8,9,7],
-"classviennacl_1_1tools_1_1shared__ptr.html#a9c5a1acb01a2a96541f961d2ca07737e":[6,0,0,8,9,14],
-"classviennacl_1_1tools_1_1shared__ptr.html#ab2104fa6e839672da3c30400e8325e52":[6,0,0,8,9,15],
-"classviennacl_1_1tools_1_1shared__ptr.html#ab9d3450cc3e04af6bdc6bff612dc956c":[6,0,0,8,9,8],
-"classviennacl_1_1tools_1_1shared__ptr.html#ae6962753b5f7789dccb52041138b1171":[6,0,0,8,9,3],
-"classviennacl_1_1tools_1_1shared__ptr.html#aee7f42cfc5501572a40c0b1ab78d62bf":[6,0,0,8,9,5],
-"classviennacl_1_1tools_1_1shared__ptr.html#aefe4b5bbd5a4dd9636ecd60ee93ab64f":[6,0,0,8,9,1],
-"classviennacl_1_1tools_1_1shared__ptr.html#afdf25a5882d4b6e59387be662b686070":[6,0,0,8,9,4],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html":[6,0,0,8,10],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a081be125fc3eb501046cde54540402fb":[6,0,0,8,10,13],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a2507b267d71992e40afcfb62c4509e9c":[6,0,0,8,10,7],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a276f5aacea5626321de95330aff6cd5f":[6,0,0,8,10,12],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a29e3c8932f7e9dfcb122fe874691f247":[6,0,0,8,10,8],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a46620d6ed4860d68648c7f8fe9867f7b":[6,0,0,8,10,9],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a555a44840a7701fb71b963641bde311d":[6,0,0,8,10,0],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#a9de1a5bd4859b425b6982a9c8d3cf0f6":[6,0,0,8,10,3],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aa0db2979027e767db60d46653524b3d4":[6,0,0,8,10,2],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aa50a78019bea41fc8d304cd2ff04abf8":[6,0,0,8,10,5],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#aacb46899e0b307bd99fe1ce8315531ad":[6,0,0,8,10,11],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#abf62172bfdb5ad0fe5d65a7856cf64be":[6,0,0,8,10,6],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#ac0fb1b97a7ae4cbeea5e14658fa6adef":[6,0,0,8,10,4],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#ae403b59ea10272344a50b5120c52f7db":[6,0,0,8,10,10],
-"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html#affcc73c4eb98e4b5f5742297be1bdcb2":[6,0,0,8,10,1],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html":[6,0,0,8,11],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a05167006e5e5582ae0a027b480cabdba":[6,0,0,8,11,18],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a255aebc44075b33387a151a412cbab5d":[6,0,0,8,11,3],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a25c6307db3fd2dbb791fe75fa2de4d5c":[6,0,0,8,11,12],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a36f987fc36cdf7d475335d03a1ad8f00":[6,0,0,8,11,9],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a3b2adf5c86682c548f57e55dc8657b90":[6,0,0,8,11,2],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a3fef8db019f55b71620578ef9115117c":[6,0,0,8,11,16],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a4d8c5ab6400e7065dc8d93bfab837e99":[6,0,0,8,11,4],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a70ff56b081a2e661121b6018774addaf":[6,0,0,8,11,1],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a741d9eba2d52286e13874d931c1368cc":[6,0,0,8,11,7],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a785391ab2d7630f7b806a38229868ef5":[6,0,0,8,11,14],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a7c8cce841ab671d71d97e911ed153f76":[6,0,0,8,11,17],
-"classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a7ce6c3c960bf7c71b0d2d1ecede98048":[6,0,0,8,11,0],
 "classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a89e8ccbf2a88b5201522857f2ddbf4c4":[6,0,0,8,11,5],
 "classviennacl_1_1tools_1_1sparse__matrix__adapter.html#a9b6f535bddf33be26055c157bbb5a3b0":[6,0,0,8,11,19],
 "classviennacl_1_1tools_1_1sparse__matrix__adapter.html#abc2ca5efdfa121c92ef06bbf57637cc5":[6,0,0,8,11,15],
@@ -60,37 +19,37 @@ var NAVTREEINDEX7 =
 "classviennacl_1_1unknown__norm__exception.html":[6,0,0,155],
 "classviennacl_1_1unknown__norm__exception.html#a54d00eebcc284ec99fe2ad144f594265":[6,0,0,155,0],
 "classviennacl_1_1vandermonde__matrix.html":[6,0,0,156],
-"classviennacl_1_1vandermonde__matrix.html#a106c7f6cd734a9036a421fcea3f21bb1":[6,0,0,156,12],
-"classviennacl_1_1vandermonde__matrix.html#a1bf2f35203ef6179dfdd5382e07b0d9b":[6,0,0,156,2],
-"classviennacl_1_1vandermonde__matrix.html#a2b9f5ed543e7e148569821ce115438f8":[6,0,0,156,6],
-"classviennacl_1_1vandermonde__matrix.html#a5418d4fd332df9df76d94c3d19a0425d":[6,0,0,156,3],
-"classviennacl_1_1vandermonde__matrix.html#a6e286a8425d504264b8b5910c6d0b531":[6,0,0,156,5],
-"classviennacl_1_1vandermonde__matrix.html#a78e04f188b375ea59ce39e9fb6ee5c18":[6,0,0,156,9],
-"classviennacl_1_1vandermonde__matrix.html#a92d6be5a35f867bdac45cd32ac7ebed2":[6,0,0,156,10],
-"classviennacl_1_1vandermonde__matrix.html#a9ada537246eda3970241e1d499d5ec28":[6,0,0,156,0],
-"classviennacl_1_1vandermonde__matrix.html#ab12e0f085c99524703bfdd67a58d0edc":[6,0,0,156,4],
-"classviennacl_1_1vandermonde__matrix.html#ab899a13f35a951e1fd94767dbf83e311":[6,0,0,156,8],
-"classviennacl_1_1vandermonde__matrix.html#ae021cff8cdbc8d3a9943c171385191dd":[6,0,0,156,11],
-"classviennacl_1_1vandermonde__matrix.html#afd9a029d3f4bcbadd2fa2b6022af2703":[6,0,0,156,1],
-"classviennacl_1_1vandermonde__matrix.html#afed38343a2f69b5248c58a3cfd03d04b":[6,0,0,156,7],
+"classviennacl_1_1vandermonde__matrix.html#a12be83df9631afeca56eb63096a312f0":[6,0,0,156,0],
+"classviennacl_1_1vandermonde__matrix.html#a2599d32b10b1051cec65cf6b9458f195":[6,0,0,156,9],
+"classviennacl_1_1vandermonde__matrix.html#a3fdab282172b78263faa3e782adb5ed0":[6,0,0,156,2],
+"classviennacl_1_1vandermonde__matrix.html#a5ea4016ca29b5a9c65ce34192c574bd3":[6,0,0,156,1],
+"classviennacl_1_1vandermonde__matrix.html#a63629c958e216bc68d67e2d3fbe75577":[6,0,0,156,4],
+"classviennacl_1_1vandermonde__matrix.html#a6b3eadef03c3a238fd1ec8e62b176926":[6,0,0,156,12],
+"classviennacl_1_1vandermonde__matrix.html#a8f6d67f35d5ab894c818252f393ba4b9":[6,0,0,156,7],
+"classviennacl_1_1vandermonde__matrix.html#a94af00b5b37b587aa54eb7dfa69ed3d0":[6,0,0,156,8],
+"classviennacl_1_1vandermonde__matrix.html#aa2454bc5dc95863e93f70bb11c67aadf":[6,0,0,156,5],
+"classviennacl_1_1vandermonde__matrix.html#aa2731747886c5d9bb625c996baa369cf":[6,0,0,156,10],
+"classviennacl_1_1vandermonde__matrix.html#ab478479b8cd5e48262adc6549ad0e2be":[6,0,0,156,3],
+"classviennacl_1_1vandermonde__matrix.html#acc23bc5cfe84e53e8eb8293b964683a8":[6,0,0,156,11],
+"classviennacl_1_1vandermonde__matrix.html#ae0a32feff8be75c7a4e12adcab31b7c5":[6,0,0,156,6],
 "classviennacl_1_1vector.html":[6,0,0,157],
-"classviennacl_1_1vector.html#a0265a7e75988e868bfbdfe2aaeb19487":[6,0,0,157,13],
-"classviennacl_1_1vector.html#a02c6926515cfe978cc4e11094f2d1f0f":[6,0,0,157,9],
-"classviennacl_1_1vector.html#a1c172d55c8c96822e661cd7311ce73ae":[6,0,0,157,1],
-"classviennacl_1_1vector.html#a3384c255d4757a235afbebacbbe82495":[6,0,0,157,4],
-"classviennacl_1_1vector.html#a3848da3369c5385bacb00cdce9acd3a4":[6,0,0,157,10],
-"classviennacl_1_1vector.html#a3ec15c5a5edb007132ff0949664cfdcb":[6,0,0,157,12],
-"classviennacl_1_1vector.html#a48bc22bb43ec5dff676b1b428c81f331":[6,0,0,157,5],
-"classviennacl_1_1vector.html#a51317190789589583d9e47808ae77fb5":[6,0,0,157,6],
-"classviennacl_1_1vector.html#a5155eca00e71a4e9fd89772d918783b3":[6,0,0,157,16],
-"classviennacl_1_1vector.html#a8551e636fb29c501be9abf165f22e147":[6,0,0,157,7],
-"classviennacl_1_1vector.html#a9df34196fc05e9c83c83f9d5eb7c1c97":[6,0,0,157,14],
-"classviennacl_1_1vector.html#a9f8cd5baea4bf57639586d38f5ca20e1":[6,0,0,157,0],
-"classviennacl_1_1vector.html#acdc1544d571d7ac5b03c22219cab6c33":[6,0,0,157,11],
-"classviennacl_1_1vector.html#ae07f0ce8823a6d07d096f443bf8b27d3":[6,0,0,157,15],
-"classviennacl_1_1vector.html#ae3f078bdf622bbbb9425f0eda22e14f4":[6,0,0,157,2],
-"classviennacl_1_1vector.html#aea709d4c3037f3da9492c569612835be":[6,0,0,157,8],
-"classviennacl_1_1vector.html#afaa66212b8e58889fb76782f269a4e65":[6,0,0,157,3],
+"classviennacl_1_1vector.html#a021fdd9e74d47f1bbbebe3141e3804ea":[6,0,0,157,1],
+"classviennacl_1_1vector.html#a07bb8d387673358d18fbe939b9f118fc":[6,0,0,157,7],
+"classviennacl_1_1vector.html#a1b73aadf0c7b6c0028fd237ebb30c767":[6,0,0,157,14],
+"classviennacl_1_1vector.html#a3c2a39b9ea60d9086bcd77b5043a21dc":[6,0,0,157,6],
+"classviennacl_1_1vector.html#a3fbd82bb7795e827693eaedf0d7e67eb":[6,0,0,157,11],
+"classviennacl_1_1vector.html#a45b1a9e18907072bace972c9acae6c8a":[6,0,0,157,5],
+"classviennacl_1_1vector.html#a4bd109b6136687f5aefcf7e3595f348a":[6,0,0,157,10],
+"classviennacl_1_1vector.html#a59f2ec43f298cc04d2f2bbbeee239bfe":[6,0,0,157,16],
+"classviennacl_1_1vector.html#a64491dd219701749e8afb18b148be471":[6,0,0,157,2],
+"classviennacl_1_1vector.html#a6bcfb05948eaf1d9b26e5e73e28dc94f":[6,0,0,157,8],
+"classviennacl_1_1vector.html#a7e683e134c8aad7b3cd057776a58c4c4":[6,0,0,157,0],
+"classviennacl_1_1vector.html#a805300e6add819e9fe6a5e3f27f42275":[6,0,0,157,3],
+"classviennacl_1_1vector.html#a8cbd168a74c13a026466575b88c4e126":[6,0,0,157,12],
+"classviennacl_1_1vector.html#ab45bacf9fd09acba5ca324b6a8834d72":[6,0,0,157,4],
+"classviennacl_1_1vector.html#ab8d0867a867e4aae13450a222c7a5f4c":[6,0,0,157,13],
+"classviennacl_1_1vector.html#aba321298847ca424e2656292138265d5":[6,0,0,157,9],
+"classviennacl_1_1vector.html#addd07176a7a8612888ce2386b57bc5cb":[6,0,0,157,15],
 "classviennacl_1_1vector__base.html":[6,0,0,158],
 "classviennacl_1_1vector__base.html#a0064de5b081cae912adc624860d66847":[6,0,0,158,4],
 "classviennacl_1_1vector__base.html#a00ce836edfc2e9022f289faf9cd1d2f8":[6,0,0,158,63],
@@ -176,16 +135,16 @@ var NAVTREEINDEX7 =
 "classviennacl_1_1vector__expression.html#af32367d489747d02c0e48e5fcca12469":[6,0,0,159,5],
 "classviennacl_1_1vector__expression.html#aff94c356857f48e8d676ec82c6f98c03":[6,0,0,159,2],
 "classviennacl_1_1vector__iterator.html":[6,0,0,160],
-"classviennacl_1_1vector__iterator.html#a070223d6eefc8da36c64a4c47618b154":[6,0,0,160,2],
-"classviennacl_1_1vector__iterator.html#a07383f1103e3fb45a61f55d5d39b9022":[6,0,0,160,7],
-"classviennacl_1_1vector__iterator.html#a16509d8f948514a2f81e0b83cf06396e":[6,0,0,160,9],
-"classviennacl_1_1vector__iterator.html#a4110a9e5c6b1c76fc16ee7afb3bee1f6":[6,0,0,160,5],
-"classviennacl_1_1vector__iterator.html#a54c60d200c37f74c74ae7f019533d8e4":[6,0,0,160,1],
-"classviennacl_1_1vector__iterator.html#a70abd3b6fea5777f3af802e1fdd1134f":[6,0,0,160,6],
-"classviennacl_1_1vector__iterator.html#a7ec9ab6a284faad9433e7d65b883672b":[6,0,0,160,3],
-"classviennacl_1_1vector__iterator.html#acc28ef3263b6eb16360b2e39ab1bcf9a":[6,0,0,160,0],
-"classviennacl_1_1vector__iterator.html#ade476415f537c00a88beb0b59c3d950e":[6,0,0,160,4],
-"classviennacl_1_1vector__iterator.html#afc719587759e23e8b0700622eeed6591":[6,0,0,160,8],
+"classviennacl_1_1vector__iterator.html#a28ca2b649fe60663bb841a1f63de5f6a":[6,0,0,160,4],
+"classviennacl_1_1vector__iterator.html#a3354efa8f7135919a35b13e4bf8edff8":[6,0,0,160,5],
+"classviennacl_1_1vector__iterator.html#a3d6f0cdf4dc263a0158620734e1e5c0b":[6,0,0,160,0],
+"classviennacl_1_1vector__iterator.html#a47959ab718b446e075fe3c9493228a1b":[6,0,0,160,3],
+"classviennacl_1_1vector__iterator.html#a569410cd7f08cff5c98dfccf36d8e4af":[6,0,0,160,2],
+"classviennacl_1_1vector__iterator.html#a5e0e454f6331493d811d0c01e5f62a7a":[6,0,0,160,8],
+"classviennacl_1_1vector__iterator.html#a66cfad479c0e3fc45e0b01aed8cf44d7":[6,0,0,160,7],
+"classviennacl_1_1vector__iterator.html#a945eb5d3193eaad1c776c1b7666d0e98":[6,0,0,160,9],
+"classviennacl_1_1vector__iterator.html#aa7ffa22176b67ae742e7cdacc96cf739":[6,0,0,160,1],
+"classviennacl_1_1vector__iterator.html#adf08866ed77efe9aa69bfb9a678dd7ca":[6,0,0,160,6],
 "classviennacl_1_1vector__range.html":[6,0,0,161],
 "classviennacl_1_1vector__range.html#a0e8ff91829f522c94dac80759ff20afe":[6,0,0,161,9],
 "classviennacl_1_1vector__range.html#a200a915e7a287327517a5d003221d0dd":[6,0,0,161,11],
@@ -249,5 +208,46 @@ var NAVTREEINDEX7 =
 "clear_8hpp.html#a2097f610b02ff1f371fc6202a9519d00":[7,0,3,10,0,1],
 "clear_8hpp.html#a22ab64b1df12a9da0423e5cad52ea367":[7,0,3,10,0,0],
 "clear_8hpp_source.html":[7,0,3,10,0],
-"command__queue_8hpp.html":[7,0,3,7,1]
+"command__queue_8hpp.html":[7,0,3,7,1],
+"command__queue_8hpp_source.html":[7,0,3,7,1],
+"compressed__compressed__matrix_8hpp.html":[7,0,3,12],
+"compressed__compressed__matrix_8hpp.html#a33af429555220f128281e71d75932ea3":[7,0,3,12,4],
+"compressed__compressed__matrix_8hpp.html#a4513747040c2f4c7951d3e866fbb7fb4":[7,0,3,12,3],
+"compressed__compressed__matrix_8hpp.html#a4b65590ba7d3edb355ff50e46ea26195":[7,0,3,12,5],
+"compressed__compressed__matrix_8hpp.html#a99c761df7c27ca099b03b46931911648":[7,0,3,12,1],
+"compressed__compressed__matrix_8hpp.html#ab83a1719b10d1145a9d7035487c8f2ce":[7,0,3,12,2],
+"compressed__compressed__matrix_8hpp_source.html":[7,0,3,12],
+"compressed__matrix_8hpp.html":[7,0,3,13],
+"compressed__matrix_8hpp.html#a2e37765605f0b2728573419f0f6e691b":[7,0,3,13,6],
+"compressed__matrix_8hpp.html#ab4e5611375f016807a103ff293d3dc8a":[7,0,3,13,1],
+"compressed__matrix_8hpp.html#acee17c9f4826a3a7574c6d94fd1946c4":[7,0,3,13,3],
+"compressed__matrix_8hpp.html#ae58906ac8a192c572283fbaf6347dda5":[7,0,3,13,5],
+"compressed__matrix_8hpp.html#aeae943c139b8f5faf2ca261c1a919e4d":[7,0,3,13,4],
+"compressed__matrix_8hpp.html#afa72783b1449b3eef3fc2d5bab759871":[7,0,3,13,2],
+"compressed__matrix_8hpp_source.html":[7,0,3,13],
+"config_8hpp.html":[7,0,3,4,1,1,3],
+"config_8hpp.html#a62bb16be6604cdcfdf2e6e9026876cc7":[7,0,3,4,1,1,3,2],
+"config_8hpp.html#a9d776da4d91c5393d73cae382fdbc48d":[7,0,3,4,1,1,3,1],
+"config_8hpp.html#aa7220f1cb89f26a7b0791610a17330b9":[7,0,3,4,1,1,3,0],
+"config_8hpp.html#ad37f4af0725c7960b6450e315c10422e":[7,0,3,4,1,1,3,3],
+"config_8hpp_source.html":[7,0,3,4,1,1,3],
+"context_8hpp.html":[7,0,3,14],
+"context_8hpp_source.html":[7,0,3,14],
+"coordinate__matrix_8hpp.html":[7,0,3,15],
+"coordinate__matrix_8hpp.html#a09970b6d02bfa2dd17a7d63d1fcbe18f":[7,0,3,15,4],
+"coordinate__matrix_8hpp.html#a3947c4a75b60a14b7051746805e1bc47":[7,0,3,15,1],
+"coordinate__matrix_8hpp.html#a6f355f732e924a4233950b0e77a14db5":[7,0,3,15,3],
+"coordinate__matrix_8hpp.html#a9285f6f62eebc19c0756c5a31f3806f1":[7,0,3,15,2],
+"coordinate__matrix_8hpp_source.html":[7,0,3,15],
+"cpu_2fallback_8hpp.html":[7,0,3,2,0,0,1,0],
+"cpu_2fallback_8hpp.html#a070629d9c5946699aec773a48fba07b0":[7,0,3,2,0,0,1,0,0],
+"cpu_2fallback_8hpp.html#a165c1226624152cc53519132d5de1b87":[7,0,3,2,0,0,1,0,7],
+"cpu_2fallback_8hpp.html#a65e74ae5066b1102a3568fe15a7fd288":[7,0,3,2,0,0,1,0,2],
+"cpu_2fallback_8hpp.html#a6615744bb3040f75c0023d97c5086223":[7,0,3,2,0,0,1,0,1],
+"cpu_2fallback_8hpp.html#a7caa46a7ff9e847f9dec9107964082d2":[7,0,3,2,0,0,1,0,5],
+"cpu_2fallback_8hpp.html#a8f1e860654bb82ffb972d689410151b9":[7,0,3,2,0,0,1,0,3],
+"cpu_2fallback_8hpp.html#ae4f5d78cd7583c08356ddc8fdd11861b":[7,0,3,2,0,0,1,0,6],
+"cpu_2fallback_8hpp.html#af964598fd12dad32a11beb80bb838626":[7,0,3,2,0,0,1,0,4],
+"cpu_2fallback_8hpp_source.html":[7,0,3,2,0,0,1,0],
+"cpu__ram_8hpp.html":[7,0,3,0,0]
 };
