@@ -1,56 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"command__queue_8hpp_source.html":[7,0,3,7,1],
-"compressed__compressed__matrix_8hpp.html":[7,0,3,12],
-"compressed__compressed__matrix_8hpp.html#a33af429555220f128281e71d75932ea3":[7,0,3,12,4],
-"compressed__compressed__matrix_8hpp.html#a4513747040c2f4c7951d3e866fbb7fb4":[7,0,3,12,3],
-"compressed__compressed__matrix_8hpp.html#a4b65590ba7d3edb355ff50e46ea26195":[7,0,3,12,5],
-"compressed__compressed__matrix_8hpp.html#a99c761df7c27ca099b03b46931911648":[7,0,3,12,1],
-"compressed__compressed__matrix_8hpp.html#ab83a1719b10d1145a9d7035487c8f2ce":[7,0,3,12,2],
-"compressed__compressed__matrix_8hpp_source.html":[7,0,3,12],
-"compressed__matrix_8hpp.html":[7,0,3,13],
-"compressed__matrix_8hpp.html#a2e37765605f0b2728573419f0f6e691b":[7,0,3,13,6],
-"compressed__matrix_8hpp.html#ab4e5611375f016807a103ff293d3dc8a":[7,0,3,13,1],
-"compressed__matrix_8hpp.html#acee17c9f4826a3a7574c6d94fd1946c4":[7,0,3,13,3],
-"compressed__matrix_8hpp.html#ae58906ac8a192c572283fbaf6347dda5":[7,0,3,13,5],
-"compressed__matrix_8hpp.html#aeae943c139b8f5faf2ca261c1a919e4d":[7,0,3,13,4],
-"compressed__matrix_8hpp.html#afa72783b1449b3eef3fc2d5bab759871":[7,0,3,13,2],
-"compressed__matrix_8hpp_source.html":[7,0,3,13],
-"config_8hpp.html":[7,0,3,4,1,1,3],
-"config_8hpp.html#a62bb16be6604cdcfdf2e6e9026876cc7":[7,0,3,4,1,1,3,2],
-"config_8hpp.html#a9d776da4d91c5393d73cae382fdbc48d":[7,0,3,4,1,1,3,1],
-"config_8hpp.html#aa7220f1cb89f26a7b0791610a17330b9":[7,0,3,4,1,1,3,0],
-"config_8hpp.html#ad37f4af0725c7960b6450e315c10422e":[7,0,3,4,1,1,3,3],
-"config_8hpp_source.html":[7,0,3,4,1,1,3],
-"context_8hpp.html":[7,0,3,14],
-"context_8hpp_source.html":[7,0,3,14],
-"coordinate__matrix_8hpp.html":[7,0,3,15],
-"coordinate__matrix_8hpp.html#a09970b6d02bfa2dd17a7d63d1fcbe18f":[7,0,3,15,4],
-"coordinate__matrix_8hpp.html#a3947c4a75b60a14b7051746805e1bc47":[7,0,3,15,1],
-"coordinate__matrix_8hpp.html#a6f355f732e924a4233950b0e77a14db5":[7,0,3,15,3],
-"coordinate__matrix_8hpp.html#a9285f6f62eebc19c0756c5a31f3806f1":[7,0,3,15,2],
-"coordinate__matrix_8hpp_source.html":[7,0,3,15],
-"cpu_2fallback_8hpp.html":[7,0,3,2,0,0,1,0],
-"cpu_2fallback_8hpp.html#a070629d9c5946699aec773a48fba07b0":[7,0,3,2,0,0,1,0,5],
-"cpu_2fallback_8hpp.html#a0d4060b829741253b9ae57cf90576847":[7,0,3,2,0,0,1,0,10],
-"cpu_2fallback_8hpp.html#a165c1226624152cc53519132d5de1b87":[7,0,3,2,0,0,1,0,17],
-"cpu_2fallback_8hpp.html#a4759a9e73b65e388fe698f63344f909a":[7,0,3,2,0,0,1,0,13],
-"cpu_2fallback_8hpp.html#a65e74ae5066b1102a3568fe15a7fd288":[7,0,3,2,0,0,1,0,7],
-"cpu_2fallback_8hpp.html#a6615744bb3040f75c0023d97c5086223":[7,0,3,2,0,0,1,0,6],
-"cpu_2fallback_8hpp.html#a6d0cfb8b37b4d95be48cad46ca1101e8":[7,0,3,2,0,0,1,0,1],
-"cpu_2fallback_8hpp.html#a74a4ffc70647f228f4192b87a443be14":[7,0,3,2,0,0,1,0,0],
-"cpu_2fallback_8hpp.html#a7caa46a7ff9e847f9dec9107964082d2":[7,0,3,2,0,0,1,0,15],
-"cpu_2fallback_8hpp.html#a8f1e860654bb82ffb972d689410151b9":[7,0,3,2,0,0,1,0,8],
-"cpu_2fallback_8hpp.html#aa1f52762022d64aa70d34d154d91a790":[7,0,3,2,0,0,1,0,9],
-"cpu_2fallback_8hpp.html#ab19939c8d0ef7caab3278f88a848ed7e":[7,0,3,2,0,0,1,0,11],
-"cpu_2fallback_8hpp.html#ab948a2cd027ff4829b64ccf0bfc5957b":[7,0,3,2,0,0,1,0,3],
-"cpu_2fallback_8hpp.html#abbf56d530bdc3464d87a59253ab81d9f":[7,0,3,2,0,0,1,0,2],
-"cpu_2fallback_8hpp.html#acad63fbad6fc521e18dcc42b0a344a22":[7,0,3,2,0,0,1,0,4],
-"cpu_2fallback_8hpp.html#ae4f5d78cd7583c08356ddc8fdd11861b":[7,0,3,2,0,0,1,0,16],
-"cpu_2fallback_8hpp.html#aeb270016572568b12eab41510b457bcd":[7,0,3,2,0,0,1,0,12],
-"cpu_2fallback_8hpp.html#af964598fd12dad32a11beb80bb838626":[7,0,3,2,0,0,1,0,14],
-"cpu_2fallback_8hpp_source.html":[7,0,3,2,0,0,1,0],
-"cpu__ram_8hpp.html":[7,0,3,0,0],
 "cpu__ram_8hpp.html#a307263f9deed5ce983ae50ebda5c1e0b":[7,0,3,0,0,2],
 "cpu__ram_8hpp.html#a3fc1147917966bad9e3786c1d46d4169":[7,0,3,0,0,1],
 "cpu__ram_8hpp.html#a55bf912f3d21fcf7d348d59e1c8bef7d":[7,0,3,0,0,3],
@@ -249,5 +198,56 @@ var NAVTREEINDEX8 =
 "cuda_2matrix__operations_8hpp.html#acefdde109434edb771c8e599919661cc":[7,0,3,4,0,12,40],
 "cuda_2matrix__operations_8hpp.html#ad75b04f178a6ef90166e1bf6503dbe95":[7,0,3,4,0,12,20],
 "cuda_2matrix__operations_8hpp.html#adfe3d5deb6c411a4ee7a8827500a73ce":[7,0,3,4,0,12,39],
-"cuda_2matrix__operations_8hpp.html#ae9d9309bcf7f8ae6f5fba0a55a11a89e":[7,0,3,4,0,12,23]
+"cuda_2matrix__operations_8hpp.html#ae9d9309bcf7f8ae6f5fba0a55a11a89e":[7,0,3,4,0,12,23],
+"cuda_2matrix__operations_8hpp.html#af7b3ed1cd1f0dffb5b3bb0b1f8d9753e":[7,0,3,4,0,12,33],
+"cuda_2matrix__operations_8hpp.html#afbd21e3e8abdf10a79ba272244ac233b":[7,0,3,4,0,12,16],
+"cuda_2matrix__operations_8hpp.html#afc09fa89bb645f9480a2b6e8e7efdda5":[7,0,3,4,0,12,8],
+"cuda_2matrix__operations_8hpp.html#afd7583ae441f66185764ae2fed763feb":[7,0,3,4,0,12,37],
+"cuda_2matrix__operations_8hpp_source.html":[7,0,3,4,0,12],
+"cuda_2misc__operations_8hpp.html":[7,0,3,4,0,16],
+"cuda_2misc__operations_8hpp.html#a221e340d7c16d34426307e5cbb2cacb5":[7,0,3,4,0,16,1],
+"cuda_2misc__operations_8hpp.html#a3ccc8d796f7466d354392d4c6c4f936b":[7,0,3,4,0,16,0],
+"cuda_2misc__operations_8hpp_source.html":[7,0,3,4,0,16],
+"cuda_2nmf__operations_8hpp.html":[7,0,3,4,0,17],
+"cuda_2nmf__operations_8hpp.html#a453ec252f6dc75aca7e04d13950ee33b":[7,0,3,4,0,17,0],
+"cuda_2nmf__operations_8hpp.html#ad9b529eaaf42d91af16200a3def8971c":[7,0,3,4,0,17,1],
+"cuda_2nmf__operations_8hpp_source.html":[7,0,3,4,0,17],
+"cuda_2scalar__operations_8hpp.html":[7,0,3,4,0,18],
+"cuda_2scalar__operations_8hpp.html#a050aa10b0d22325f6489ca618366da71":[7,0,3,4,0,18,1],
+"cuda_2scalar__operations_8hpp.html#a07e0be416a8732c6a0637cf7f6b77ab4":[7,0,3,4,0,18,9],
+"cuda_2scalar__operations_8hpp.html#a0a4228286b28270ac6c3d870bd3795cd":[7,0,3,4,0,18,10],
+"cuda_2scalar__operations_8hpp.html#a0da1459f4ea0123577007992c1bc0b88":[7,0,3,4,0,18,4],
+"cuda_2scalar__operations_8hpp.html#a46cc5446cd00d687be1828a5bd661542":[7,0,3,4,0,18,14],
+"cuda_2scalar__operations_8hpp.html#a575576cdbfb3b25a9f0a08ea95545606":[7,0,3,4,0,18,7],
+"cuda_2scalar__operations_8hpp.html#a585713583193f822129f9ad731add69f":[7,0,3,4,0,18,5],
+"cuda_2scalar__operations_8hpp.html#a5b68f30ea78fb683bf95c102cc57ced3":[7,0,3,4,0,18,12],
+"cuda_2scalar__operations_8hpp.html#a8fc7dbf404b544c4a8d136ee169fc5a7":[7,0,3,4,0,18,8],
+"cuda_2scalar__operations_8hpp.html#a977bbf7c99c8698869270197663b7c5f":[7,0,3,4,0,18,0],
+"cuda_2scalar__operations_8hpp.html#aa7cca68c538586814cac5e7cf511a685":[7,0,3,4,0,18,2],
+"cuda_2scalar__operations_8hpp.html#ab31bfc6b874a06a0fa57a2bafa1510d4":[7,0,3,4,0,18,13],
+"cuda_2scalar__operations_8hpp.html#ab450fb683f732284d90281a6d1debd2b":[7,0,3,4,0,18,11],
+"cuda_2scalar__operations_8hpp.html#aca3f1e982cff8e1d86a38572d106e702":[7,0,3,4,0,18,3],
+"cuda_2scalar__operations_8hpp.html#ae960a90da7af9f5b805d55a8c5fb800f":[7,0,3,4,0,18,6],
+"cuda_2scalar__operations_8hpp_source.html":[7,0,3,4,0,18],
+"cuda_2sparse__matrix__operations_8hpp.html":[7,0,3,4,0,19],
+"cuda_2sparse__matrix__operations_8hpp.html#a024534399717753627909b438923214a":[7,0,3,4,0,19,7],
+"cuda_2sparse__matrix__operations_8hpp.html#a0d532743e1fe84992a76db74b9b1ffd1":[7,0,3,4,0,19,5],
+"cuda_2sparse__matrix__operations_8hpp.html#a0d90ae5104947ac08924577953bef578":[7,0,3,4,0,19,39],
+"cuda_2sparse__matrix__operations_8hpp.html#a0ef28a94368c9b52dc01d02303c012c1":[7,0,3,4,0,19,15],
+"cuda_2sparse__matrix__operations_8hpp.html#a162b793a59cb8435e2c8021baba67063":[7,0,3,4,0,19,28],
+"cuda_2sparse__matrix__operations_8hpp.html#a2274b07759c6f58ef22fc899f2e71df0":[7,0,3,4,0,19,42],
+"cuda_2sparse__matrix__operations_8hpp.html#a3a7b9b0998cc5a4c69049be2e0d70008":[7,0,3,4,0,19,26],
+"cuda_2sparse__matrix__operations_8hpp.html#a3ae63b5b65fcc115e6d03c8781aaed65":[7,0,3,4,0,19,18],
+"cuda_2sparse__matrix__operations_8hpp.html#a4138788ef0f9453e5cec339748b684f7":[7,0,3,4,0,19,27],
+"cuda_2sparse__matrix__operations_8hpp.html#a43b31c772693ff5486a7d6b97984f11d":[7,0,3,4,0,19,8],
+"cuda_2sparse__matrix__operations_8hpp.html#a43f99d1c4b65b6f8479a9a7a530de04a":[7,0,3,4,0,19,9],
+"cuda_2sparse__matrix__operations_8hpp.html#a45615bf3f3314b66269070ae06bc3386":[7,0,3,4,0,19,44],
+"cuda_2sparse__matrix__operations_8hpp.html#a4a8d6aa23566b195f88cd484f5847ab2":[7,0,3,4,0,19,43],
+"cuda_2sparse__matrix__operations_8hpp.html#a56b30f30bab469b7ee9efa74a0479b0a":[7,0,3,4,0,19,6],
+"cuda_2sparse__matrix__operations_8hpp.html#a57dca1940b92d3425f2b54b91c4c978d":[7,0,3,4,0,19,10],
+"cuda_2sparse__matrix__operations_8hpp.html#a58667ad168f3038faf582fd9b7bcfe63":[7,0,3,4,0,19,17],
+"cuda_2sparse__matrix__operations_8hpp.html#a58f92a1210124363530b848ddbb2608e":[7,0,3,4,0,19,32],
+"cuda_2sparse__matrix__operations_8hpp.html#a5df5057dcbcb5b9aaecdd1044fc91471":[7,0,3,4,0,19,45],
+"cuda_2sparse__matrix__operations_8hpp.html#a62fe3f2822e97ce4a612c08271bff4ab":[7,0,3,4,0,19,20],
+"cuda_2sparse__matrix__operations_8hpp.html#a660a484e368e5bfb2cdf4ad9e726739d":[7,0,3,4,0,19,41]
 };
