@@ -1,80 +1,29 @@
 var NAVTREEINDEX9 =
 {
-"cuda_2matrix__operations_8hpp.html#af7b3ed1cd1f0dffb5b3bb0b1f8d9753e":[7,0,3,4,0,12,33],
-"cuda_2matrix__operations_8hpp.html#afbd21e3e8abdf10a79ba272244ac233b":[7,0,3,4,0,12,16],
-"cuda_2matrix__operations_8hpp.html#afc09fa89bb645f9480a2b6e8e7efdda5":[7,0,3,4,0,12,8],
-"cuda_2matrix__operations_8hpp.html#afd7583ae441f66185764ae2fed763feb":[7,0,3,4,0,12,37],
-"cuda_2matrix__operations_8hpp_source.html":[7,0,3,4,0,12],
-"cuda_2misc__operations_8hpp.html":[7,0,3,4,0,16],
-"cuda_2misc__operations_8hpp.html#a221e340d7c16d34426307e5cbb2cacb5":[7,0,3,4,0,16,1],
-"cuda_2misc__operations_8hpp.html#a3ccc8d796f7466d354392d4c6c4f936b":[7,0,3,4,0,16,0],
-"cuda_2misc__operations_8hpp_source.html":[7,0,3,4,0,16],
-"cuda_2nmf__operations_8hpp.html":[7,0,3,4,0,17],
-"cuda_2nmf__operations_8hpp.html#a453ec252f6dc75aca7e04d13950ee33b":[7,0,3,4,0,17,0],
-"cuda_2nmf__operations_8hpp.html#ad9b529eaaf42d91af16200a3def8971c":[7,0,3,4,0,17,1],
-"cuda_2nmf__operations_8hpp_source.html":[7,0,3,4,0,17],
-"cuda_2scalar__operations_8hpp.html":[7,0,3,4,0,18],
-"cuda_2scalar__operations_8hpp.html#a050aa10b0d22325f6489ca618366da71":[7,0,3,4,0,18,1],
-"cuda_2scalar__operations_8hpp.html#a07e0be416a8732c6a0637cf7f6b77ab4":[7,0,3,4,0,18,9],
-"cuda_2scalar__operations_8hpp.html#a0a4228286b28270ac6c3d870bd3795cd":[7,0,3,4,0,18,10],
-"cuda_2scalar__operations_8hpp.html#a0da1459f4ea0123577007992c1bc0b88":[7,0,3,4,0,18,4],
-"cuda_2scalar__operations_8hpp.html#a46cc5446cd00d687be1828a5bd661542":[7,0,3,4,0,18,14],
-"cuda_2scalar__operations_8hpp.html#a575576cdbfb3b25a9f0a08ea95545606":[7,0,3,4,0,18,7],
-"cuda_2scalar__operations_8hpp.html#a585713583193f822129f9ad731add69f":[7,0,3,4,0,18,5],
-"cuda_2scalar__operations_8hpp.html#a5b68f30ea78fb683bf95c102cc57ced3":[7,0,3,4,0,18,12],
-"cuda_2scalar__operations_8hpp.html#a8fc7dbf404b544c4a8d136ee169fc5a7":[7,0,3,4,0,18,8],
-"cuda_2scalar__operations_8hpp.html#a977bbf7c99c8698869270197663b7c5f":[7,0,3,4,0,18,0],
-"cuda_2scalar__operations_8hpp.html#aa7cca68c538586814cac5e7cf511a685":[7,0,3,4,0,18,2],
-"cuda_2scalar__operations_8hpp.html#ab31bfc6b874a06a0fa57a2bafa1510d4":[7,0,3,4,0,18,13],
-"cuda_2scalar__operations_8hpp.html#ab450fb683f732284d90281a6d1debd2b":[7,0,3,4,0,18,11],
-"cuda_2scalar__operations_8hpp.html#aca3f1e982cff8e1d86a38572d106e702":[7,0,3,4,0,18,3],
-"cuda_2scalar__operations_8hpp.html#ae960a90da7af9f5b805d55a8c5fb800f":[7,0,3,4,0,18,6],
-"cuda_2scalar__operations_8hpp_source.html":[7,0,3,4,0,18],
-"cuda_2sparse__matrix__operations_8hpp.html":[7,0,3,4,0,19],
-"cuda_2sparse__matrix__operations_8hpp.html#a024534399717753627909b438923214a":[7,0,3,4,0,19,5],
-"cuda_2sparse__matrix__operations_8hpp.html#a0c2c303c629870e3f32dc08c2cf22a64":[7,0,3,4,0,19,7],
-"cuda_2sparse__matrix__operations_8hpp.html#a0c365dcc8bb5fcc34ff63d4d59b7a1fa":[7,0,3,4,0,19,32],
-"cuda_2sparse__matrix__operations_8hpp.html#a0d90ae5104947ac08924577953bef578":[7,0,3,4,0,19,37],
-"cuda_2sparse__matrix__operations_8hpp.html#a0ef28a94368c9b52dc01d02303c012c1":[7,0,3,4,0,19,13],
-"cuda_2sparse__matrix__operations_8hpp.html#a162b793a59cb8435e2c8021baba67063":[7,0,3,4,0,19,26],
-"cuda_2sparse__matrix__operations_8hpp.html#a2274b07759c6f58ef22fc899f2e71df0":[7,0,3,4,0,19,40],
-"cuda_2sparse__matrix__operations_8hpp.html#a24059796bd4e6fc06e81b0dcb3c2634a":[7,0,3,4,0,19,38],
-"cuda_2sparse__matrix__operations_8hpp.html#a3a7b9b0998cc5a4c69049be2e0d70008":[7,0,3,4,0,19,24],
-"cuda_2sparse__matrix__operations_8hpp.html#a4138788ef0f9453e5cec339748b684f7":[7,0,3,4,0,19,25],
-"cuda_2sparse__matrix__operations_8hpp.html#a43b31c772693ff5486a7d6b97984f11d":[7,0,3,4,0,19,6],
-"cuda_2sparse__matrix__operations_8hpp.html#a45615bf3f3314b66269070ae06bc3386":[7,0,3,4,0,19,42],
-"cuda_2sparse__matrix__operations_8hpp.html#a4a8d6aa23566b195f88cd484f5847ab2":[7,0,3,4,0,19,41],
-"cuda_2sparse__matrix__operations_8hpp.html#a5084d3e574223cc8c80d82a5c0df44f3":[7,0,3,4,0,19,19],
-"cuda_2sparse__matrix__operations_8hpp.html#a55ee720fa910a193f763e5e0339b1d8f":[7,0,3,4,0,19,16],
-"cuda_2sparse__matrix__operations_8hpp.html#a56b30f30bab469b7ee9efa74a0479b0a":[7,0,3,4,0,19,4],
-"cuda_2sparse__matrix__operations_8hpp.html#a58667ad168f3038faf582fd9b7bcfe63":[7,0,3,4,0,19,15],
-"cuda_2sparse__matrix__operations_8hpp.html#a58f92a1210124363530b848ddbb2608e":[7,0,3,4,0,19,30],
-"cuda_2sparse__matrix__operations_8hpp.html#a5df5057dcbcb5b9aaecdd1044fc91471":[7,0,3,4,0,19,43],
-"cuda_2sparse__matrix__operations_8hpp.html#a627be04a12785d50ede1becfea01a8e8":[7,0,3,4,0,19,35],
-"cuda_2sparse__matrix__operations_8hpp.html#a62fe3f2822e97ce4a612c08271bff4ab":[7,0,3,4,0,19,18],
-"cuda_2sparse__matrix__operations_8hpp.html#a7fc317edefd9bb239a9d1d591bc6aaac":[7,0,3,4,0,19,17],
-"cuda_2sparse__matrix__operations_8hpp.html#a886565441cda563116228f1a984a9077":[7,0,3,4,0,19,31],
-"cuda_2sparse__matrix__operations_8hpp.html#a8d72d223a94a2e7d72599b197495ce28":[7,0,3,4,0,19,39],
-"cuda_2sparse__matrix__operations_8hpp.html#a8dc1bcfa3513087ec991e515d77cebeb":[7,0,3,4,0,19,3],
-"cuda_2sparse__matrix__operations_8hpp.html#a9b88a5d172082773693e6b71aae2c879":[7,0,3,4,0,19,29],
-"cuda_2sparse__matrix__operations_8hpp.html#aa2da2ca39d77243c4d1ed747a53a7622":[7,0,3,4,0,19,8],
-"cuda_2sparse__matrix__operations_8hpp.html#aa81864a154a9aa526e297c37c9eee511":[7,0,3,4,0,19,10],
-"cuda_2sparse__matrix__operations_8hpp.html#aabe94b15790c0d5ce1491105b4fa67a1":[7,0,3,4,0,19,33],
-"cuda_2sparse__matrix__operations_8hpp.html#ab3881905db81575de93b0fd9ae174b9b":[7,0,3,4,0,19,27],
-"cuda_2sparse__matrix__operations_8hpp.html#ab495253e3bb653e523c2e628efdd0d58":[7,0,3,4,0,19,21],
-"cuda_2sparse__matrix__operations_8hpp.html#ab6b75eafc5e309d770a760f3dad516f8":[7,0,3,4,0,19,9],
-"cuda_2sparse__matrix__operations_8hpp.html#ac588666828831dc470e4ed55da6d9a10":[7,0,3,4,0,19,1],
-"cuda_2sparse__matrix__operations_8hpp.html#ac72ca24b3c566d1d7a21f300b3973c80":[7,0,3,4,0,19,44],
-"cuda_2sparse__matrix__operations_8hpp.html#ac9cc3af3ddf62ac5a8d17deb100cd829":[7,0,3,4,0,19,20],
-"cuda_2sparse__matrix__operations_8hpp.html#ad31cda4aebc7b1b2455cb64510355ac1":[7,0,3,4,0,19,23],
-"cuda_2sparse__matrix__operations_8hpp.html#ad40efac67a29cbc3482aa6da0a6a7a02":[7,0,3,4,0,19,28],
-"cuda_2sparse__matrix__operations_8hpp.html#adc106f90ea24d3bd6691f0db4fd56d9c":[7,0,3,4,0,19,36],
-"cuda_2sparse__matrix__operations_8hpp.html#adef638b203497a37625dc0f3ef8a81e2":[7,0,3,4,0,19,2],
-"cuda_2sparse__matrix__operations_8hpp.html#adf0603d39ba4e5c25a45348fddede2be":[7,0,3,4,0,19,11],
-"cuda_2sparse__matrix__operations_8hpp.html#aecebe8fe96a843f68fadeefa6aa6c900":[7,0,3,4,0,19,14],
-"cuda_2sparse__matrix__operations_8hpp.html#aed1f23243a32f7b4fe627ca7c42346e4":[7,0,3,4,0,19,22],
-"cuda_2sparse__matrix__operations_8hpp.html#af538b6efd58d3b9a72d19d8e60aeab08":[7,0,3,4,0,19,12],
-"cuda_2sparse__matrix__operations_8hpp.html#afedae669b4c5992f25d43e89f67729d6":[7,0,3,4,0,19,34],
+"cuda_2sparse__matrix__operations_8hpp.html#a79333b0dc10fc077353e4e619e8c3125":[7,0,3,4,0,19,46],
+"cuda_2sparse__matrix__operations_8hpp.html#a7d8dbcdbd5534a37dc6db366babc60b7":[7,0,3,4,0,19,21],
+"cuda_2sparse__matrix__operations_8hpp.html#a7fc317edefd9bb239a9d1d591bc6aaac":[7,0,3,4,0,19,19],
+"cuda_2sparse__matrix__operations_8hpp.html#a805a66eac24013eedb4f656a27f0d980":[7,0,3,4,0,19,30],
+"cuda_2sparse__matrix__operations_8hpp.html#a9b88a5d172082773693e6b71aae2c879":[7,0,3,4,0,19,31],
+"cuda_2sparse__matrix__operations_8hpp.html#a9e2e96fb062cf0f5fa87006b6b1d0d2c":[7,0,3,4,0,19,34],
+"cuda_2sparse__matrix__operations_8hpp.html#a9e62b5d2820c1c201b2e8d20d5ed4a65":[7,0,3,4,0,19,37],
+"cuda_2sparse__matrix__operations_8hpp.html#aa81864a154a9aa526e297c37c9eee511":[7,0,3,4,0,19,12],
+"cuda_2sparse__matrix__operations_8hpp.html#aabe94b15790c0d5ce1491105b4fa67a1":[7,0,3,4,0,19,35],
+"cuda_2sparse__matrix__operations_8hpp.html#ab3881905db81575de93b0fd9ae174b9b":[7,0,3,4,0,19,29],
+"cuda_2sparse__matrix__operations_8hpp.html#ab495253e3bb653e523c2e628efdd0d58":[7,0,3,4,0,19,23],
+"cuda_2sparse__matrix__operations_8hpp.html#ab6b75eafc5e309d770a760f3dad516f8":[7,0,3,4,0,19,11],
+"cuda_2sparse__matrix__operations_8hpp.html#abcb8858e84408f2e4ac421801bc8f80e":[7,0,3,4,0,19,33],
+"cuda_2sparse__matrix__operations_8hpp.html#ac588666828831dc470e4ed55da6d9a10":[7,0,3,4,0,19,3],
+"cuda_2sparse__matrix__operations_8hpp.html#ac9cc3af3ddf62ac5a8d17deb100cd829":[7,0,3,4,0,19,22],
+"cuda_2sparse__matrix__operations_8hpp.html#ad31cda4aebc7b1b2455cb64510355ac1":[7,0,3,4,0,19,25],
+"cuda_2sparse__matrix__operations_8hpp.html#adc106f90ea24d3bd6691f0db4fd56d9c":[7,0,3,4,0,19,38],
+"cuda_2sparse__matrix__operations_8hpp.html#adef638b203497a37625dc0f3ef8a81e2":[7,0,3,4,0,19,4],
+"cuda_2sparse__matrix__operations_8hpp.html#adf0603d39ba4e5c25a45348fddede2be":[7,0,3,4,0,19,13],
+"cuda_2sparse__matrix__operations_8hpp.html#ae8300c63e8ef1f4b555fff6551c8e634":[7,0,3,4,0,19,40],
+"cuda_2sparse__matrix__operations_8hpp.html#aecebe8fe96a843f68fadeefa6aa6c900":[7,0,3,4,0,19,16],
+"cuda_2sparse__matrix__operations_8hpp.html#aed1f23243a32f7b4fe627ca7c42346e4":[7,0,3,4,0,19,24],
+"cuda_2sparse__matrix__operations_8hpp.html#af788bdbce7ac45ee8a7ed3b57bcc16f9":[7,0,3,4,0,19,14],
+"cuda_2sparse__matrix__operations_8hpp.html#afedae669b4c5992f25d43e89f67729d6":[7,0,3,4,0,19,36],
 "cuda_2sparse__matrix__operations_8hpp_source.html":[7,0,3,4,0,19],
 "cuda_2vector__operations_8hpp.html":[7,0,3,4,0,23],
 "cuda_2vector__operations_8hpp.html#a0084570f864bca09fd50bf70bc7151ba":[7,0,3,4,0,23,2],
@@ -209,20 +158,10 @@ var NAVTREEINDEX9 =
 "cuthill__mckee_8hpp.html#afc45d444ac8e66896ee5ba2b186a8510":[7,0,3,6,1,8],
 "cuthill__mckee_8hpp_source.html":[7,0,3,6,1],
 "cypress_8hpp.html":[7,0,3,2,0,0,2,0,0,1],
-"cypress_8hpp.html#a0465b4268c249dfaa94b987df68e0203":[7,0,3,2,0,0,2,0,0,1,11],
-"cypress_8hpp.html#a04b170219e447a120fb23c87fae66869":[7,0,3,2,0,0,2,0,0,1,10],
-"cypress_8hpp.html#a127308a8610f95cbc064d6cac6ca98a9":[7,0,3,2,0,0,2,0,0,1,1],
-"cypress_8hpp.html#a1a69df21383cd6fdcdbd391bc1146f6d":[7,0,3,2,0,0,2,0,0,1,8],
-"cypress_8hpp.html#a23ebc62288af5363da814000605f79e7":[7,0,3,2,0,0,2,0,0,1,9],
-"cypress_8hpp.html#a23fe3d74720124f6ef339cd196d86831":[7,0,3,2,0,0,2,0,0,1,0],
-"cypress_8hpp.html#a27db422105c8d9650b1248f09a972248":[7,0,3,2,0,0,2,0,0,1,6],
-"cypress_8hpp.html#a28f48231f00081a98ddcd7cd8135910c":[7,0,3,2,0,0,2,0,0,1,3],
-"cypress_8hpp.html#a40a59de4f3f2ca3c52708296c0541573":[7,0,3,2,0,0,2,0,0,1,13],
-"cypress_8hpp.html#a8638ef1d9e292eb6295ab2604dbaa4ce":[7,0,3,2,0,0,2,0,0,1,12],
-"cypress_8hpp.html#ab5cf26400e2a97ef5af2a86509451d44":[7,0,3,2,0,0,2,0,0,1,5],
-"cypress_8hpp.html#ab787739a0e379046b0859f1d1ba046fd":[7,0,3,2,0,0,2,0,0,1,7],
-"cypress_8hpp.html#acd226a7692103ffd46b9944a9737581e":[7,0,3,2,0,0,2,0,0,1,4],
-"cypress_8hpp.html#ae53b5bdcfa19555dc45f00ca47f356f8":[7,0,3,2,0,0,2,0,0,1,2],
+"cypress_8hpp.html#a127308a8610f95cbc064d6cac6ca98a9":[7,0,3,2,0,0,2,0,0,1,0],
+"cypress_8hpp.html#a28f48231f00081a98ddcd7cd8135910c":[7,0,3,2,0,0,2,0,0,1,2],
+"cypress_8hpp.html#acd226a7692103ffd46b9944a9737581e":[7,0,3,2,0,0,2,0,0,1,3],
+"cypress_8hpp.html#ae53b5bdcfa19555dc45f00ca47f356f8":[7,0,3,2,0,0,2,0,0,1,1],
 "cypress_8hpp_source.html":[7,0,3,2,0,0,2,0,0,1],
 "dense__blas_8cpp.html":[7,0,0,0,0],
 "dense__blas_8cpp.html#a0c464e202ab39eece213320f33750b8b":[7,0,0,0,0,0],
@@ -249,5 +188,66 @@ var NAVTREEINDEX9 =
 "detail_2spai_2qr_8hpp.html#a9a76ae3dcfedb876ec9f2db3155b81a7":[7,0,3,4,1,3,3,4],
 "detail_2spai_2qr_8hpp.html#a9c9928b400d93d677b626c5ea9e51819":[7,0,3,4,1,3,3,5],
 "detail_2spai_2qr_8hpp.html#aa237a50ec1e8dd5e279a0fb02ff0bf8f":[7,0,3,4,1,3,3,13],
-"detail_2spai_2qr_8hpp.html#aa47df1186969f6872fe0dcaf83d4982b":[7,0,3,4,1,3,3,12]
+"detail_2spai_2qr_8hpp.html#aa47df1186969f6872fe0dcaf83d4982b":[7,0,3,4,1,3,3,12],
+"detail_2spai_2qr_8hpp.html#aa50a771c3604ad3913905871d54176f4":[7,0,3,4,1,3,3,3],
+"detail_2spai_2qr_8hpp.html#ab3b64ba7bb53a1526cc852daf0d4d53e":[7,0,3,4,1,3,3,2],
+"detail_2spai_2qr_8hpp.html#abbff207e6f84bc89822c0eab0aea0fe7":[7,0,3,4,1,3,3,15],
+"detail_2spai_2qr_8hpp.html#abcaaf643f5b021ac04dd7690904e59f9":[7,0,3,4,1,3,3,17],
+"detail_2spai_2qr_8hpp.html#ae6d21631da144b8d5c5de25afcbe53e7":[7,0,3,4,1,3,3,7],
+"detail_2spai_2qr_8hpp.html#af12bfcc7a652ea6bc9150c302dae81a7":[7,0,3,4,1,3,3,9],
+"detail_2spai_2qr_8hpp.html#af7b43cbe43e0371cea55b325b410c1b4":[7,0,3,4,1,3,3,10],
+"detail_2spai_2qr_8hpp_source.html":[7,0,3,4,1,3,3],
+"detail_2spai_2spai_8hpp.html":[7,0,3,4,1,3,7],
+"detail_2spai_2spai_8hpp.html#a18b9a595189ffa38d5acdaad6a286905":[7,0,3,4,1,3,7,15],
+"detail_2spai_2spai_8hpp.html#a1a76d81e5a1302f9d03949ea2783ee7d":[7,0,3,4,1,3,7,19],
+"detail_2spai_2spai_8hpp.html#a1dda26d5d7af5cbba03485b2da3075b2":[7,0,3,4,1,3,7,0],
+"detail_2spai_2spai_8hpp.html#a312ded5b57f112daa612d3b790cbc830":[7,0,3,4,1,3,7,12],
+"detail_2spai_2spai_8hpp.html#a4673473f615b2369ca4e14b1a6f98b5c":[7,0,3,4,1,3,7,6],
+"detail_2spai_2spai_8hpp.html#a4a5e501e0f8a2f6e2733b0c5df10c6ad":[7,0,3,4,1,3,7,9],
+"detail_2spai_2spai_8hpp.html#a4d52c5d84eb0f23619d0129c50412e82":[7,0,3,4,1,3,7,7],
+"detail_2spai_2spai_8hpp.html#a511597723c2d451fda55ff4ead99eaf0":[7,0,3,4,1,3,7,21],
+"detail_2spai_2spai_8hpp.html#a5dca466b626554c2b42bf25b500842e2":[7,0,3,4,1,3,7,16],
+"detail_2spai_2spai_8hpp.html#a644c28fb7b3c4e677d86dc4b06388dab":[7,0,3,4,1,3,7,14],
+"detail_2spai_2spai_8hpp.html#a6983ad76ea95e66ed94092bd05f44204":[7,0,3,4,1,3,7,10],
+"detail_2spai_2spai_8hpp.html#a7c462e0ad109f5e23eb34982c2f91dd4":[7,0,3,4,1,3,7,20],
+"detail_2spai_2spai_8hpp.html#a906b89d67f50b1adf349391bb62b7cf0":[7,0,3,4,1,3,7,3],
+"detail_2spai_2spai_8hpp.html#a934fa8b447e7836d4c9be2dd40c35390":[7,0,3,4,1,3,7,18],
+"detail_2spai_2spai_8hpp.html#acaad1278cf03e43d711f0f24d9d454c9":[7,0,3,4,1,3,7,5],
+"detail_2spai_2spai_8hpp.html#ada1688aeb8885254756bf80384a223ac":[7,0,3,4,1,3,7,1],
+"detail_2spai_2spai_8hpp.html#ae544b4abea516f88a64117c4c548d3a7":[7,0,3,4,1,3,7,4],
+"detail_2spai_2spai_8hpp.html#ae5d1da881af74993b78c433286b70a00":[7,0,3,4,1,3,7,17],
+"detail_2spai_2spai_8hpp.html#aea8b96ecccca6f209e810669f0d13e36":[7,0,3,4,1,3,7,13],
+"detail_2spai_2spai_8hpp.html#af29f9f19dceffdd04a1ac530c6fbb4ed":[7,0,3,4,1,3,7,8],
+"detail_2spai_2spai_8hpp.html#afe2919f83347787985e20e0599ba4296":[7,0,3,4,1,3,7,2],
+"detail_2spai_2spai_8hpp.html#aff1616fc9ee32fd0e1d641f6d8f2ebf3":[7,0,3,4,1,3,7,11],
+"detail_2spai_2spai_8hpp_source.html":[7,0,3,4,1,3,7],
+"devastator_8hpp.html":[7,0,3,2,0,0,2,0,1,1],
+"devastator_8hpp.html#a1f4714219d6dc156beb94179729d02f4":[7,0,3,2,0,0,2,0,1,1,1],
+"devastator_8hpp.html#a3efd3b9772f8ea7229bbe154cb0ca84f":[7,0,3,2,0,0,2,0,1,1,0],
+"devastator_8hpp.html#a4ff2803744c9df519eb87a0549b08bcf":[7,0,3,2,0,0,2,0,1,1,2],
+"devastator_8hpp.html#abb46400dbeeadbd7704dbb0bc979e927":[7,0,3,2,0,0,2,0,1,1,3],
+"devastator_8hpp_source.html":[7,0,3,2,0,0,2,0,1,1],
+"device_8hpp.html":[7,0,3,7,3],
+"device_8hpp_source.html":[7,0,3,7,3],
+"device__specific_2builtin__database_2common_8hpp.html":[7,0,3,2,0,1],
+"device__specific_2builtin__database_2common_8hpp.html#a6f059365bdf3dcb21b78c519dc294250":[7,0,3,2,0,1,7],
+"device__specific_2builtin__database_2common_8hpp.html#a95ff5245e4bc95912528d86219bb8bde":[7,0,3,2,0,1,6],
+"device__specific_2builtin__database_2common_8hpp_source.html":[7,0,3,2,0,1],
+"device__specific_2execute_8hpp.html":[7,0,3,2,2],
+"device__specific_2execute_8hpp.html#a0e0576421dc6e48555abd251d0a83ae0":[7,0,3,2,2,0],
+"device__specific_2execute_8hpp_source.html":[7,0,3,2,2],
+"device__specific_2forwards_8h.html":[7,0,3,2,4],
+"device__specific_2forwards_8h.html#a08bd08c6dc86b78e78749891e8832fe4":[7,0,3,2,4,16],
+"device__specific_2forwards_8h.html#a4ae1b6692dfe648094c52c14f0e81d45":[7,0,3,2,4,11],
+"device__specific_2forwards_8h.html#a5927db4220a325127326f3391ddf3321":[7,0,3,2,4,10],
+"device__specific_2forwards_8h.html#a5a4282524aeeafba4d9c5e44397403e7":[7,0,3,2,4,22],
+"device__specific_2forwards_8h.html#a70f9b436519b02537064504f3a327470":[7,0,3,2,4,24],
+"device__specific_2forwards_8h.html#a7935d6fe2cb68ce032c9a177ed7f1d41":[7,0,3,2,4,23],
+"device__specific_2forwards_8h.html#a810fd16fbb883a4987ff0cf720d47037":[7,0,3,2,4,17],
+"device__specific_2forwards_8h.html#a89c2dbe54841c653951eaa6a248c7526":[7,0,3,2,4,20],
+"device__specific_2forwards_8h.html#aa451f851b492f6422bfdd71f51fdc1fb":[7,0,3,2,4,7],
+"device__specific_2forwards_8h.html#aaa1f965282523dc44221b5ee4a99d41b":[7,0,3,2,4,8],
+"device__specific_2forwards_8h.html#ab912aba0d144f286022bb3af5d5f8f77":[7,0,3,2,4,15],
+"device__specific_2forwards_8h.html#ac45007f831a7945fb8b03ab3a8498446":[7,0,3,2,4,9],
+"device__specific_2forwards_8h.html#acc7955a54ca37ad328cc400859d39be9":[7,0,3,2,4,12]
 };
