@@ -1,10 +1,10 @@
 var searchData=
 [
   ['j',['j',['../structviennacl_1_1device__specific_1_1index__tuple.html#aac82b1c95dd3e2295fd86f49550a9766',1,'viennacl::device_specific::index_tuple']]],
+  ['jacobi_5fiters',['jacobi_iters',['../classviennacl_1_1linalg_1_1chow__patel__tag.html#a57b522b1e889fe09b1e5b9ed47b7e036',1,'viennacl::linalg::chow_patel_tag::jacobi_iters() const '],['../classviennacl_1_1linalg_1_1chow__patel__tag.html#ac481d0e7a28ee1c4ec83e70877329aba',1,'viennacl::linalg::chow_patel_tag::jacobi_iters(vcl_size_t num)']]],
   ['jacobi_5fprecond',['jacobi_precond',['../classviennacl_1_1linalg_1_1jacobi__precond.html',1,'viennacl::linalg']]],
   ['jacobi_5fprecond',['jacobi_precond',['../classviennacl_1_1linalg_1_1jacobi__precond.html#a8484f42e58dc181682e8b0d7c5e59c2a',1,'viennacl::linalg::jacobi_precond::jacobi_precond()'],['../classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html#ac157dcfa0588c12f721fd1f0b492d222',1,'viennacl::linalg::jacobi_precond&lt; MatrixT, true &gt;::jacobi_precond()']]],
   ['jacobi_5fprecond_2ehpp',['jacobi_precond.hpp',['../jacobi__precond_8hpp.html',1,'']]],
   ['jacobi_5fprecond_3c_20matrixt_2c_20true_20_3e',['jacobi_precond< MatrixT, true >',['../classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html',1,'viennacl::linalg']]],
-  ['jacobi_5ftag',['jacobi_tag',['../classviennacl_1_1linalg_1_1jacobi__tag.html',1,'viennacl::linalg']]],
-  ['join',['join',['../classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html#ac1b7e036e87322e750639ecdd8d8daac',1,'viennacl::linalg::detail::amg::amg_slicing']]]
+  ['jacobi_5ftag',['jacobi_tag',['../classviennacl_1_1linalg_1_1jacobi__tag.html',1,'viennacl::linalg']]]
 ];
