@@ -1,7 +1,7 @@
 var searchData=
 [
-  ['scalar',['scalar',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html',1,'viennacl::linalg::opencl::kernels']]],
   ['scalar',['scalar',['../classviennacl_1_1scalar.html',1,'viennacl']]],
+  ['scalar',['scalar',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html',1,'viennacl::linalg::opencl::kernels']]],
   ['scalar_3c_20char_20_3e',['scalar&lt; char &gt;',['../classviennacl_1_1scalar.html',1,'viennacl']]],
   ['scalar_3c_20double_20_3e',['scalar&lt; double &gt;',['../classviennacl_1_1scalar.html',1,'viennacl']]],
   ['scalar_3c_20float_20_3e',['scalar&lt; float &gt;',['../classviennacl_1_1scalar.html',1,'viennacl']]],
@@ -32,8 +32,8 @@ var searchData=
   ['size2_5ffun',['size2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html',1,'viennacl::device_specific::utils']]],
   ['size_5ffun',['size_fun',['../structviennacl_1_1device__specific_1_1utils_1_1size__fun.html',1,'viennacl::device_specific::utils']]],
   ['size_5ftype',['size_type',['../structviennacl_1_1result__of_1_1size__type.html',1,'viennacl::result_of']]],
-  ['sliced_5fell_5fmatrix',['sliced_ell_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
   ['sliced_5fell_5fmatrix',['sliced_ell_matrix',['../classviennacl_1_1sliced__ell__matrix.html',1,'viennacl']]],
+  ['sliced_5fell_5fmatrix',['sliced_ell_matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix.html',1,'viennacl::linalg::opencl::kernels']]],
   ['sliced_5fell_5fmatrix_3c_20numerict_2c_20unsigned_20int_20_3e',['sliced_ell_matrix&lt; NumericT, unsigned int &gt;',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html',1,'viennacl::linalg::opencl::kernels']]],
   ['spai',['spai',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html',1,'viennacl::linalg::opencl::kernels']]],
   ['spai_5fprecond',['spai_precond',['../classviennacl_1_1linalg_1_1spai__precond.html',1,'viennacl::linalg']]],
@@ -44,6 +44,8 @@ var searchData=
   ['sparse_5fvector',['sparse_vector',['../classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html',1,'viennacl::linalg::detail::spai']]],
   ['spgemm_5foutput_5fwrite_5fdisabled',['spgemm_output_write_disabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__disabled.html',1,'viennacl::linalg::host_based']]],
   ['spgemm_5foutput_5fwrite_5fenabled',['spgemm_output_write_enabled',['../structviennacl_1_1linalg_1_1host__based_1_1spgemm__output__write__enabled.html',1,'viennacl::linalg::host_based']]],
+  ['spmv_5falpha_5fbeta',['spmv_alpha_beta',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__alpha__beta.html',1,'viennacl::linalg::cuda::detail']]],
+  ['spmv_5fpure',['spmv_pure',['../structviennacl_1_1linalg_1_1cuda_1_1detail_1_1spmv__pure.html',1,'viennacl::linalg::cuda::detail']]],
   ['start1_5ffun',['start1_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html',1,'viennacl::device_specific::utils']]],
   ['start2_5ffun',['start2_fun',['../structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html',1,'viennacl::device_specific::utils']]],
   ['statement',['statement',['../classviennacl_1_1scheduler_1_1statement.html',1,'viennacl::scheduler']]],
