@@ -13,5 +13,6 @@ var searchData=
   ['array_5fdeleter',['array_deleter',['../structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html',1,'viennacl::backend::cpu_ram::detail']]],
   ['asbs_5fconfig',['asbs_config',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html',1,'viennacl::linalg::opencl::kernels']]],
   ['aux',['aux',['../structviennacl_1_1tools_1_1detail_1_1aux.html',1,'viennacl::tools::detail']]],
-  ['auximpl',['auximpl',['../structviennacl_1_1tools_1_1detail_1_1auximpl.html',1,'viennacl::tools::detail']]]
+  ['auximpl',['auximpl',['../structviennacl_1_1tools_1_1detail_1_1auximpl.html',1,'viennacl::tools::detail']]],
+  ['avbv_5fconfig',['avbv_config',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config.html',1,'viennacl::linalg::opencl::kernels']]]
 ];
