@@ -1,8 +1,10 @@
 var searchData=
 [
+  ['uniform_5frandom_5fnumbers',['uniform_random_numbers',['../classviennacl_1_1tools_1_1uniform__random__numbers.html',1,'viennacl::tools']]],
   ['unit_5flower_5ftag',['unit_lower_tag',['../structviennacl_1_1linalg_1_1unit__lower__tag.html',1,'viennacl::linalg']]],
   ['unit_5fupper_5ftag',['unit_upper_tag',['../structviennacl_1_1linalg_1_1unit__upper__tag.html',1,'viennacl::linalg']]],
   ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html',1,'viennacl']]],
   ['unknown_5ferror',['unknown_error',['../classviennacl_1_1ocl_1_1unknown__error.html',1,'viennacl::ocl']]],
+  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html',1,'viennacl']]],
   ['upper_5ftag',['upper_tag',['../structviennacl_1_1linalg_1_1upper__tag.html',1,'viennacl::linalg']]]
 ];
