@@ -20,12 +20,10 @@ var searchData=
   ['mapped_5fvector',['mapped_vector',['../classviennacl_1_1device__specific_1_1mapped__vector.html',1,'viennacl::device_specific']]],
   ['mapped_5fvector_5fdiag',['mapped_vector_diag',['../classviennacl_1_1device__specific_1_1mapped__vector__diag.html',1,'viennacl::device_specific']]],
   ['mat_5fmult_5fmatrix_5findex',['mat_mult_matrix_index',['../structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html',1,'viennacl::linalg::cuda']]],
-  ['matrix',['matrix',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html',1,'viennacl::linalg::opencl::kernels']]],
+  ['matrix',['matrix',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html',1,'viennacl::linalg::opencl::kernels']]],
   ['matrix',['matrix',['../classviennacl_1_1matrix.html',1,'viennacl']]],
   ['matrix_3c_20numerict_20_3e',['matrix&lt; NumericT &gt;',['../classviennacl_1_1matrix.html',1,'viennacl']]],
   ['matrix_5farray_5fwrapper',['matrix_array_wrapper',['../classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html',1,'viennacl::linalg::host_based::detail']]],
-  ['matrix_5faxpy_5fparameters_5ftype',['matrix_axpy_parameters_type',['../classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html',1,'viennacl::device_specific']]],
-  ['matrix_5faxpy_5ftemplate',['matrix_axpy_template',['../classviennacl_1_1device__specific_1_1matrix__axpy__template.html',1,'viennacl::device_specific']]],
   ['matrix_5fbase',['matrix_base',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
   ['matrix_5fbase_3c_20char_20_3e',['matrix_base&lt; char &gt;',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
   ['matrix_5fbase_3c_20double_20_3e',['matrix_base&lt; double &gt;',['../classviennacl_1_1matrix__base.html',1,'viennacl']]],
