@@ -6,5 +6,6 @@ var searchData=
   ['power_5fiter_5ftag',['power_iter_tag',['../classviennacl_1_1linalg_1_1power__iter__tag.html',1,'viennacl::linalg']]],
   ['process_5ftraversal',['process_traversal',['../classviennacl_1_1device__specific_1_1tree__parsing_1_1process__traversal.html',1,'viennacl::device_specific::tree_parsing']]],
   ['profiling_5finfo_5fnot_5favailable',['profiling_info_not_available',['../classviennacl_1_1ocl_1_1profiling__info__not__available.html',1,'viennacl::ocl']]],
-  ['program',['program',['../classviennacl_1_1ocl_1_1program.html',1,'viennacl::ocl']]]
+  ['program',['program',['../classviennacl_1_1ocl_1_1program.html',1,'viennacl::ocl']]],
+  ['program_5fnot_5ffound',['program_not_found',['../classviennacl_1_1ocl_1_1program__not__found.html',1,'viennacl::ocl']]]
 ];
