@@ -3,5 +3,6 @@ var searchData=
   ['ambm_5fscalar_5ftype',['ambm_scalar_type',['../namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html#a0cafaf477353c066293d8e29ab6f80a6',1,'viennacl::linalg::opencl::kernels']]],
   ['amg_5fcoarsening_5fmethod',['amg_coarsening_method',['../namespaceviennacl_1_1linalg.html#a3ba810acdca541a5eada4560982a645c',1,'viennacl::linalg']]],
   ['amg_5finterpolation_5fmethod',['amg_interpolation_method',['../namespaceviennacl_1_1linalg.html#a9933216144a64dbd433ec02c95bbfdd7',1,'viennacl::linalg']]],
-  ['asbs_5fscalar_5ftype',['asbs_scalar_type',['../namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html#a323e3383b8b667f277bed47432bb8ce9',1,'viennacl::linalg::opencl::kernels']]]
+  ['asbs_5fscalar_5ftype',['asbs_scalar_type',['../namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html#a323e3383b8b667f277bed47432bb8ce9',1,'viennacl::linalg::opencl::kernels']]],
+  ['avbv_5fscalar_5ftype',['avbv_scalar_type',['../namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html#ab23ebf188d7c889220ae36ae83d23496',1,'viennacl::linalg::opencl::kernels']]]
 ];
