@@ -2,15 +2,16 @@ var searchData=
 [
   ['main_2edox',['main.dox',['../main_8dox.html',1,'']]],
   ['mapped_5fobjects_2ehpp',['mapped_objects.hpp',['../mapped__objects_8hpp.html',1,'']]],
+  ['matrix_2dfree_2ecpp',['matrix-free.cpp',['../matrix-free_8cpp.html',1,'']]],
   ['matrix_2drange_2ecpp',['matrix-range.cpp',['../matrix-range_8cpp.html',1,'']]],
   ['matrix_2ehpp',['matrix.hpp',['../linalg_2opencl_2kernels_2matrix_8hpp.html',1,'']]],
   ['matrix_2ehpp',['matrix.hpp',['../matrix_8hpp.html',1,'']]],
-  ['matrix_5faxpy_2ehpp',['matrix_axpy.hpp',['../matrix__axpy_8hpp.html',1,'']]],
-  ['matrix_5faxpy_5ftemplate_2ehpp',['matrix_axpy_template.hpp',['../matrix__axpy__template_8hpp.html',1,'']]],
   ['matrix_5fcol_5fdouble_2ecpp',['matrix_col_double.cpp',['../matrix__col__double_8cpp.html',1,'']]],
   ['matrix_5fcol_5ffloat_2ecpp',['matrix_col_float.cpp',['../matrix__col__float_8cpp.html',1,'']]],
   ['matrix_5fcol_5fint_2ecpp',['matrix_col_int.cpp',['../matrix__col__int_8cpp.html',1,'']]],
+  ['matrix_5fconvert_2ecpp',['matrix_convert.cpp',['../matrix__convert_8cpp.html',1,'']]],
   ['matrix_5fdef_2ehpp',['matrix_def.hpp',['../matrix__def_8hpp.html',1,'']]],
+  ['matrix_5felement_2ehpp',['matrix_element.hpp',['../matrix__element_8hpp.html',1,'']]],
   ['matrix_5ffloat_5fdouble_2ehpp',['matrix_float_double.hpp',['../matrix__float__double_8hpp.html',1,'']]],
   ['matrix_5fgeneration_2ehpp',['matrix_generation.hpp',['../matrix__generation_8hpp.html',1,'']]],
   ['matrix_5fint_2ehpp',['matrix_int.hpp',['../matrix__int_8hpp.html',1,'']]],
@@ -39,10 +40,10 @@ var searchData=
   ['mem_5fhandle_2ehpp',['mem_handle.hpp',['../mem__handle_8hpp.html',1,'']]],
   ['memory_2edox',['memory.dox',['../memory_8dox.html',1,'']]],
   ['memory_2ehpp',['memory.hpp',['../memory_8hpp.html',1,'']]],
-  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../host__based_2misc__operations_8hpp.html',1,'']]],
-  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../cuda_2misc__operations_8hpp.html',1,'']]],
-  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../misc__operations_8hpp.html',1,'']]],
   ['misc_5foperations_2ehpp',['misc_operations.hpp',['../opencl_2misc__operations_8hpp.html',1,'']]],
+  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../misc__operations_8hpp.html',1,'']]],
+  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../cuda_2misc__operations_8hpp.html',1,'']]],
+  ['misc_5foperations_2ehpp',['misc_operations.hpp',['../host__based_2misc__operations_8hpp.html',1,'']]],
   ['mixed_5fprecision_5fcg_2ehpp',['mixed_precision_cg.hpp',['../mixed__precision__cg_8hpp.html',1,'']]],
   ['mtl4_2dwith_2dviennacl_2ecpp',['mtl4-with-viennacl.cpp',['../mtl4-with-viennacl_8cpp.html',1,'']]],
   ['multi_2ddevice_2edox',['multi-device.dox',['../multi-device_8dox.html',1,'']]],
