@@ -1,9 +1,7 @@
 var searchData=
 [
-  ['unary_5felement_5fop',['unary_element_op',['../namespaceviennacl_1_1scheduler_1_1preset.html#aa11466374772f68e24f7ec8053dc859f',1,'viennacl::scheduler::preset']]],
   ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html#acf1edf2697940a7321bdfc8b4e4d459a',1,'viennacl::unit_vector']]],
   ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html#a54d00eebcc284ec99fe2ad144f594265',1,'viennacl::unknown_norm_exception']]],
-  ['up_5fto_5finternal_5fsize',['up_to_internal_size',['../classviennacl_1_1device__specific_1_1matrix__axpy__template.html#a3b489a3a6960699bfb85ffae95273882',1,'viennacl::device_specific::matrix_axpy_template::up_to_internal_size()'],['../classviennacl_1_1device__specific_1_1vector__axpy__template.html#a950bc84f7f5240d3b5fe3d584c9a0bfa',1,'viennacl::device_specific::vector_axpy_template::up_to_internal_size()']]],
   ['update_5ffloat_5fqr_5fcolumn',['update_float_QR_column',['../namespaceviennacl_1_1linalg_1_1detail.html#a4d6d704d39ec27eb15a604580eb1df5b',1,'viennacl::linalg::detail']]],
   ['update_5ffloat_5fqr_5fcolumn_5fgpu',['update_float_QR_column_gpu',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ce6438b322e096df65112ac6536b0b1',1,'viennacl::linalg::detail']]],
   ['upper_5finplace_5fsolve_5fmatrix',['upper_inplace_solve_matrix',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a38989d09acd0c0763276fd94123e9d51',1,'viennacl::linalg::host_based::detail']]],
