@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['additional_20algorithms',['Additional Algorithms',['../manual-additional-algorithms.html',1,'usermanual']]],
+  ['additional_20algorithms_20_28unstable_29',['Additional Algorithms (Unstable)',['../manual-additional-algorithms.html',1,'usermanual']]],
   ['algorithms',['Algorithms',['../manual-algorithms.html',1,'usermanual']]],
   ['authors_20and_20contributors',['Authors and Contributors',['../manual-authors.html',1,'usermanual']]]
 ];
