@@ -2,8 +2,7 @@ var searchData=
 [
   ['p',['p',['../structviennacl_1_1tools_1_1detail_1_1auximpl.html#ac2091cb8c855a44b2509b53e8bf1698d',1,'viennacl::tools::detail::auximpl']]],
   ['p_5f',['p_',['../classviennacl_1_1device__specific_1_1template__base__impl.html#ac1a2b570d477d82f9cbd3d88dcb6e8c2',1,'viennacl::device_specific::template_base_impl']]],
-  ['pointvector_5fslice_5f',['pointvector_slice_',['../classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html#ab1df4b3928ab779316f997b2cd279957',1,'viennacl::linalg::detail::amg::amg_slicing']]],
+  ['point_5ftypes_5f',['point_types_',['../structviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__level__context.html#a8856e6db54e88c12e2ac728b5fcbe1e4',1,'viennacl::linalg::detail::amg::amg_level_context']]],
   ['precision',['precision',['../struct_vienna_c_l_host_scalar__impl.html#a5017f1f1f2d1e9054c4a1b8f5f724211',1,'ViennaCLHostScalar_impl::precision()'],['../struct_vienna_c_l_scalar__impl.html#af8a28d7c016b5c0b811c46a4bcb4b7c2',1,'ViennaCLScalar_impl::precision()'],['../struct_vienna_c_l_vector__impl.html#a8d5df6fb95c537becef8fe3f574945f9',1,'ViennaCLVector_impl::precision()'],['../struct_vienna_c_l_matrix__impl.html#ad9b5572714d5760e0d6db0d5c4eacbc4',1,'ViennaCLMatrix_impl::precision()']]],
-  ['problem',['problem',['../least-squares_8cpp.html#a5bd8cdcf93dfca2b1a3e30bff4607bde',1,'least-squares.cpp']]],
-  ['progress',['progress',['../changelog.html#a2e94e83059a899735d4cae8bfa5d1626',1,'changelog']]]
+  ['problem',['problem',['../least-squares_8cpp.html#a5bd8cdcf93dfca2b1a3e30bff4607bde',1,'least-squares.cpp']]]
 ];
