@@ -19,7 +19,7 @@ var searchData=
   ['size1_5f',['size1_',['../classviennacl_1_1implicit__matrix__base.html#af45a73be66586ba3d7e64ea917e0a072',1,'viennacl::implicit_matrix_base']]],
   ['size2',['size2',['../struct_vienna_c_l_matrix__impl.html#ac2184140bcb059f7521857a6a5ef4362',1,'ViennaCLMatrix_impl']]],
   ['size2_5f',['size2_',['../classviennacl_1_1implicit__matrix__base.html#a6873916ea820179b0bb9c6cafa8e6b00',1,'viennacl::implicit_matrix_base']]],
-  ['size_5f',['size_',['../classviennacl_1_1implicit__vector__base.html#aec8627d9a9f2b395bef3e0e39d0e71e8',1,'viennacl::implicit_vector_base']]],
+  ['size_5f',['size_',['../classviennacl_1_1implicit__vector__base.html#aec8627d9a9f2b395bef3e0e39d0e71e8',1,'viennacl::implicit_vector_base::size_()'],['../structviennacl_1_1linalg_1_1detail_1_1ilut__sparse__vector.html#a596273b4c650b973e801e4f182b78ba7',1,'viennacl::linalg::detail::ilut_sparse_vector::size_()']]],
   ['start',['start',['../structviennacl_1_1ocl_1_1packed__cl__uint.html#a7991987e7676fabb8d1cbc54eaa0ba01',1,'viennacl::ocl::packed_cl_uint']]],
   ['start1',['start1',['../struct_vienna_c_l_matrix__impl.html#a56404bb5c6aaf0b64c53c89b2f6bc26a',1,'ViennaCLMatrix_impl']]],
   ['start2',['start2',['../struct_vienna_c_l_matrix__impl.html#ab7815c208b9260ca0097909c1892fd0f',1,'ViennaCLMatrix_impl']]],
@@ -37,7 +37,6 @@ var searchData=
   ['svd_5fbidiag_5fpack_5fkernel',['SVD_BIDIAG_PACK_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a6c692160febc1bf0c8c1b3f14609843b',1,'viennacl::linalg::opencl']]],
   ['svd_5fcopy_5fcol_5fkernel',['SVD_COPY_COL_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a83f95bb0dba31593bfdea7d48825ef45',1,'viennacl::linalg::opencl']]],
   ['svd_5fcopy_5frow_5fkernel',['SVD_COPY_ROW_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#adf9d9e0232c7731006e942e6f1eb787c',1,'viennacl::linalg::opencl']]],
-  ['svd_5fexclusive_5fscan_5fkernel_5f1',['SVD_EXCLUSIVE_SCAN_KERNEL_1',['../namespaceviennacl_1_1linalg_1_1opencl.html#a55efe16c86efff4d42bfa7ecea29fa70',1,'viennacl::linalg::opencl']]],
   ['svd_5ffinal_5fiter_5fupdate_5fkernel',['SVD_FINAL_ITER_UPDATE_KERNEL',['../namespaceviennacl_1_1linalg.html#a8477d884683dafc7e6ca04f2e02a1d1f',1,'viennacl::linalg']]],
   ['svd_5fgivens_5fnext_5fkernel',['SVD_GIVENS_NEXT_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#ae14982b121ba058e0cc0569b93f80646',1,'viennacl::linalg::opencl']]],
   ['svd_5fgivens_5fprev_5fkernel',['SVD_GIVENS_PREV_KERNEL',['../namespaceviennacl_1_1linalg.html#a15bedacb51ec9b425baf52ee7f68bdba',1,'viennacl::linalg']]],
@@ -45,11 +44,7 @@ var searchData=
   ['svd_5fhouseholder_5fupdate_5fa_5fright_5fkernel',['SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a24049445243113b8aff433e4dd6d3c01',1,'viennacl::linalg::opencl::SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL()'],['../namespaceviennacl_1_1linalg.html#ace85ea4095e9e7404b6f77b767ac000f',1,'viennacl::linalg::SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL()']]],
   ['svd_5fhouseholder_5fupdate_5fql_5fkernel',['SVD_HOUSEHOLDER_UPDATE_QL_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a656519064a982e5904b5a66b5e9c2785',1,'viennacl::linalg::opencl::SVD_HOUSEHOLDER_UPDATE_QL_KERNEL()'],['../namespaceviennacl_1_1linalg.html#a04a5ce1f7230502c9d1ee87dcc24c8b4',1,'viennacl::linalg::SVD_HOUSEHOLDER_UPDATE_QL_KERNEL()']]],
   ['svd_5fhouseholder_5fupdate_5fqr_5fkernel',['SVD_HOUSEHOLDER_UPDATE_QR_KERNEL',['../namespaceviennacl_1_1linalg.html#a5b5cb81b46208cae772a5e0813f02517',1,'viennacl::linalg']]],
-  ['svd_5finclusive_5fscan_5fkernel_5f1',['SVD_INCLUSIVE_SCAN_KERNEL_1',['../namespaceviennacl_1_1linalg_1_1opencl.html#a0c1e78c33de1edf10a666c2a3d561af3',1,'viennacl::linalg::opencl']]],
   ['svd_5finverse_5fsigns_5fkernel',['SVD_INVERSE_SIGNS_KERNEL',['../namespaceviennacl_1_1linalg.html#a05717ddd22894376e780b075d59616ed',1,'viennacl::linalg']]],
   ['svd_5fmatrix_5ftranspose_5fkernel',['SVD_MATRIX_TRANSPOSE_KERNEL',['../namespaceviennacl_1_1linalg.html#a349e6e78f95ef631a5f2736158766739',1,'viennacl::linalg']]],
-  ['svd_5fscan_5fkernel_5f2',['SVD_SCAN_KERNEL_2',['../namespaceviennacl_1_1linalg_1_1opencl.html#a5077728cfc9a2f2bdf1e480948a3fe6f',1,'viennacl::linalg::opencl']]],
-  ['svd_5fscan_5fkernel_5f3',['SVD_SCAN_KERNEL_3',['../namespaceviennacl_1_1linalg_1_1opencl.html#ac35599cd7a904c6187e3d1e4c5b2d38b',1,'viennacl::linalg::opencl']]],
-  ['svd_5fscan_5fkernel_5f4',['SVD_SCAN_KERNEL_4',['../namespaceviennacl_1_1linalg_1_1opencl.html#a24d101c5571414986506c8170ce4f261',1,'viennacl::linalg::opencl']]],
   ['svd_5fupdate_5fqr_5fcolumn_5fkernel',['SVD_UPDATE_QR_COLUMN_KERNEL',['../namespaceviennacl_1_1linalg.html#a3a439370108ddfa59c2fcb4136b13c8d',1,'viennacl::linalg']]]
 ];
