@@ -1,7 +1,7 @@
 var solver_8cpp =
 [
     [ "BENCHMARK_RUNS", "solver_8cpp.html#adb0225facf93cb5236fe7a5c0bf50f18", null ],
-    [ "NDEBUG", "solver_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e", null ],
+    [ "BOOST_UBLAS_NDEBUG", "solver_8cpp.html#aa2c0476a142c9e172a2c18d054b6c210", null ],
     [ "VIENNACL_WITH_UBLAS", "solver_8cpp.html#af9d2311f8dd8c5536101e46f1351df56", null ],
     [ "diff_2", "solver_8cpp.html#a1f843c90fc96fbef2ece33a7a818fcfd", null ],
     [ "diff_inf", "solver_8cpp.html#a9b90f6647b9bb73122488fbba0c0f4b3", null ],
