@@ -1,8 +1,6 @@
 var tql_8cpp =
 [
     [ "EPS", "tql_8cpp.html#a6ebf6899d6c1c8b7b9d09be872c05aae", null ],
-    [ "NDEBUG", "tql_8cpp.html#a8de3ed741dadc9c979a4ff17c0a9116e", null ],
-    [ "VIENNACL_WITH_UBLAS", "tql_8cpp.html#af9d2311f8dd8c5536101e46f1351df56", null ],
     [ "ScalarType", "tql_8cpp.html#ad5c19ca4f47d3f8ec21232a5af2624e5", null ],
     [ "main", "tql_8cpp.html#ae66f6b31b5ad750f1fe042a706a4e3d4", null ],
     [ "test_eigen_val_vec", "tql_8cpp.html#addc3b5bf488c68ee7b156e7554638126", null ],
