@@ -2,7 +2,7 @@
 #define VIENNACL_TOOLS_ADAPTER_HPP_
 
 /* =========================================================================
-   Copyright (c) 2010-2014, Institute for Microelectronics,
+   Copyright (c) 2010-2016, Institute for Microelectronics,
                             Institute for Analysis and Scientific Computing,
                             TU Wien.
    Portions of this software are copyright by UChicago Argonne, LLC.
@@ -13,7 +13,7 @@
 
    Project Head:    Karl Rupp                   rupp@iue.tuwien.ac.at
 
-   (A list of authors and contributors can be found in the PDF manual)
+   (A list of authors and contributors can be found in the manual)
 
    License:         MIT (X11), see file LICENSE in the base directory
 ============================================================================= */
@@ -365,7 +365,7 @@ public:
   typedef SizeT                                              size_type;
 
   sparse_matrix_adapter(std::vector<std::map<SizeT, NumericT> > & mat)
-    : BaseType(mat), mat_(mat), size1_(mat_.size()), size2_(mat_.size()) {}
+    : BaseType(mat), mat_(mat), size1_(static_cast<SizeT>(mat_.size())), size2_(static_cast<SizeT>(mat_.size())) {}
 
   sparse_matrix_adapter(std::vector<std::map<SizeT, NumericT> > & mat,
                         vcl_size_t num_rows,
